@@ -41,7 +41,8 @@ AppWindow* AppWindow::p = NULL;
 // CONSTRUCTOR
 AppWindow::AppWindow()
 :   m_view_login( NULL ), m_diary_view( NULL ), m_entry_view( NULL ), m_tag_view( NULL ),
-    m_ctg_tags_view( NULL ), m_chapter_view( NULL ), m_about_dialog( NULL ), m_paned_main( NULL )
+    m_ctg_tags_view( NULL ), m_chapter_view( NULL ), m_about_dialog( NULL ), m_paned_main( NULL ),
+    m_seconds_remaining( LOGOUT_COUNTDOWN + 1 ), m_auto_logout_status( 1 )
 {
     p = this;
 
@@ -62,11 +63,23 @@ AppWindow::AppWindow()
     // GTKBUILDER
     Lifeograph::p->load_gui( UIDIR "/lifeograph.ui" );
 
+    // HEADERBAR
+    m_headerbar.set_show_close_button();
+
+    // Set headerbar as titlebar
+    set_titlebar( m_headerbar );
+    m_headerbar.show();
+
     // DRAW UI
-    if( Lifeograph::settings.flag_maiden_voyage || Lifeograph::p->m_flag_force_welcome )
-        draw_welcomescreen();
-    else
-        draw_loginscreen();
+    try
+    {
+        m_view_login = new ViewLogin;
+        m_view_login->handle_start();
+    }
+    catch( ... )
+    {
+        throw LIFEO::Error( "Failed to create the login view" );
+    }
 }
 
 AppWindow::~AppWindow()
@@ -84,7 +97,18 @@ AppWindow::~AppWindow()
 bool
 AppWindow::on_event( GdkEvent* )
 {
-    Lifeograph::p->handle_event();
+    if( !m_auto_logout_status )
+    {
+        // restart
+        m_seconds_remaining = Lifeograph::settings.idletime;
+        m_connection_timeout.disconnect();
+        m_connection_timeout = Glib::signal_timeout().connect_seconds(
+                sigc::mem_fun( this, &AppWindow::handle_idle ),
+                Lifeograph::settings.idletime - LOGOUT_COUNTDOWN );
+
+        update_auto_logout_count_down();
+    }
+
     return false;
 }
 
@@ -133,6 +157,89 @@ AppWindow::handle_redo()
     UndoManager::m->redo();
 }
 
+// AUTO LOGOUT SYSTEM
+bool
+AppWindow::handle_idle()
+{
+    if( m_auto_logout_status )
+        return false;
+
+    if( m_seconds_remaining > LOGOUT_COUNTDOWN )
+        m_seconds_remaining = LOGOUT_COUNTDOWN;
+    else
+        m_seconds_remaining--;
+
+    if( m_seconds_remaining > 0 )
+    {
+        m_connection_timeout = Glib::signal_timeout().connect_seconds(
+                sigc::mem_fun( this, &AppWindow::handle_idle ), 1 );
+
+        update_auto_logout_count_down();
+    }
+    else
+    {
+        update_auto_logout_count_down();
+
+        Lifeograph::loginstatus = Lifeograph::LOGGED_TIME_OUT;
+        logout( true );
+    }
+
+    return false;
+}
+
+void
+AppWindow::freeze_auto_logout()
+{
+    if( !m_auto_logout_status )
+    {
+        m_connection_timeout.disconnect();
+        m_seconds_remaining = Lifeograph::settings.idletime;
+        update_auto_logout_count_down();
+    }
+
+    m_auto_logout_status++;
+}
+
+void
+AppWindow::unfreeze_auto_logout()
+{
+    if( Lifeograph::settings.autologout && Diary::d->is_encrypted() &&
+        Lifeograph::loginstatus == Lifeograph::LOGGED_IN && m_auto_logout_status == 1 )
+    {
+        m_connection_timeout = Glib::signal_timeout().connect_seconds(
+                sigc::mem_fun( this, &AppWindow::handle_idle ),
+                Lifeograph::settings.idletime - LOGOUT_COUNTDOWN );
+    }
+
+    m_auto_logout_status--;
+}
+
+void
+AppWindow::update_auto_logout_count_down()
+{
+    static Gtk::Window* W_count_down( NULL );
+    static Gtk::Label* L_count_down( NULL );
+
+    if( m_seconds_remaining > 0  && m_seconds_remaining <= LOGOUT_COUNTDOWN )
+    {
+        if( W_count_down == NULL )
+        {
+            Lifeograph::builder->get_widget( "W_auto_logout", W_count_down );
+            Lifeograph::builder->get_widget( "L_auto_logout", L_count_down );
+
+            W_count_down->set_transient_for( *this );
+        }
+
+        L_count_down->set_label( Glib::ustring::compose(
+                _( "%1 SECONDS TO LOG OUT" ), m_seconds_remaining ) );
+
+        W_count_down->show();
+    }
+    else if( W_count_down )
+        W_count_down->hide();
+}
+
+// LOG OUT
 bool
 AppWindow::finish_editing( bool opt_save )
 {
@@ -207,7 +314,7 @@ AppWindow::finish_editing( bool opt_save )
     if( Lifeograph::loginstatus == Lifeograph::LOGGED_IN )
         Lifeograph::loginstatus = Lifeograph::LOGGED_OUT;
     Diary::d->clear();
-    Lifeograph::p->m_connection_timeout.disconnect();
+    m_connection_timeout.disconnect();
     m_connection_backup.disconnect();
     Lifeograph::m_internaloperation--;
 
@@ -217,9 +324,13 @@ AppWindow::finish_editing( bool opt_save )
 void
 AppWindow::logout( bool opt_save )
 {
+    panel_main->hide_popover(); // hide if is visible. necessary when logging out without saving
+
     Lifeograph::p->m_flag_open_directly = false;   // should be reset to prevent logging in again
     if( finish_editing( opt_save ) )
         m_view_login->handle_logout();
+
+    m_auto_logout_status = 1;
 }
 
 bool
@@ -254,7 +365,7 @@ AppWindow::get_element_row( const DiaryElement* element )
         case DiaryElement::ET_ENTRY:
         case DiaryElement::ET_CHAPTER:
         case DiaryElement::ET_TOPIC:
-        case DiaryElement::ET_TODO_GRP:
+        case DiaryElement::ET_GROUP:
             return( panel_diary->get_row( element->m_list_data->treepath ) );
 
         case DiaryElement::ET_TAG:
@@ -274,66 +385,12 @@ AppWindow::update_title()
     if( Lifeograph::loginstatus == Lifeograph::LOGGED_IN )
     {
         title += " - ";
-        title += Glib::filename_display_basename( Diary::d->get_path() );
-
-        if( Diary::d->is_read_only() )
-        {
-            title += " <";
-            title += "Read Only";
-            title += ">";
-        }
+        title += Diary::d->get_name();
     }
 
     set_title( title );
 }
 
-// MODE DRAWING FUNCTIONS
-void
-AppWindow::draw_welcomescreen()
-{
-    Gtk::Alignment* alignment = Gtk::manage( new Gtk::Alignment( 0.5, 0.5, 0.1, 0 ) );
-    Gtk::Label* label_salutation =
-            Gtk::manage( new Gtk::Label( _( STRING::SALUTATION ), 0.5, 0.5 ) );
-    Gtk::Button* button_start = Gtk::manage( new Gtk::Button( _("_Continue"), true ) );
-    Gtk::Image* icon_forward =
-            Gtk::manage( new Gtk::Image( Gtk::Stock::GO_FORWARD, Gtk::ICON_SIZE_MENU ) );
-    Gtk::Box* vbox = Gtk::manage( new Gtk::Box( Gtk::ORIENTATION_VERTICAL, 50 ) );
-
-    alignment->set_padding( 120, 120, 150, 150 );
-
-    label_salutation->set_use_markup( true );
-
-    button_start->set_image( *icon_forward );
-    button_start->set_image_position( Gtk::POS_RIGHT );
-
-    vbox->pack_start( *label_salutation );
-    vbox->pack_start( *button_start );
-
-    alignment->add( *vbox );
-    alignment->show_all();
-
-    button_start->signal_clicked().connect( sigc::mem_fun( *this, &AppWindow::draw_loginscreen ) );
-
-    add( *alignment );
-}
-
-void
-AppWindow::draw_loginscreen()
-{
-    // only to be called on start up
-    assert( m_view_login == NULL );
-
-    try
-    {
-        m_view_login = new ViewLogin;
-        m_view_login->handle_start();
-    }
-    catch( ... )
-    {
-        throw LIFEO::Error( "Failed to create the login view" );
-    }
-}
-
 void
 AppWindow::login()
 {
@@ -409,6 +466,10 @@ AppWindow::login()
                     Gdk::Pixbuf::create_from_file( ICONDIR "/todo_open-16.png" );
             Lifeograph::icons->todo_open_32 =
                     Gdk::Pixbuf::create_from_file( ICONDIR "/todo_open-32.png" );
+            Lifeograph::icons->todo_progressed_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_progressed-16.png" );
+            Lifeograph::icons->todo_progressed_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_progressed-32.png" );
             Lifeograph::icons->todo_done_16 =
                     Gdk::Pixbuf::create_from_file( ICONDIR "/todo_done-16.png" );
             Lifeograph::icons->todo_done_32 =
@@ -454,12 +515,12 @@ AppWindow::login()
         m_paned_entry->set_position( Lifeograph::settings.position_pane_tags );
 
         // ACTIONS
-        Lifeograph::create_action( true, m_action_undo,"Undo", Gtk::Stock::UNDO,
+        Lifeograph::create_action( true, m_action_undo,"Undo",
                        _( "Undo" ), "",     // this tooltip will be dynamic
                        Gtk::AccelKey( GDK_KEY_z, Gdk::CONTROL_MASK ),
                        sigc::mem_fun( *this, &AppWindow::handle_undo ) );
 
-        Lifeograph::create_action( true, m_action_redo, "Redo", Gtk::Stock::REDO,
+        Lifeograph::create_action( true, m_action_redo, "Redo",
                        _( "Redo" ), "",     // this tooltip will be dynamic
                        Gtk::AccelKey( GDK_KEY_z, Gdk::CONTROL_MASK | Gdk::SHIFT_MASK ),
                        sigc::mem_fun( *this, &AppWindow::handle_redo ) );
@@ -485,8 +546,13 @@ AppWindow::login()
     add( *m_paned_main );
 
     // LOGIN
+    // the following must come before handle_login()s
+    m_auto_logout_status = ( Lifeograph::settings.autologout && Diary::d->is_encrypted() ) ? 0 : 1;
+
     Lifeograph::m_internaloperation++;
 
+    panel_main->handle_login(); // must come before m_diary_view->handle_login() for header bar order
+    m_view_login->handle_login();
     m_tag_view->handle_login();
     m_filter_view->handle_login();
     m_entry_view->handle_login();
@@ -498,6 +564,6 @@ AppWindow::login()
     Lifeograph::m_internaloperation--;
 
     Lifeograph::loginstatus = Lifeograph::LOGGED_IN;
-    Lifeograph::p->m_flag_auto_logout_frozen = false;
+
     update_title();
 }
