@@ -24,6 +24,7 @@
 #include "lifeograph.hpp"
 #include "dialog_export.hpp"
 #include "dialog_password.hpp"
+#include "app_window.hpp"
 
 using namespace LIFEO;
 
@@ -34,6 +35,7 @@ DialogSaveGeneric::DialogSaveGeneric( const Glib::ustring& title )
     add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
     add_button( Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT );
     set_do_overwrite_confirmation( true );
+    set_transient_for( * AppWindow::p );
 }
 
 DialogSaveGeneric::DialogSaveGeneric( BaseObjectType* cobject,
@@ -90,6 +92,7 @@ DialogSaveDiary::launch( std::string& path, std::string& passphrase )
     if( ptr  == NULL )
         Lifeograph::builder->get_widget_derived( "FD_save", ptr );
 
+    ptr->set_transient_for( * AppWindow::p );
     ptr->set_current_folder( Glib::path_get_dirname( path ) );
     ptr->set_current_name( Glib::path_get_basename( path ) );
     ptr->m_check_encrypt->set_active( false );
@@ -151,6 +154,8 @@ DialogOpenDiary::DialogOpenDiary()
     signal_selection_changed().connect(
             sigc::mem_fun( this, &DialogOpenDiary::handle_selection_changed ) );
 
+    set_transient_for( * AppWindow::p );
+
     set_default_response( RESPONSE_EDIT );
 }
 
@@ -248,34 +253,38 @@ DialogImport::handle_diary_changed()
 
     m_diary = new Diary;
 
-    m_diary->set_path( m_file_chooser_button->get_filename(), false, true );
-
-    if( m_diary->read_header() == SUCCESS )
+    if( m_diary->set_path( m_file_chooser_button->get_filename(), Diary::SPT_READ_ONLY )
+            == SUCCESS )
     {
-        if( m_diary->is_encrypted() )
+        if( m_diary->read_header() == SUCCESS )
         {
-            DialogPassword::launch( DialogPassword::OT_OPEN, m_diary );
-            // TODO: do something if result != RESPONSE_GO
-        }
+            if( m_diary->is_encrypted() )
+            {
+                DialogPassword::launch( DialogPassword::OT_OPEN, m_diary );
+                // TODO: do something if result != RESPONSE_GO
+            }
 
-        Result result = m_diary->read_body();
-        if( result == SUCCESS )
-        {
-            set_ready();
-        }
-        else if( result == WRONG_PASSWORD )
-        {
-            set_not_ready( _( "Entered password is wrong; please try again" ) );
+            Result result = m_diary->read_body();
+            if( result == SUCCESS )
+            {
+                set_ready();
+            }
+            else if( result == WRONG_PASSWORD )
+            {
+                set_not_ready( _( "Entered password is wrong; please try again" ) );
+            }
+            else
+            {
+                set_not_ready( _( "Selected file cannot be read" ) );
+            }
         }
         else
         {
-            set_not_ready( _( "Selected file cannot be read" ) );
+            set_not_ready( _( "Selected file does not seem to be a valid diary" ) );
         }
     }
     else
-    {
-        set_not_ready( _( "Selected file does not seem to be a valid diary" ) );
-    }
+        set_not_ready( _( "Selected file cannot be read" ) );
 }
 
 void
