@@ -31,51 +31,25 @@
 
 namespace LIFEO
 {
+
 const char                      DB_FILE_HEADER[] = "LIFEOGRAPHDB";
-const int                       DB_FILE_VERSION_INT( 1011 );
-const int                       DB_FILE_VERSION_INT_MIN( 56 );
+const int                       DB_FILE_VERSION_INT( 1020 );
+const int                       DB_FILE_VERSION_INT_MIN( 110 );
 const std::string::size_type    PASSPHRASE_MIN_SIZE( 4 );
 const char                      LOCK_SUFFIX[] = ".~LOCK~";
 
 
-enum Result
-{
-    OK,
-    ABORTED,
-    SUCCESS,
-    FAILURE,
-    COULD_NOT_START,
-    COULD_NOT_FINISH,
-    WRONG_PASSWORD,
-    //APPARENTLY_ENCRYTED_FILE,
-    //APPARENTLY_PLAIN_FILE,
-    INCOMPATIBLE_FILE_OLD,
-    INCOMPATIBLE_FILE_NEW,
-    CORRUPT_FILE,
-    // EMPTY_DATABASE, // not used anymore
-    // VARIABLES USED BY set_path():
-    FILE_NOT_FOUND,
-    FILE_NOT_READABLE,
-    FILE_LOCKED
-};
-
-
-typedef PoolEntries::iterator               EntryIter;
-typedef PoolEntries::reverse_iterator       EntryIterReverse;
-typedef PoolEntries::const_iterator         EntryIterConst;
-typedef PoolEntries::const_reverse_iterator EntryIterConstRev;
-
-
-class Diary : public DiaryBase, public DiaryElement
+class Diary : public DiaryElement
 {
     public:
+        static ElementShower< Diary >* shower;
 
-        static ElementShower< Diary > *shower;
+        enum SetPathType { SPT_NORMAL, SPT_READ_ONLY, SPT_NEW };
 
                                 Diary();
                                 ~Diary();
 
-        static Diary            *d;
+        static Diary*           d;
 
         bool	                is_old()
         { return( m_read_version < DB_FILE_VERSION_INT ); }
@@ -105,7 +79,7 @@ class Diary : public DiaryBase, public DiaryElement
         Glib::ustring           get_list_str() const
         { return Glib::ustring::compose( "<b>%1</b>", Glib::Markup::escape_text( m_name ) ); }
 
-        LIFEO::Result           set_path( const std::string&, bool, bool = false );
+        LIFEO::Result           set_path( const std::string&, SetPathType );
         const std::string&	    get_path() const;
         bool                    is_path_set() const;
 
@@ -125,28 +99,47 @@ class Diary : public DiaryBase, public DiaryElement
         DiaryElement*           get_prev_session_elem() const;
         void                    set_last_elem( const DiaryElement* );
 
-        Entry*                  get_entry( const Date::date_t );
-        EntryVector*            get_entries( Date::date_t );
-        PoolEntries&	        get_entries()
-        { return m_entries; }
-        bool                    get_day_has_multiple_entries( const Date& );
-        Entry*                  get_entry_today();
-        Entry*                  get_entry_next_in_day( const Date& );
-        Entry*                  get_entry_first();
-        void                    set_entry_date( Entry*, const Date& );
-
-        bool                    is_first( const Entry * const ) const;
-        bool                    is_last( const Entry * const ) const;
+        bool                    is_first( const Entry* const ) const;
+        bool                    is_last( const Entry* const ) const;
         SortingCriteria	        get_sorting_criteria() const
         { return m_option_sorting_criteria; }
         void	                set_sorting_criteria( SortingCriteria sc )
         { m_option_sorting_criteria = sc; }
 
+        std::string             get_lang() const { return m_language; }
+        void                    set_lang( const std::string& lang ) { m_language = lang; }
+
+        DEID                    create_new_id( DiaryElement* element )
+        {
+            DEID retval;
+            if( m_force_id == DEID_UNSET )
+                retval = m_current_id;
+            else
+            {
+                retval = m_force_id;
+                m_force_id = DEID_UNSET;
+            }
+            m_ids[ retval ] = element;
+
+            while( m_ids.find( m_current_id ) != m_ids.end() )
+                m_current_id++;
+
+            return retval;
+        }
+        void                    erase_id( DEID id ) { m_ids.erase( id ); }
+        bool                    set_force_id( DEID id )
+        {
+            if( m_ids.find( id ) != m_ids.end() || id <= DEID_DIARY )
+                return false;
+            m_force_id = id;
+            return true;
+        }
+
         // FILTERING
         void                    set_search_text( const Glib::ustring& );
         Glib::ustring	        get_search_text() const
         { return m_search_text; }
-        bool                    is_search_active()
+        bool                    is_search_active() const
         { return( m_search_text.empty() == false ); }
         int                     replace_text( const Glib::ustring& );
 
@@ -154,7 +147,7 @@ class Diary : public DiaryBase, public DiaryElement
         { return m_filter_active; }
         Filter*                 get_filter_default()
         { return m_filter_default; }
-        void                    set_filter_tag( const Tag *tag )
+        void                    set_filter_tag( const Tag* tag )
         { m_filter_active->set_tag( tag ); }
         const Tag*              get_filter_tag() const
         { return m_filter_active->get_tag(); }
@@ -170,13 +163,24 @@ class Diary : public DiaryBase, public DiaryElement
         ElemStatus              get_filter_status() const
         { return m_filter_active->get_status(); }
 
+        // ENTRIES
+        Entry*                  get_entry( const Date::date_t, bool=false );
+        EntryVector*            get_entries( Date::date_t );
+        PoolEntries&            get_entries()
+        { return m_entries; }
+        bool                    get_day_has_multiple_entries( const Date& );
+        Entry*                  get_entry_today();
+        Entry*                  get_entry_next_in_day( const Date& );
+        Entry*                  get_entry_first();
+        void                    set_entry_date( Entry*, const Date& );
         Entry*                  create_entry( Date::date_t, const Glib::ustring& = "",
                                               bool = false );
         // adds a new entry to today even if there is already one or more:
         Entry*                  add_today();
         virtual bool            dismiss_entry( Entry* );
-        int                     list_entries();
+        bool                    make_free_entry_order( Date& ) const;
 
+        // TAGS
         PoolTags*               get_tags()
         { return &m_tags; }
         CategoryTags*           create_tag_ctg();
@@ -184,29 +188,32 @@ class Diary : public DiaryBase, public DiaryElement
         void                    dismiss_tag_ctg( CategoryTags*, bool = false );
         Tag*                    create_tag( const Glib::ustring&, CategoryTags* = NULL );
         void                    dismiss_tag( Tag*, bool = false );
+        Untagged*               get_untagged()
+        { return &m_untagged; }
 
-    const PoolCategoriesChapters*
-                                get_chapter_ctgs() const
-        { return &m_chapter_categories; }
-        CategoryChapters*	    get_current_chapter_ctg()
+        // CHAPTERS
+        CategoryChapters*       get_current_chapter_ctg()
         { return m_ptr2chapter_ctg_cur; }
+        void                    set_current_chapter_ctg( CategoryChapters* ctg )
+        {
+            m_ptr2chapter_ctg_cur = ctg;
+            update_entries_in_chapters();
+        }
         CategoryChapters*       create_chapter_ctg();
         CategoryChapters*       create_chapter_ctg( const Glib::ustring& );
         void                    dismiss_chapter_ctg( CategoryChapters* );
         bool                    rename_chapter_ctg( CategoryChapters*, const Glib::ustring& );
         void                    dismiss_chapter( Chapter*, bool = false );
-        const CategoryChapters* get_topics()
-        { return &m_topics; }
-        const CategoryChapters* get_todo_groups()
-        { return &m_todo_groups; }
-        Chapter*                add_topic( const Glib::ustring& );
-        Chapter*                add_todo_group( const Glib::ustring& );
+        CategoryChapters*       get_topics()
+        { return m_topics; }
+        CategoryChapters*       get_groups()
+        { return m_groups; }
+        void                    update_entries_in_chapters();
+        void                    add_entry_to_related_chapter( Entry* );
+        void                    remove_entry_from_chapters( Entry* );
         void                    set_topic_order( Chapter*, Date::date_t );
 
-        Date                    get_free_chapter_order_temporal();
-        Date                    get_free_chapter_order_ordinal();
-
-        bool                    make_free_entry_order( Date& );
+        //Date                    get_free_chapter_order_temporal();
 
         bool                    is_encrypted() const
         { return( ! m_passphrase.empty() ); }
@@ -217,26 +224,25 @@ class Diary : public DiaryBase, public DiaryElement
         bool                    import_entries( const Diary&, bool, const Glib::ustring& );
         bool                    import_chapters( const Diary& );
 
-        Untagged*               get_untagged()
-        { return &m_untagged; }
-
         static bool             s_flag_ignore_locks;
 
     protected:
         std::string             m_path;
         std::string             m_passphrase;
-        // content
-        PoolEntries	            m_entries;
+        // CONTENT
+        PoolEntries             m_entries;
+        Untagged                m_untagged; // pseudo tag "untagged"
         PoolTags                m_tags;
         PoolCategoriesTags      m_tag_categories;
         PoolCategoriesChapters	m_chapter_categories;
         CategoryChapters*       m_ptr2chapter_ctg_cur;
-        CategoryChapters        m_topics;   // ordinal chapters
-        CategoryChapters        m_todo_groups;
+        CategoryChapters*       m_topics; // ordinal chapters
+        CategoryChapters*       m_groups; // chapters with invisible order
+        Chapter                 m_orphans; // entries that remain out of defined chapters
 
         DEID                    m_startup_elem_id;
         DEID                    m_last_elem_id;
-        // options & flags
+        // OPTIONS & FLAGS
         SortingCriteria	        m_option_sorting_criteria;
         int                     m_read_version;
         bool                    m_flag_only_save_filtered;
@@ -247,16 +253,23 @@ class Diary : public DiaryBase, public DiaryElement
         Filter*                 m_filter_default;
         // TODO FilterVector            m_filters;  // user defined filters
 
-        // pseudo tag "untagged":
-        Untagged                m_untagged;
+        // BASE
+        DEID                    m_current_id;
+        DEID                    m_force_id;
+        PoolDEIDs               m_ids;
+        std::string             m_language;
+
+        LIFEO::Result           parse_db_body_text( std::istream& );
+        LIFEO::Result           parse_db_body_text_1020( std::istream& );
+        LIFEO::Result           parse_db_body_text_1010( std::istream& );
+        LIFEO::Result           parse_db_body_text_110( std::istream& );
+        void                    do_standard_checks_after_parse();
 
-        void                    create_db_tag_text( char, const Tag*, std::stringstream& );
-        LIFEO::Result           parse_db_body_text( std::stringstream& );
-        LIFEO::Result           parse_db_body_text_1010( std::stringstream& );
-        LIFEO::Result           parse_db_body_text_110( std::stringstream& );
-        LIFEO::Result           parse_db_body_text_56( std::stringstream& );
         bool                    create_db_body_text( std::stringstream& );
         bool                    create_db_header_text( std::stringstream&, bool );
+        void                    create_db_tag_text( char, const Tag*, std::stringstream& );
+
+        void                    close_file();
         LIFEO::Result           read_plain();
         LIFEO::Result           read_encrypted();
         LIFEO::Result           write_plain( const std::string&, bool = false );
@@ -265,7 +278,7 @@ class Diary : public DiaryBase, public DiaryElement
         bool                    remove_lock();
 
     private:
-        std::ios::pos_type      m_body_position;
+        std::ifstream*          m_ifstream;
 
     friend class EntryView;
     friend class DiaryView;
