@@ -52,24 +52,55 @@ LIFEO::compare_names( const Glib::ustring& name_l, const Glib::ustring& name_r )
 ListData::Colrec*                   ListData::colrec;
 bool                                DiaryElement::FLAG_ALLOCATE_GUI_FOR_DIARY = true;
 const Glib::RefPtr< Gdk::Pixbuf >   DiaryElement::s_pixbuf_null;
+const Glib::ustring DiaryElement::s_type_names[] =
+{   "", _( "Tag" ), _( "Untagged" ), _( "Tag Category" ), _( "Chapter Category" ),
+    // TRANSLATORS: filter is a noun here
+    _( "Filter" ),
+    _( "Diary" ), _( "Dated Chapter" ), _( "Numbered Chapter" ),
+    _( "Free Chapter" ), _( "Entry" ), "Multiple Entries", "", ""
+};
 
-DiaryElement::DiaryElement( DiaryBase* const ptr2diary,
-                            ElemStatus status,
-                            const Glib::ustring &name )
+DiaryElement::DiaryElement()
+:   NamedElement( "" ), m_list_data( NULL ), m_ptr2diary( NULL ), m_id( DEID_UNSET ),
+    m_status( ES::VOID )
+{
+}
+DiaryElement::DiaryElement( Diary* const ptr2diary,
+                            const Glib::ustring& name,
+                            ElemStatus status )
 :   NamedElement( name ), m_ptr2diary( ptr2diary ),
-    m_id( ptr2diary ? ptr2diary->create_new_id( this ) : DEID_UNSET ), m_status( status )
+    m_id( ptr2diary ? ptr2diary->create_new_id( this ) :  DEID_UNSET ),
+    m_status( status )
+{
+    if( FLAG_ALLOCATE_GUI_FOR_DIARY )
+        m_list_data = new ListData;
+}
+DiaryElement::DiaryElement( Diary* const ptr2diary, DEID id, ElemStatus status )
+:   NamedElement( "" ), m_ptr2diary( ptr2diary ), m_id( id ), m_status( status )
 {
     if( FLAG_ALLOCATE_GUI_FOR_DIARY )
         m_list_data = new ListData;
 }
 
+DiaryElement::~DiaryElement()
+{
+    if( m_ptr2diary != NULL )
+        m_ptr2diary->erase_id( m_id );
+}
+
+void
+DiaryElement::set_todo_status( ElemStatus s )
+{
+    m_status -= ( m_status & ES::FILTER_TODO );
+    m_status |= s;
+}
 
 // TAG =============================================================================================
 // STATIC MEMBERS
 ElementShower< Tag >* Tag::shower( NULL );
 
-Tag::Tag( DiaryBase* const d, const Glib::ustring& name, CategoryTags* category )
-:   DiaryElementContainer( d, name ), m_ptr2category( category ), m_theme( NULL )
+Tag::Tag( Diary* const d, const Glib::ustring& name, CategoryTags* category )
+:   DiaryElementReferrer( d, name, ES::VOID ), m_ptr2category( category ), m_theme( NULL )
 {
     if( category != NULL )
         category->insert( this );
@@ -126,13 +157,11 @@ Tag::get_own_theme()
 {
     if( m_theme == NULL )
     {
-        m_theme = new Theme( ThemeSystem::get() );
+        m_theme = new Theme;
 
-        for( SetDiaryElements::const_iterator iter = m_items.begin();
-             iter != m_items.end();
-             ++iter )
+        for( Set::iterator iter = begin(); iter != end(); ++iter )
         {
-            Entry* entry = dynamic_cast< Entry* >( * iter );
+            Entry* entry = *iter;
             entry->update_theme();
         }
     }
@@ -148,11 +177,9 @@ Tag::create_own_theme_duplicating( const Theme* theme )
 
     m_theme = new Theme( theme );
 
-    for( SetDiaryElements::const_iterator iter = m_items.begin();
-         iter != m_items.end();
-         ++iter )
+    for( Set::iterator iter = begin(); iter != end(); ++iter )
     {
-        Entry* entry = dynamic_cast< Entry* >( * iter );
+        Entry* entry = *iter;
         entry->update_theme();
     }
 
@@ -167,11 +194,9 @@ Tag::reset_theme()
         delete m_theme;
         m_theme = NULL;
 
-        for( SetDiaryElements::const_iterator iter = m_items.begin();
-             iter != m_items.end();
-             ++iter )
+        for( Set::const_iterator iter = begin(); iter != end(); ++iter )
         {
-            Entry* entry = dynamic_cast< Entry* >( * iter );
+            Entry* entry = *iter;
             entry->update_theme();
         }
     }
@@ -250,9 +275,8 @@ PoolTags::clear()
 // STATIC MEMBERS
 ElementShower< CategoryTags >* CategoryTags::shower( NULL );
 
-CategoryTags::CategoryTags( DiaryBase* const d, const Glib::ustring& name )
-:   DiaryElement( d, ES::EXPANDED, name ),
-    std::set< Tag*, FuncCompareDiaryElemNamed >( compare_listitems_by_name )
+CategoryTags::CategoryTags( Diary* const d, const Glib::ustring& name )
+:   DiaryElementReferrer( d, name, ES::EXPANDED, compare_listitems_by_name )
 {
 }
 
@@ -353,14 +377,8 @@ Tagset::get_tag( unsigned int tagorder ) const
 // STATIC MEMBERS
 ElementShower< Chapter >* Chapter::shower( NULL );
 
-Chapter::Chapter( DiaryBase* const d, const Glib::ustring& name )
-:   DiaryElement( d, ES::TODO, name ), m_date_begin( Date::NOTSET ), m_time_span( 0 ), m_size( 0 ),
-    m_type( ET_CHAPTER )
-{
-}
-
-Chapter::Chapter( DiaryBase* const d, const Glib::ustring& name, Date date )
-:   DiaryElement( d, ES::TODO, name ), m_date_begin( date ), m_size( 0 )
+Chapter::Chapter( Diary* const d, const Glib::ustring& name, Date::date_t date )
+:   DiaryElementReferrer( d, name, ES::CHAPTER_DEFAULT ), m_date_begin( date ), m_time_span( 0 )
 {
     update_type();
 }
@@ -368,36 +386,49 @@ Chapter::Chapter( DiaryBase* const d, const Glib::ustring& name, Date date )
 const Glib::RefPtr< Gdk::Pixbuf >&
 Chapter::get_icon() const
 {
-    if( m_date_begin.is_todo() )
-        switch( m_status & ES::FILTER_TODO )
-        {
-            case ES::TODO:
-                return Lifeograph::icons->todo_open_16;
-            case ES::DONE:
-                return Lifeograph::icons->todo_done_16;
-            case ES::CANCELED:
-                return Lifeograph::icons->todo_canceled_16;
-        }
-
-    return( m_date_begin.is_ordinal() ?
-            Lifeograph::icons->chapter_16 : Lifeograph::icons->month_16 );
+    switch( m_status & ES::FILTER_TODO )
+    {
+        case ES::TODO:
+            return Lifeograph::icons->todo_open_16;
+        case ES::PROGRESSED:
+            return Lifeograph::icons->todo_progressed_16;
+        case ES::DONE:
+            return Lifeograph::icons->todo_done_16;
+        case ES::CANCELED:
+            return Lifeograph::icons->todo_canceled_16;
+        default:
+            return( m_date_begin.is_ordinal() ?
+                    Lifeograph::icons->chapter_16 : Lifeograph::icons->month_16 );
+    }
 }
 const Glib::RefPtr< Gdk::Pixbuf >&
 Chapter::get_icon32() const
 {
-    if( m_date_begin.is_todo() )
-            switch( m_status & ES::FILTER_TODO )
-            {
-                case ES::TODO:
-                    return Lifeograph::icons->todo_open_32;
-                case ES::DONE:
-                    return Lifeograph::icons->todo_done_32;
-                case ES::CANCELED:
-                    return Lifeograph::icons->todo_canceled_32;
-            }
+    switch( m_status & ES::FILTER_TODO )
+    {
+        case ES::TODO:
+            return Lifeograph::icons->todo_open_32;
+        case ES::PROGRESSED:
+            return Lifeograph::icons->todo_progressed_32;
+        case ES::DONE:
+            return Lifeograph::icons->todo_done_32;
+        case ES::CANCELED:
+            return Lifeograph::icons->todo_canceled_32;
+        default:
+            return( m_date_begin.is_ordinal() ?
+                    Lifeograph::icons->chapter_32 : Lifeograph::icons->month_32 );
+    }
 
-    return( m_date_begin.is_ordinal() ?
-                Lifeograph::icons->chapter_32 : Lifeograph::icons->month_32 );
+}
+
+Glib::ustring
+Chapter::get_list_str() const
+{
+    if( m_date_begin.is_hidden() )
+        return Glib::ustring::compose( "<b>%1</b>", Glib::Markup::escape_text( m_name ) );
+//    else
+        return Glib::ustring::compose( "<b>%1 -  %2</b>", m_date_begin.format_string(),
+                    Glib::Markup::escape_text( m_name ) );
 }
 
 void
@@ -419,10 +450,7 @@ Chapter::set_name( const Glib::ustring& name )
 Glib::ustring
 Chapter::get_date_str() const
 {
-    if( is_initialized() )
-        return m_date_begin.format_string();
-    else
-        return "";
+    return m_date_begin.format_string();
 }
 
 Date
@@ -434,8 +462,8 @@ Chapter::get_date() const
 void
 Chapter::update_type()
 {
-    if( m_date_begin.is_todo() )
-        m_type = ET_TODO_GRP;
+    if( m_date_begin.is_hidden() )
+        m_type = ET_GROUP;
     else if( m_date_begin.is_ordinal() )
         m_type = ET_TOPIC;
     else
@@ -462,9 +490,16 @@ Chapter::recalculate_span( const Chapter* next )
 }
 
 // CHAPTER CATEGORY ================================================================================
-CategoryChapters::CategoryChapters( DiaryBase* const d, const Glib::ustring& name )
-:   DiaryElement( d, ES::VOID, name ),
-    std::map< Date::date_t, Chapter*, FuncCompareDates >( compare_dates )
+CategoryChapters::CategoryChapters( Diary* const d, const Glib::ustring& name )
+:   DiaryElement( d, name ),
+    std::map< Date::date_t, Chapter*, FuncCompareDates >( compare_dates ),
+    m_date_min( 0 )
+{
+}
+CategoryChapters::CategoryChapters( Diary* const d, Date::date_t date_min )
+:   DiaryElement( d, DEID_UNSET ),
+    std::map< Date::date_t, Chapter*, FuncCompareDates >( compare_dates ),
+    m_date_min( date_min )
 {
 }
 
@@ -484,40 +519,16 @@ CategoryChapters::get_chapter( const Date::date_t date ) const
 Chapter*
 CategoryChapters::create_chapter( const Glib::ustring& name, const Date& date )
 {
-    Chapter* chapter = new Chapter( m_ptr2diary, name, date );
+    Chapter* chapter = new Chapter( m_ptr2diary, name, date.m_date );
 
     add( chapter );
 
     return chapter;
 }
-
-void
-CategoryChapters::dismiss_chapter( Chapter* chapter )
+Chapter*
+CategoryChapters::create_chapter_ordinal( const Glib::ustring& name )
 {
-    iterator iter( find( chapter->m_date_begin.m_date ) );
-    if( iter == end() )
-    {
-        print_error( "chapter could not be found in assumed category" );
-        return;
-    }
-    else if( ( ++iter ) != end() )  // fix time span
-    {
-        Chapter *chapter_earlier( iter->second );
-        if( chapter->m_time_span > 0 )
-            chapter_earlier->m_time_span += chapter->m_time_span;
-        else
-            chapter_earlier->m_time_span = 0;
-    }
-    erase( chapter->m_date_begin.m_date );
-    delete chapter;
-}
-
-bool
-CategoryChapters::rename_chapter( Chapter* chapter, const Glib::ustring& name )
-{
-    // Chapters must have unique begin dates not names
-    chapter->set_name( name );
-    return true;
+    return create_chapter( name, get_free_order_ordinal() );
 }
 
 bool
@@ -525,7 +536,7 @@ CategoryChapters::set_chapter_date( Chapter* chapter, Date::date_t date )
 {
     assert( chapter->is_ordinal() == false );
 
-    if( chapter->m_date_begin.m_date != Date::NOTSET )
+    if( chapter->m_date_begin.m_date != Date::NOT_SET )
     {
         iterator iter( find( chapter->m_date_begin.m_date ) );
         if( iter == end() )
@@ -544,8 +555,9 @@ CategoryChapters::set_chapter_date( Chapter* chapter, Date::date_t date )
 
         if( find( date ) != end() ) // if target is taken move chapters
         {
+            // FIXME "chapter->m_date_begin.is_ordinal() ?" conflicts with the assertion above:
             Date::date_t d( chapter->m_date_begin.is_ordinal() ?
-                            chapter->m_date_begin.m_date : get_free_order().m_date );
+                            chapter->m_date_begin.m_date : get_free_order_ordinal().m_date );
                             // if a temporal chapter is being converted..
                             // ..assume that it was the last
             Date::date_t step( chapter->m_date_begin.m_date > date ?
@@ -607,19 +619,17 @@ CategoryChapters::clear()
 }
 
 Date
-CategoryChapters::get_free_order() const
+CategoryChapters::get_free_order_ordinal() const
 {
-    if( size() > 0 )
-    {
-        Date d( begin()->first );
-        if( d.is_ordinal() )
-        {
-            d.forward_ordinal_order();
-            return d;
-        }
-    }
+    assert( m_date_min );   // only for ordinal chapter categories
+
+    if( empty() )
+        return Date( m_date_min );
+
+    Date d( begin()->first );
+    d.forward_ordinal_order();
+    return d;
 
-    return Date( 0, 0 );
 }
 
 PoolCategoriesChapters::~PoolCategoriesChapters()
@@ -639,20 +649,14 @@ PoolCategoriesChapters::clear()
 
 // THEMES ==========================================================================================
 // STATIC MEMBERS
-const Gdk::RGBA Theme::s_color_match( "#33FF33" );
+const Gdk::RGBA Theme::s_color_match1( "#33FF33" );
 const Gdk::RGBA Theme::s_color_match2( "#009900" );
-const Gdk::RGBA Theme::s_color_link( "#3333FF" );
+const Gdk::RGBA Theme::s_color_link1( "#3333FF" );
 const Gdk::RGBA Theme::s_color_link2( "#000099" );
-const Gdk::RGBA Theme::s_color_broken( "#FF3333" );
+const Gdk::RGBA Theme::s_color_broken1( "#FF3333" );
 const Gdk::RGBA Theme::s_color_broken2( "#990000" );
 
 Theme::Theme()
-:   font( ThemeSystem::get()->font ),
-    color_base( ThemeSystem::get()->color_base ),
-    color_text( ThemeSystem::get()->color_text ),
-    color_heading( ThemeSystem::get()->color_heading ),
-    color_subheading( ThemeSystem::get()->color_subheading ),
-    color_highlight( ThemeSystem::get()->color_highlight )
 {
 }
 
@@ -716,8 +720,8 @@ ThemeSystem::get()
 // FILTERS =========================================================================================
 ElementShower< Filter >* Filter::shower( NULL );
 
-Filter::Filter( DiaryBase* const d, const Glib::ustring& name )
-:   DiaryElement( d, ES::FILTER_DEFAULT, name ), m_tag( NULL ),
+Filter::Filter( Diary* const d, const Glib::ustring& name )
+:   DiaryElement( d, name, ES::FILTER_RESET ), m_tag( NULL ),
     m_date_begin( 0 ), m_date_end( Date::DATE_MAX )
 {
 }
@@ -746,7 +750,7 @@ Filter::show()
 void
 Filter::reset()
 {
-    m_status = ES::FILTER_DEFAULT;
+    m_status = ES::FILTER_RESET;
     m_tag = NULL;
     m_date_begin = 0;
     m_date_end = Date::DATE_MAX;
@@ -780,7 +784,7 @@ void
 Filter::set_favorites( bool flag_show_fav, bool flag_show_not_fav )
 {
     // clear previous values
-    m_status &= ( ES::FILTER_FAVORED ^ ES::FILTER_MAX ); // or ( ~ES::FILTER_FAVORED )
+    m_status &= ( ES::FILTER_FAVORED ^ ES::FILTER_MAX );
 
     if( flag_show_fav )
         m_status |= ES::SHOW_FAVORED;
@@ -805,13 +809,18 @@ Filter::set_trash( bool flag_show_trashed, bool flag_show_not_trashed )
 }
 
 void
-Filter::set_todo( bool flag_show_todo, bool flag_show_done, bool flag_show_canceled )
+Filter::set_todo( bool flag_show_not_todo, bool flag_show_todo,
+                  bool flag_show_progressed, bool flag_show_done, bool flag_show_canceled )
 {
     // clear previous values
     m_status &= ( ES::FILTER_TODO ^ ES::FILTER_MAX );
 
+    if( flag_show_not_todo )
+        m_status |= ES::SHOW_NOT_TODO;
     if( flag_show_todo )
         m_status |= ES::SHOW_TODO;
+    if( flag_show_progressed )
+        m_status |= ES::SHOW_PROGRESSED;
     if( flag_show_done )
         m_status |= ES::SHOW_DONE;
     if( flag_show_canceled )
