@@ -41,7 +41,8 @@ static const SortingCriteria SC_SIZE    = 's';
 static const SortingCriteria SC_CHANGE  = 'c';  // last change date
 
 typedef unsigned long DEID; // unique diary element id
-static const DEID DEID_MIN = 10000;         // reserved for Diary itself
+static const DEID DEID_DIARY = 10000;       // reserved for Diary
+static const DEID DEID_FIRST = 10001;       // first sub item in the diary
 static const DEID DEID_UNSET = 404;         // :)
 static const DEID HOME_CURRENT_ELEM = 1;    // element shown at startup
 static const DEID HOME_LAST_ELEM = 2;       // element shown at startup
@@ -59,20 +60,25 @@ namespace ES
     static const ElemStatus NOT_TRASHED      = 0x400;
     static const ElemStatus TRASHED          = 0x800;
     static const ElemStatus FILTER_TRASHED   = NOT_TRASHED|TRASHED;
-    static const ElemStatus TODO             = 0x1000;
-    static const ElemStatus DONE             = 0x2000;
-    static const ElemStatus CANCELED         = 0x4000;
-    static const ElemStatus FILTER_TODO      = TODO|DONE|CANCELED;
+    static const ElemStatus NOT_TODO         = 0x1000;
+    static const ElemStatus TODO             = 0x2000;
+    static const ElemStatus PROGRESSED       = 0x4000;
+    static const ElemStatus DONE             = 0x8000;
+    static const ElemStatus CANCELED         = 0x10000;
+    static const ElemStatus FILTER_TODO      = NOT_TODO|TODO|PROGRESSED|DONE|CANCELED;
 
-    static const ElemStatus DEFAULT          = NOT_FAVORED|NOT_TRASHED|TODO;
-    static const ElemStatus DEFAULT_FAVORED  = FAVORED|NOT_TRASHED|TODO;
+    static const ElemStatus ENTRY_DEFAULT       = NOT_FAVORED|NOT_TRASHED|NOT_TODO;
+    static const ElemStatus ENTRY_DEFAULT_FAV   = FAVORED|NOT_TRASHED|NOT_TODO;
+    static const ElemStatus CHAPTER_DEFAULT     = EXPANDED|NOT_TODO;
 
     // FILTER RELATED CONSTANTS AND ALIASES
     static const ElemStatus SHOW_NOT_FAVORED    = NOT_FAVORED;
     static const ElemStatus SHOW_FAVORED        = FAVORED;
     static const ElemStatus SHOW_NOT_TRASHED    = NOT_TRASHED;
     static const ElemStatus SHOW_TRASHED        = TRASHED;
+    static const ElemStatus SHOW_NOT_TODO       = NOT_TODO;
     static const ElemStatus SHOW_TODO           = TODO;
+    static const ElemStatus SHOW_PROGRESSED     = PROGRESSED;
     static const ElemStatus SHOW_DONE           = DONE;
     static const ElemStatus SHOW_CANCELED       = CANCELED;
 
@@ -80,17 +86,22 @@ namespace ES
     static const ElemStatus FILTER_DATE_BEGIN   = 0x200000;
     static const ElemStatus FILTER_DATE_END     = 0x400000;
     static const ElemStatus FILTER_INDIVIDUAL   = 0x800000;
-    static const ElemStatus FILTER_OUTSTANDING  = 0x10000000;
+    static const ElemStatus FILTER_OUTSTANDING  = 0x20000000;
 
-    static const ElemStatus FILTERED_OUT        = 0x80000000;
+    static const ElemStatus FILTERED_OUT        = 0x40000000;
 
-    static const ElemStatus FILTER_DEFAULT      = FILTER_FAVORED|SHOW_NOT_TRASHED|SHOW_TODO;
-    static const ElemStatus FILTER_MAX          = 0xFFFFFFFF;
+    static const ElemStatus FILTER_RESET        = FILTER_FAVORED|SHOW_NOT_TRASHED|SHOW_NOT_TODO|
+                                                  SHOW_TODO|SHOW_PROGRESSED|FILTER_OUTSTANDING;
+    static const ElemStatus FILTER_MAX          = 0x7FFFFFFF;
+    // to go parallel with Java version 0x7FFFFFFF is the max
 }
 
 class DiaryElement;     // forward declaration
 class Untagged;         // forward declaration
-class Entry;            // forward decleration
+class Entry;            // forward declaration
+class Filter;           // forward declaration
+class Diary;            // forward declaration
+class ListData;	        // forward declaration
 
 typedef std::vector< Entry* >               EntryVector;
 typedef std::vector< Entry* >::iterator     EntryVectorIter;
@@ -98,67 +109,7 @@ typedef std::vector< Entry* >::iterator     EntryVectorIter;
 typedef std::set< Entry* >                  EntrySet;
 typedef std::set< Entry* >::iterator        EntrySetIter;
 
-
-// DIARYBASE (FOR COMMUNICATION)
-class DiaryBase
-{
-    public:
-        typedef std::map< DEID, DiaryElement* >
-                                    PoolDEIDs;
-
-                                    DiaryBase()
-        :   m_current_id( DEID_MIN ), m_force_id( DEID_UNSET ), m_language( "" ) {}
-        virtual                     ~DiaryBase() {}
-
-        DEID                        create_new_id( DiaryElement *element )
-        {
-            DEID retval;
-            if( m_force_id == DEID_UNSET )
-                retval = m_current_id;
-            else
-            {
-                retval = m_force_id;
-                m_force_id = DEID_UNSET;
-            }
-            m_ids[ retval ] = element;
-
-            while( m_ids.find( m_current_id ) != m_ids.end() )
-                m_current_id++;
-
-            return retval;
-        }
-        void                        erase_id( DEID id ) { m_ids.erase( id ); }
-        bool                        set_force_id( DEID id )
-        {
-            if( m_ids.find( id ) != m_ids.end() || id <= DEID_MIN )
-                return false;
-            m_force_id = id;
-            return true;
-        }
-
-        void                        clear()
-        {
-            m_force_id = DEID_UNSET;
-            m_current_id = DEID_MIN;
-            m_ids.clear();
-        }
-
-        virtual bool                make_free_entry_order( Date& ) = 0;
-
-        std::string                 get_lang() const { return m_language; }
-        void                        set_lang( const std::string &lang ) { m_language = lang; }
-
-        virtual Untagged*           get_untagged() = 0;
-
-    protected:
-        DEID                        m_current_id;
-        DEID                        m_force_id;
-        PoolDEIDs                   m_ids;
-        std::string                 m_language;
-};
-
-
-class ListData;	// forward declaration
+typedef std::map< DEID, DiaryElement* >     PoolDEIDs;
 
 // DIARYELEMENT ====================================================================================
 class NamedElement
@@ -185,35 +136,38 @@ class DiaryElement : public NamedElement
         static bool             FLAG_ALLOCATE_GUI_FOR_DIARY;
         static const Glib::RefPtr< Gdk::Pixbuf >
                                 s_pixbuf_null;
+        static const Glib::ustring
+                                s_type_names[];
 
         enum Type
         {   // CAUTION: order is significant and shouldn't be changed!
+            // type_names above should follow the same order to work
             ET_NONE, ET_TAG, ET_UNTAGGED, ET_TAG_CTG, ET_CHAPTER_CTG, ET_FILTER,
             // entry list elements:
-            ET_DIARY, ET_CHAPTER, ET_TOPIC, ET_TODO_GRP, ET_ENTRY, ET_DATE,
+            ET_DIARY, ET_CHAPTER, ET_TOPIC, ET_GROUP, ET_ENTRY, ET_MULTIPLE_ENTRIES, ET_DATE,
             // special types for pseudo elements:
             ET_HEADER
         };
+                                DiaryElement(); // only for pseudo elements
+                                DiaryElement( Diary* const, const Glib::ustring&,
+                                              ElemStatus = ES::VOID );
+                                DiaryElement( Diary* const, DEID, ElemStatus = ES::VOID );
+        virtual                 ~DiaryElement();
 
-                                DiaryElement( DiaryBase* const,
-                                              ElemStatus,
-                                              const Glib::ustring& = "" );
-        virtual                 ~DiaryElement()
-        {
-            if( m_ptr2diary != NULL )
-                m_ptr2diary->erase_id( m_id );
-        }
-
-        virtual Date            get_date() const
-        { return Date( 0 ); }
-        virtual int             get_size() const = 0;
         virtual Type            get_type() const = 0;
+        Glib::ustring           get_type_name()
+        { return s_type_names[ get_type() ]; }
+        virtual int             get_size() const = 0;
         virtual const Glib::RefPtr< Gdk::Pixbuf >&
                                 get_icon() const
         { return( s_pixbuf_null ); }
         virtual const Glib::RefPtr< Gdk::Pixbuf >&
                                 get_icon32() const
         { return( s_pixbuf_null ); }
+        virtual Date            get_date() const
+        { return Date( Date::NOT_APPLICABLE ); }
+        Date::date_t            get_date_t() const
+        { return get_date().m_date; }
 
         virtual Glib::ustring   get_list_str() const
         { return ""; }
@@ -231,11 +185,27 @@ class DiaryElement : public NamedElement
         void                    set_status( ElemStatus status )
         { m_status = status; }
 
+        void                    set_status_flag( ElemStatus flag, bool add )
+        {
+            if( add )
+                m_status |= flag;
+            else if( m_status & flag )
+                m_status -= flag;
+        }
+
+        // only for entries and chapters:
+        ElemStatus              get_todo_status() const
+        { return( m_status & ES::FILTER_TODO ); }
+        void                    set_todo_status( ElemStatus );
+
+        virtual bool            is_favored() const
+        { return false; }
+
         ListData*               m_list_data;
 
-        DiaryBase* const        m_ptr2diary;
-
     protected:
+        Diary* const            m_ptr2diary;
+
         const DEID              m_id;
         ElemStatus              m_status;
 };
@@ -271,8 +241,6 @@ bool compare_names( const Glib::ustring&, const Glib::ustring& );
 
 typedef bool( *FuncCompareStrings )( const Glib::ustring&, const Glib::ustring& ) ;
 typedef bool( *FuncCompareDiaryElem )( DiaryElement*, DiaryElement* ) ;
-typedef bool( *FuncCompareDiaryElemNamed )( DiaryElement*, DiaryElement* ) ;
-typedef std::set< DiaryElement*, FuncCompareDiaryElem > SetDiaryElements;
 
 template< class T >
 Glib::ustring
@@ -295,15 +263,15 @@ create_unique_name_for_map( const std::map< Glib::ustring, T*, FuncCompareString
 class ElementShowerProto
 {
     public:
-        ElementShowerProto() : m_menu( NULL ) {}
+        ElementShowerProto() : m_grid_popover( NULL ) {}
         virtual             ~ElementShowerProto() {}
 
         virtual DiaryElement*   get_element() = 0;
 
         Gtk::Widget*            get_widget()
         { return m_vbox; }
-        virtual Gtk::Menu*      get_menu()
-        { return m_menu; }
+        virtual Gtk::Widget*    get_popover()
+        { return m_grid_popover; }
         virtual Gtk::Widget*    get_extra_tools()
         { return NULL; }
 
@@ -311,8 +279,6 @@ class ElementShowerProto
         { return ""; }
         virtual Glib::ustring   get_info_str() const
         { return ""; }
-        virtual Glib::ustring   get_tip_str() const
-        { return ""; }
 
         virtual bool            is_title_editable() const
         { return false; }
@@ -325,7 +291,7 @@ class ElementShowerProto
 
     protected:
         Gtk::Box*               m_vbox;
-        Gtk::Menu*              m_menu;
+        Gtk::Grid*              m_grid_popover;
 };
 
 template< class T >
@@ -344,26 +310,24 @@ class ElementShower : public ElementShowerProto
         T*                      m_ptr2elem;
 };
 
-class DiaryElementContainer : public DiaryElement
+template< typename T >
+class DiaryElementReferrer : public DiaryElement, public std::set< T*, FuncCompareDiaryElem >
 {
 // NOTE: this class and its derivatives are not responsible for handling of...
 // ...its children's allocation and deletion
     public:
-        DiaryElementContainer( DiaryBase* const d )
-        :   DiaryElement( d, ES::VOID ), m_items( compare_listitems ) {}
-        DiaryElementContainer( DiaryBase* const d, const Glib::ustring &name )
-        :   DiaryElement( d, ES::VOID, name ), m_items( compare_listitems ) {}
+        typedef std::set< T*, FuncCompareDiaryElem > Set;
+
+        DiaryElementReferrer( Diary* const d )
+        :   DiaryElement( d, "" ),
+            std::set< T*, FuncCompareDiaryElem >( compare_listitems ) {}
+        DiaryElementReferrer( Diary* const d, const Glib::ustring& name, ElemStatus es,
+                               FuncCompareDiaryElem f = compare_listitems )
+        :   DiaryElement( d, name, es ),
+            std::set< T*, FuncCompareDiaryElem >( f ) {}
 
-        SetDiaryElements*       get_items()
-        { return &m_items; }
         virtual int             get_size() const
-        { return m_items.size(); }
-
-        void                    clear()
-        { m_items.clear(); }
-
-    protected:
-        SetDiaryElements        m_items;
+        { return std::set< T*, FuncCompareDiaryElem >::size(); }
 };
 
 // THEME ===========================================================================================
@@ -393,11 +357,11 @@ class Theme
         Gdk::RGBA                   color_highlight;
 
         // CONSTANT COLORS
-        static const Gdk::RGBA      s_color_match;
+        static const Gdk::RGBA      s_color_match1;
         static const Gdk::RGBA      s_color_match2;
-        static const Gdk::RGBA      s_color_link;
+        static const Gdk::RGBA      s_color_link1;
         static const Gdk::RGBA      s_color_link2;
-        static const Gdk::RGBA      s_color_broken;
+        static const Gdk::RGBA      s_color_broken1;
         static const Gdk::RGBA      s_color_broken2;
 };
 
@@ -421,18 +385,15 @@ class ThemeSystem : public Theme
 class Tag;	// forward declaration
 
 // TAG CATEGORY
-// TODO: should be a DiaryElementContainer as it is not responsible for memory handling
-class CategoryTags : public DiaryElement, public std::set< Tag*, FuncCompareDiaryElemNamed >
+class CategoryTags : public DiaryElementReferrer< Tag >
 {
     public:
         static ElementShower< CategoryTags >* shower;
 
-                                CategoryTags( DiaryBase * const, const Glib::ustring& );
+                                CategoryTags( Diary* const, const Glib::ustring& );
 
         void                    show();
 
-        virtual int             get_size() const
-        { return size(); }
         Type                    get_type() const
         { return ET_TAG_CTG; }
         const Glib::RefPtr< Gdk::Pixbuf >&
@@ -446,12 +407,7 @@ class CategoryTags : public DiaryElement, public std::set< Tag*, FuncCompareDiar
         bool                    get_expanded() const
         { return( m_status & ES::EXPANDED ); }
         void                    set_expanded( bool flag_expanded )
-        {
-            if( flag_expanded )
-                m_status |= ES::EXPANDED;
-            else if( m_status & ES::EXPANDED )
-                m_status -= ES::EXPANDED;
-        }
+        { set_status_flag( ES::EXPANDED, flag_expanded ); }
 
     protected:
 
@@ -472,15 +428,15 @@ class PoolCategoriesTags : public std::map< Glib::ustring, CategoryTags*, FuncCo
 };
 
 // TAG
-class Tag : public DiaryElementContainer
+class Tag : public DiaryElementReferrer< Entry >
 {
     public:
-        static ElementShower< Tag > *shower;
+        static ElementShower< Tag >* shower;
 
-                                Tag( DiaryBase* const d )
-                                :   DiaryElementContainer( d ),
+                                Tag( Diary* const d )
+                                :   DiaryElementReferrer( d ),
                                     m_ptr2category( NULL ), m_theme( NULL ) {}
-        explicit                Tag( DiaryBase* const, const Glib::ustring&, CategoryTags* );
+        explicit                Tag( Diary* const, const Glib::ustring&, CategoryTags* );
         virtual                 ~Tag();
 
         void                    show();
@@ -497,6 +453,7 @@ class Tag : public DiaryElementContainer
         void                    reset_theme();
 
         void                    set_name( const Glib::ustring& );
+
         //Date                  get_date() const; // if earliest entry's date is needed
         virtual Type            get_type() const
         { return ET_TAG; }
@@ -527,12 +484,14 @@ class Untagged : public Tag
                                 get_icon() const;
         const Glib::RefPtr< Gdk::Pixbuf >&
                                 get_icon32() const;
-        /*const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon() const;
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32() const;*/
 
         Glib::ustring           get_list_str() const;
+
+        void                    reset()
+        {
+            clear();
+            reset_theme();
+        }
 };
 
 // POOL OF DEFINED TAGS
@@ -552,11 +511,11 @@ class PoolTags : public std::map< Glib::ustring, Tag*, FuncCompareStrings >
 
 // TAGS OF AN ENTRY
 // not responsible for memory handling
-class Tagset : public std::set< Tag*, FuncCompareDiaryElemNamed >
+class Tagset : public std::set< Tag*, FuncCompareDiaryElem >
 {
     public:
                                 Tagset()
-        :   std::set< Tag*, FuncCompareDiaryElemNamed >( compare_listitems_by_name ) {}
+        :   std::set< Tag*, FuncCompareDiaryElem >( compare_listitems_by_name ) {}
 
                                 ~Tagset();
         bool                    add( Tag* );
@@ -569,13 +528,12 @@ class Tagset : public std::set< Tag*, FuncCompareDiaryElemNamed >
 };
 
 // CHAPTER =========================================================================================
-class Chapter : public DiaryElement
+class Chapter : public DiaryElementReferrer< Entry >
 {
     public:
         static ElementShower< Chapter >* shower;
 
-        explicit                Chapter( DiaryBase* const, const Glib::ustring& );
-                                Chapter( DiaryBase* const, const Glib::ustring&, Date );
+                                Chapter( Diary* const, const Glib::ustring&, Date::date_t );
         // this class should have a virtual dtor for some reason because
         // if it does not, its derived classes cannot be deleted
         virtual                 ~Chapter() {}
@@ -583,61 +541,43 @@ class Chapter : public DiaryElement
         void                    show();
 
         void                    set_name( const Glib::ustring& );
-        Date                    get_date() const;
+
         Glib::ustring           get_date_str() const;
+
         void                    set_date( Date::date_t date )
         { m_date_begin.m_date = date; update_type(); }
-        virtual int             get_size() const  // TODO: stub!
-        { return m_size; }
+
         Type                    get_type() const
         { return m_type; }
         const Glib::RefPtr< Gdk::Pixbuf >&
                                 get_icon() const;
         const Glib::RefPtr< Gdk::Pixbuf >&
                                 get_icon32() const;
+        Date                    get_date() const;
+
+        Glib::ustring           get_list_str() const;
 
         Date                    get_free_order() const;
 
-        Glib::ustring           get_list_str() const
-        { return Glib::ustring::compose( "<b>%1 -  %2</b>", m_date_begin.format_string(),
-                Glib::Markup::escape_text( m_name ) ); }
-
         bool                    get_expanded() const
         { return( m_status & ES::EXPANDED ); }
         void                    set_expanded( bool flag_expanded )
-        {
-            if( flag_expanded )
-                m_status |= ES::EXPANDED;
-            else if( m_status & ES::EXPANDED )
-                m_status -= ES::EXPANDED;
-        }
+        { set_status_flag( ES::EXPANDED, flag_expanded ); }
 
-        bool                    is_initialized() const
-        { return( m_date_begin.m_date != Date::NOTSET ); }
         bool                    is_ordinal() const
         { return m_date_begin.is_ordinal(); }
 
-        void                    reset_size()
-        { m_size = 0; }
-        void                    increase_size()
-        { m_size++; }
         void                    recalculate_span( const Chapter* );
-
-        // only for to-do groups:
-        ElemStatus              get_todo_status() const
-        { return( m_status & ES::FILTER_TODO ); }
-        void                    set_todo_status( ElemStatus s )
-        {
-            m_status -= ( m_status & ES::FILTER_TODO );
-            m_status |= s;
-        }
+        int                     get_time_span() const
+        { return m_time_span; }
+        void                    set_time_span( int s )
+        { m_time_span = s; }
 
         void                    update_type();
 
     protected:
         Date                    m_date_begin;
         int                     m_time_span;
-        int                     m_size;
         Type                    m_type;
 
     friend class CategoryChapters;
@@ -648,31 +588,32 @@ class CategoryChapters :
         public DiaryElement, public std::map< Date::date_t, Chapter*, FuncCompareDates >
 {
     public:
-        explicit                CategoryChapters( DiaryBase * const d, const Glib::ustring& );
+        explicit                CategoryChapters( Diary* const, const Glib::ustring& );
+        // for topics and groups which do not have names:
+        explicit                CategoryChapters( Diary* const, Date::date_t );
         virtual                 ~CategoryChapters();
 
-        virtual int             get_size() const
-        { return size(); }
         Type                    get_type() const
         { return ET_CHAPTER_CTG; }
+        virtual int             get_size() const
+        { return size(); }
 
         void                    show() {} // not used
 
         Chapter*                get_chapter( const Date::date_t ) const;
 
         Chapter*                create_chapter( const Glib::ustring&, const Date& );
-        void                    dismiss_chapter( Chapter* );
-        bool                    rename_chapter( Chapter*, const Glib::ustring& );
+        Chapter*                create_chapter_ordinal( const Glib::ustring& );
         bool                    set_chapter_date( Chapter*, Date::date_t );
 
         bool                    add( Chapter* );
 
         void                    clear();
 
-        Date                    get_free_order() const;
+        Date                    get_free_order_ordinal() const;
 
     protected:
-
+        const Date::date_t      m_date_min;
 };
 
 class PoolCategoriesChapters :
@@ -692,14 +633,14 @@ class Filter : public DiaryElement
     public:
         static ElementShower< Filter >* shower;
 
-                                    Filter( DiaryBase* const, const Glib::ustring& );
+                                    Filter( Diary* const, const Glib::ustring& );
 
         void                        show();
 
-        int                         get_size() const
-        { return 0; }   // redundant
         DiaryElement::Type          get_type() const
         { return ET_FILTER; }
+        int                         get_size() const
+        { return 0; }   // redundant
         const Glib::RefPtr< Gdk::Pixbuf >&
                                     get_icon() const;
         const Glib::RefPtr< Gdk::Pixbuf >&
@@ -719,7 +660,7 @@ class Filter : public DiaryElement
 
         void                        set_favorites( bool, bool );
         void                        set_trash( bool, bool );
-        void                        set_todo( bool, bool, bool );
+        void                        set_todo( bool, bool, bool, bool, bool );
 
         Date::date_t                get_date_begin() const
         { return m_date_begin; }
