@@ -31,74 +31,75 @@ using namespace LIFEO;
 // STATIC MEMBERS
 ElementShower< Entry >* Entry::shower( NULL );
 
-Entry::Entry( DiaryBase* const d, const Date::date_t date,const Glib::ustring &text,
+Entry::Entry( Diary* const d, const Date::date_t date, const Glib::ustring& text,
               bool favored )
-:   DiaryElement( d, favored ? ES::DEFAULT_FAVORED : ES::DEFAULT ), m_date( date ),
+:   DiaryElement( d, "", favored ? ES::ENTRY_DEFAULT_FAV : ES::ENTRY_DEFAULT ), m_date( date ),
     m_date_created( time( NULL ) ), m_date_changed( m_date_created ),
     m_text( text ), m_ptr2theme_tag( NULL ),
     m_option_lang( LANG_INHERIT_DIARY )
 {
     calculate_title( text );
-    m_ptr2diary->get_untagged()->get_items()->insert( this );
 }
 
-Entry::Entry( DiaryBase* const d, const Date::date_t date, bool favored )
-:   DiaryElement( d, favored ? ES::DEFAULT_FAVORED : ES::DEFAULT, _( STRING::EMPTY_ENTRY_TITLE ) ),
+Entry::Entry( Diary* const d, const Date::date_t date, bool favored )
+:   DiaryElement( d, _( STRING::EMPTY_ENTRY_TITLE ),
+                  favored ?  ES::ENTRY_DEFAULT_FAV : ES::ENTRY_DEFAULT ),
     m_date( date ),
     m_date_created( time( NULL ) ), m_date_changed( m_date_created ),
     m_text( "" ), m_ptr2theme_tag( NULL ),
     m_option_lang( LANG_INHERIT_DIARY )
 {
-    m_ptr2diary->get_untagged()->get_items()->insert( this );
 }
 
 const Glib::RefPtr< Gdk::Pixbuf >&
 Entry::get_icon() const
 {
-    if( is_todo() )
-        switch( get_todo_status() )
-        {
-            case ES::TODO:
-                return Lifeograph::icons->todo_open_16;
-            case ES::DONE:
-                return Lifeograph::icons->todo_done_16;
-            case ES::CANCELED:
-                return Lifeograph::icons->todo_canceled_16;
-        }
-
-    return Lifeograph::icons->entry_16;
+    switch( get_todo_status() )
+    {
+        case ES::TODO:
+            return Lifeograph::icons->todo_open_16;
+        case ES::PROGRESSED:
+            return Lifeograph::icons->todo_progressed_16;
+        case ES::DONE:
+            return Lifeograph::icons->todo_done_16;
+        case ES::CANCELED:
+            return Lifeograph::icons->todo_canceled_16;
+        default:    // 0
+            return Lifeograph::icons->entry_16;
+    }
 }
 const Glib::RefPtr< Gdk::Pixbuf >&
 Entry::get_icon32() const
 {
-    if( is_todo() )
-        switch( get_todo_status() )
-        {
-            case ES::TODO:
-                return Lifeograph::icons->todo_open_32;
-            case ES::DONE:
-                return Lifeograph::icons->todo_done_32;
-            case ES::CANCELED:
-                return Lifeograph::icons->todo_canceled_32;
-        }
-
-    return Lifeograph::icons->entry_32;
+    switch( get_todo_status() )
+    {
+        case ES::TODO:
+            return Lifeograph::icons->todo_open_32;
+        case ES::PROGRESSED:
+            return Lifeograph::icons->todo_progressed_32;
+        case ES::DONE:
+            return Lifeograph::icons->todo_done_32;
+        case ES::CANCELED:
+            return Lifeograph::icons->todo_canceled_32;
+        default:    // 0
+            return Lifeograph::icons->entry_32;
+    }
 }
 
 Glib::ustring
 Entry::get_list_str() const
 {
-    std::string tpl = ( is_todo() && ( m_status & ES::CANCELED ) ) ?
-            "<s>%1 -  %2</s>" : "%1 -  %2";
+    static const Glib::ustring tpl[] = { "%2", "%1 -  %2", "<s>%2</s>", "<s>%1 -  %2</s>" };
 
-    if( is_trashed() )
-    {
-        tpl = Glib::ustring::compose( "<span color=\"%1\">%2</span>",
-                                      Lifeograph::s_color_insensitive, tpl );
-    }
+    int i( m_date.is_hidden() ? 0 : 1 );
+    if( m_status & ES::CANCELED ) i += 2;
 
+    Glib::ustring tpl2 = is_trashed() ?
+            Glib::ustring::compose( "<span color=\"%1\">%2</span>",
+                                    Lifeograph::s_color_insensitive, tpl[ i ] ) :
+            tpl[ i ];
 
-    return Glib::ustring::compose( tpl, m_date.format_string(),
+    return Glib::ustring::compose( tpl2, m_date.format_string(),
                                    Glib::Markup::escape_text( m_name ) );
 }
 
@@ -129,8 +130,15 @@ Entry::get_date_changed_str() const
     return Date::format_string_dt( m_date_changed );
 }
 
+std::string
+Entry::get_lang_final() const
+{
+    return m_option_lang == LANG_INHERIT_DIARY ?
+            m_ptr2diary->get_lang() : m_option_lang;
+}
+
 void
-Entry::set_tags( const Tagset &tagset )
+Entry::set_tags( const Tagset& tagset )
 {
     m_tags = tagset;
 }
@@ -150,15 +158,18 @@ Entry::get_tags()
 bool
 Entry::add_tag( Tag* tag )
 {
-    if( m_tags.add( tag ) )
+    if( tag->get_type() == ET_UNTAGGED )
     {
-        tag->get_items()->insert( this );
+        return clear_tags();
+    }
+    else if( m_tags.add( tag ) )
+    {
+        tag->insert( this );
+        m_ptr2diary->get_untagged()->erase( this );
 
         if( m_ptr2theme_tag == NULL && tag->get_has_own_theme() )
             m_ptr2theme_tag = tag;
 
-        m_ptr2diary->get_untagged()->get_items()->erase( this );
-
         return true;
     }
     else
@@ -175,10 +186,10 @@ Entry::remove_tag( Tag* tag )
         return false;
 
     m_tags.erase( tag );
-    tag->get_items()->erase( this );
+    tag->erase( this );
 
     if( m_tags.empty() )
-        m_ptr2diary->get_untagged()->get_items()->insert( this );
+        m_ptr2diary->get_untagged()->insert( this );
 
     // if this tag was the theme tag, re-adjust the theme tag
     if( m_ptr2theme_tag == tag )
@@ -193,7 +204,6 @@ Entry::remove_tag( Tag* tag )
         }
 
         m_ptr2theme_tag = NULL;
-        return true;
     }
 
     return true;
@@ -206,7 +216,7 @@ Entry::clear_tags()
         return false;
 
     for( Tagset::iterator iter = m_tags.begin(); iter != m_tags.end(); ++iter )
-        ( *iter )->get_items()->erase( this );
+        ( *iter )->erase( this );
 
     m_tags.clear();
     m_ptr2theme_tag = NULL;
@@ -218,7 +228,7 @@ const Theme*
 Entry::get_theme() const
 {
     return( m_ptr2theme_tag ?
-            m_ptr2theme_tag->get_theme() : Diary::d->get_untagged()->get_theme() );
+            m_ptr2theme_tag->get_theme() : m_ptr2diary->get_untagged()->get_theme() );
 }
 
 void
@@ -235,21 +245,10 @@ Entry::update_theme()
     if( m_ptr2theme_tag ) // if there already was a theme tag set
     {
         if( m_ptr2theme_tag->get_has_own_theme() == false ) // if it is no longer a theme tag
-        {
             m_ptr2theme_tag = NULL;
-
-            // check if another tag has its own theme and set it
-            for( Tagset::iterator iter = m_tags.begin(); iter != m_tags.end(); ++iter )
-            {
-                if( ( *iter )->get_has_own_theme() )
-                {
-                    m_ptr2theme_tag = *iter;
-                    break;
-                }
-            }
-        }
     }
-    else // if there was no theme tag previously
+
+    if( m_ptr2theme_tag == NULL )
     {
         // check if a tag has its own theme now and set it
         for( Tagset::iterator iter = m_tags.begin(); iter != m_tags.end(); ++iter )
@@ -266,7 +265,7 @@ Entry::update_theme()
 bool
 Entry::get_filtered_out()
 {
-    const Filter *filter = Diary::d->get_filter();
+    const Filter* filter = m_ptr2diary->get_filter();
     ElemStatus fs = filter->get_status();
 
     bool flag_filteredout( m_status & ES::FILTERED_OUT );
@@ -284,12 +283,9 @@ Entry::get_filtered_out()
         if( flag_filteredout )
             break;
 
-        if( is_todo() )
-        {
-            flag_filteredout = !( fs & ES::FILTER_TODO & m_status );
-            if( flag_filteredout )
-                break;
-        }
+        flag_filteredout = !( fs & ES::FILTER_TODO & m_status );
+        if( flag_filteredout )
+            break;
 
         if( fs & ES::FILTER_DATE_BEGIN )
             if( m_date.m_date < filter->get_date_begin() )
@@ -334,8 +330,8 @@ Entry::get_filtered_out()
             }
         }
 
-        if( Diary::d->is_search_active() )
-            flag_filteredout = ( m_text.lowercase().find( Diary::d->get_search_text() )
+        if( m_ptr2diary->is_search_active() )
+            flag_filteredout = ( m_text.lowercase().find( m_ptr2diary->get_search_text() )
                     == std::string::npos );
 
         break;
@@ -365,13 +361,6 @@ Entry::prepare_for_hiding()
         PRINT_DEBUG( "Entry has no graphical data!" );
 }
 
-void
-Entry::set_todo_status( ElemStatus s )
-{
-    m_status -= ( m_status & ES::FILTER_TODO );
-    m_status |= s;
-}
-
 // ENTRY SET =======================================================================================
 PoolEntries::~PoolEntries()
 {
