@@ -36,27 +36,28 @@ static const char LANG_INHERIT_DIARY[] = "d";
 class Entry : virtual public DiaryElement
 {
     public:
-        static ElementShower< Entry > *shower;
+        static ElementShower< Entry >* shower;
 
         typedef sigc::signal< void, Entry* >
                                 Signal_void_Entry;
 
-                                Entry( DiaryBase * const, const Date::date_t,
+                                Entry( Diary* const, const Date::date_t,
                                        const Glib::ustring&, bool = false );
-                                Entry( DiaryBase * const, const Date::date_t,
+                                Entry( Diary* const, const Date::date_t,
                                        bool = false );
         virtual                 ~Entry() {}
 
         void                    show();
         void                    prepare_for_hiding();
 
-        const Glib::ustring*    get_text() const { return &m_text; }
+        const Glib::ustring*    get_text() const { return& m_text; }
         Glib::ustring&          get_text() { return m_text; }
-        void                    set_text( const Glib::ustring &text )
+        void                    set_text( const Glib::ustring& text )
         { m_text = text; calculate_title( text ); }
 
         Date                    get_date() const { return m_date; }
         time_t                  get_date_created() const { return m_date_created; }
+        void                    set_date_changed( Date::date_t d ) { m_date_changed = d; }
         time_t                  get_date_changed() const { return m_date_changed; }
         Glib::ustring           get_date_created_str() const;
         Glib::ustring           get_date_changed_str() const;
@@ -88,39 +89,21 @@ class Entry : virtual public DiaryElement
         bool                    is_favored() const { return( m_status & ES::FAVORED ); }
         void                    set_favored( bool favored )
         {
-            if( favored )
-            {
-                m_status |= ES::FAVORED;
-                m_status &= ( ~ES::NOT_FAVORED );
-            }
-            else
-            {
-                m_status |= ES::NOT_FAVORED;
-                m_status &= ( ~ES::FAVORED );
-            }
+            m_status -= ( m_status & ES::FILTER_FAVORED );
+            m_status |= ( favored ? ES::FAVORED : ES::NOT_FAVORED );
         }
         void                    toggle_favored()
         { m_status ^= ES::FILTER_FAVORED; }
 
         std::string             get_lang() const { return m_option_lang; }
-        std::string             get_lang_final() const {
-            return m_option_lang == LANG_INHERIT_DIARY ?
-                    m_ptr2diary->get_lang() : m_option_lang; }
-        void                    set_lang( const std::string &lang ) { m_option_lang = lang; }
+        std::string             get_lang_final() const;
+        void                    set_lang( const std::string& lang ) { m_option_lang = lang; }
 
         bool                    is_trashed() const { return( m_status & ES::TRASHED ); }
         void                    set_trashed( bool trashed )
         {
-            if( trashed )
-            {
-                m_status |= ES::TRASHED;
-                m_status &= ( ~ES::NOT_TRASHED );
-            }
-            else
-            {
-                m_status |= ES::NOT_TRASHED;
-                m_status &= ( ~ES::TRASHED );
-            }
+            m_status -= ( m_status & ES::FILTER_TRASHED );
+            m_status |= ( trashed ? ES::TRASHED : ES::NOT_TRASHED );
         }
 
         void                    set_tags( const Tagset& );
@@ -139,12 +122,6 @@ class Entry : virtual public DiaryElement
         { return( m_ptr2theme_tag != NULL ); }
         void                    update_theme(); // called when a tag gained or lost custom theme
 
-        bool                    is_todo() const
-        { return m_date.is_todo(); }
-        ElemStatus              get_todo_status() const
-        { return( m_status & ES::FILTER_TODO ); }
-        void                    set_todo_status( ElemStatus );
-
     protected:
         Date                    m_date;
         time_t                  m_date_created;
@@ -156,8 +133,6 @@ class Entry : virtual public DiaryElement
         std::string             m_option_lang;  // empty means off
 
     friend class Diary; // TODO: remove this friendship too??
-    friend class DiaryView; // TODO: remove this friendship too??
-    friend class EntryView;
 };
 
 // ENTRY SET ===================================================================
@@ -171,6 +146,11 @@ class PoolEntries : public std::map< Date::date_t, Entry*, FuncCompareDates >
         void                        clear();
 };
 
+typedef PoolEntries::iterator               EntryIter;
+typedef PoolEntries::reverse_iterator       EntryIterReverse;
+typedef PoolEntries::const_iterator         EntryIterConst;
+typedef PoolEntries::const_reverse_iterator EntryIterConstRev;
+
 } // end of namespace LIFEO
 
 #endif
