@@ -41,6 +41,7 @@ EntryParser::reset( Glib::ustring::size_type start, Glib::ustring::size_type end
     date_last = 0;
     id_last = 0;
     m_chars_looked_for.clear();
+
     if( start == 0 )
     {
         m_chars_looked_for.push_back( AbsChar( CF_IGNORE, NULL ) ); // to prevent formatting within title
@@ -54,6 +55,14 @@ EntryParser::reset( Glib::ustring::size_type start, Glib::ustring::size_type end
     }
 }
 
+void
+EntryParser::set_search_str( const Glib::ustring &str )
+{
+    m_search_str = str;
+    i_search = 0;
+    i_search_end = str.size() - 1;
+}
+
 void
 EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end )
 {
@@ -62,9 +71,8 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
     for( ; pos_current < m_pos_end; ++pos_current )
     {
         char_current = get_char_at( pos_current );
-        m_cc_current = CC_SIGN;
 
-        if( m_search_str.size() > 0 )
+        if( !m_search_str.empty() )
         {
             if( m_search_str[ i_search ] == Glib::Unicode::tolower( char_current ) )
             {
@@ -90,17 +98,15 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
             case 0:     // should never be the case
             case '\n':
             case '\r':
-                m_cc_current = CC_NEWLINE;
                 process_char( CF_NEWLINE,
                               CF_NUM_CKBX|CF_ALPHA|CF_FORMATCHAR|
                               CF_SLASH|CF_DOTDATE|CF_MORE|CF_TAB|CF_IGNORE,
-                              0, NULL );
+                              0, NULL, CC_NEWLINE );
                 break;
             case ' ':
-                m_cc_current = CC_SPACE;
                 process_char( CF_SPACE,
                               CF_ALPHA|CF_NUMBER|CF_SLASH|CF_DOTDATE|CF_CHECKBOX,
-                              CF_NOTHING, &EntryParser::trigger_subheading );
+                              CF_NOTHING, &EntryParser::trigger_subheading, CC_SPACE );
                 break;
             case '*': // SIGN
                 process_char( CF_ASTERISK,
@@ -135,10 +141,9 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
             case '0': case '1': case '2': case '3': case '4':
             case '5': case '6': case '7': case '8': case '9':
                 handle_number();   // calculates numeric value
-                m_cc_current = CC_NUMBER;
                 process_char( CF_NUMBER,
                               CF_SLASH|CF_ALPHA|CF_DOTDATE|CF_CHECKBOX,
-                              CF_NOTHING, &EntryParser::trigger_link_date );
+                              CF_NOTHING, &EntryParser::trigger_link_date, CC_NUMBER );
                 break;
             case '.': // SIGN
                 process_char( CF_DOTDATE,
@@ -171,10 +176,9 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
                               0, NULL );
                 break;
             case '\t':
-                m_cc_current = CC_TAB;
                 process_char( CF_TAB,
                               CF_NUM_SLSH|CF_ALPHA|CF_DOTDATE,
-                              CF_NOTHING, &EntryParser::trigger_list );
+                              CF_NOTHING, &EntryParser::trigger_list, CC_TAB );
                 break;
             // LIST CHARS
             case L'☐':
@@ -194,10 +198,9 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
             default:
                 if( Glib::Unicode::isalpha( char_current ) )
                 {
-                    m_cc_current = CC_ALPHASPELL;
                     process_char( CF_ALPHA,
                                   CF_NUM_CKBX|CF_DOTDATE|CF_SLASH,
-                                  0, NULL );
+                                  0, NULL, CC_ALPHASPELL );
                 }
                 else // SIGN
                 {
@@ -211,23 +214,22 @@ EntryParser::parse( Glib::ustring::size_type start, Glib::ustring::size_type end
     // end of the text -treated like new line
     if( m_pos_end > 0 ) // only when finish is not forced
     {
-        m_cc_current = CC_NEWLINE;
         process_char( CF_NEWLINE|CF_EOT,
                       CF_NUM_CKBX|CF_ALPHA|CF_FORMATCHAR|CF_SLASH|CF_DOTDATE|CF_MORE|CF_TAB,
-                      0, NULL );
+                      0, NULL, CC_NEWLINE );
     }
 }
 
 inline void
-EntryParser::process_char( unsigned int satisfies, unsigned int breaks, unsigned int triggers_on,
-                           FPtr_void triggerer )
+EntryParser::process_char( unsigned int satisfies, unsigned int breaks,
+                           unsigned int triggers_on, FPtr_void triggerer, CharClass cc )
 {
     // NOTE: m_cc_current *must* be set before calling this function
 
     // UPDATE ALPHA LAST
     if( m_flag_handle_word )
     {
-        if( m_cc_current & CC_ALPHA ) // CC_SPELLCHECK may be used in the future
+        if( cc & CC_ALPHA ) // CC_SPELLCHECK may be used in the future
         {
             if( alpha_last.empty() )
                 pos_alpha = pos_current;
@@ -275,7 +277,7 @@ EntryParser::process_char( unsigned int satisfies, unsigned int breaks, unsigned
         }
     }
     else
-    if( ( breaks & cf ) || ( cf & CF_IMMEDIATE ) )
+    if( ( breaks & cf ) == cf || ( cf & CF_IMMEDIATE ) )
     {
         flag_clear_chars = true;
         if( triggers_on & CF_NOTHING )
@@ -303,7 +305,7 @@ EntryParser::process_char( unsigned int satisfies, unsigned int breaks, unsigned
         }
     }
 
-    // DO AS COLLECTED ONFORMATION REQUIRES
+    // DO AS COLLECTED INFORMATION REQUIRES
     if( flag_clear_chars )
     {
         m_chars_looked_for.clear();
@@ -315,7 +317,7 @@ EntryParser::process_char( unsigned int satisfies, unsigned int breaks, unsigned
         ( this->*applier )();
 
     // UPDATE WORD LAST
-    if( m_cc_current & CC_SEPARATOR )
+    if( cc & CC_SEPARATOR )
         word_last.clear();
     else
     {
@@ -325,15 +327,7 @@ EntryParser::process_char( unsigned int satisfies, unsigned int breaks, unsigned
     }
 
     // UPDATE CHAR CLASS
-    m_cc_last = m_cc_current;
-}
-
-void
-EntryParser::set_search_str( const Glib::ustring &str )
-{
-    m_search_str = str;
-    i_search = 0;
-    i_search_end = str.size() - 1;
+    m_cc_last = cc;
 }
 
 // TRIGGERERS ======================================================================================
@@ -538,7 +532,7 @@ EntryParser::trigger_list()
         return;
 
     m_chars_looked_for.clear();
-    m_chars_looked_for.push_back( AbsChar( CF_CHECKBOX, &EntryParser::junction_list, true ) );
+    m_chars_looked_for.push_back( AbsChar( CF_NONTAB, &EntryParser::junction_list, true ) );
     m_cc_req = CC_ANY;
     m_pos_start = pos_current;
 }
@@ -588,6 +582,7 @@ EntryParser::junction_link_hidden_tab()
 void
 EntryParser::junction_list()
 {
+    apply_indent();
     m_chars_looked_for.front().flags = CF_SPACE|CF_IMMEDIATE;
     m_cc_req = CC_ANY;
 
@@ -602,7 +597,10 @@ EntryParser::junction_list()
         case L'☒':
             m_chars_looked_for.front().applier = &EntryParser::apply_check_ccl_0;
             break;
-        //default: // should never occur
+        default:
+            m_chars_looked_for.clear();
+            m_chars_looked_for.push_back( AbsChar( CF_NOTHING, NULL ) );
+            break;
     }
 }
 
