@@ -73,7 +73,8 @@ enum CharFlag
     CF_FORMATCHAR       = CF_ASTERISK|CF_UNDERSCORE|CF_EQUALS|CF_HASH|CF_SBB|CF_SBE,
     CF_NUM_SLSH         = CF_NUMBER|CF_SLASH,
     CF_NUM_CKBX         = CF_NUMBER|CF_CHECKBOX,
-    CF_NONSPACE         = CF_PUNCTUATION|CF_MARKUP|CF_ALPHA|CF_NUMBER|CF_AT|CF_CHECKBOX
+    CF_NONSPACE         = CF_PUNCTUATION|CF_MARKUP|CF_ALPHA|CF_NUMBER|CF_AT|CF_CHECKBOX,
+    CF_NONTAB           = CF_NONSPACE|CF_SPACE
 };
 
 enum CharClass
@@ -124,8 +125,8 @@ class EntryParser
 
         void                        process_char( unsigned int, unsigned int,
                                                   unsigned int,
-                                                  FPtr_void );
-        //void                        process_newline();
+                                                  FPtr_void,
+                                                  CharClass = CC_SIGN );
 
         // TRIGGERERS
         void                        trigger_subheading();
@@ -180,6 +181,7 @@ class EntryParser
 //        virtual void                apply_check_fin_end() { }   // maybe later..
 //        virtual void                apply_ignore_end() { }
 
+        virtual void                apply_indent() { }
         virtual void                apply_match() { }
         virtual void                handle_word() { } // for spell-checking
 
@@ -196,7 +198,6 @@ class EntryParser
         Glib::ustring::size_type    pos_search;
 
         CharClass                   m_cc_last;
-        CharClass                   m_cc_current;
         CharClass                   m_cc_req;       // required previous char
         gunichar                    char_current;
         Glib::ustring               word_last;
@@ -204,10 +205,11 @@ class EntryParser
         unsigned int                int_last;
         Date                        date_last;
         unsigned long               id_last;
-        Glib::ustring               m_search_str;
         bool                        m_flag_hidden_link;
         bool                        m_flag_handle_word;
 
+        Glib::ustring               m_search_str;
+
         std::deque< AbsChar >       m_chars_looked_for;
         FPtr_void                   m_applier_nl;
 
