@@ -28,7 +28,6 @@
 #endif
 
 #include <iomanip>
-#include <gtkmm/stock.h>
 
 #include "helpers.hpp"
 
@@ -36,7 +35,7 @@
 namespace HELPERS
 {
 
-Error::Error( const Glib::ustring &error_message )
+Error::Error( const Glib::ustring& error_message )
 {
     print_error( error_message );
 }
@@ -44,30 +43,17 @@ Error::Error( const Glib::ustring &error_message )
 // DATE ============================================================================================
 std::string Date::s_date_format_template = "%1.%2.%3";
 
-Date::Date( const Glib::ustring &str_date )
+Date::Date( const Glib::ustring& str_date )
 :   m_date( 0 )
 {
-    Glib::Date glib_date;
-
-    glib_date.set_parse( str_date );
-
-    if( ! glib_date.valid() )
-        throw Error( "Date format not accepted" );
-
-    guint16 year = glib_date.get_year();
-
-    if( year < YEAR_MIN || year > YEAR_MAX )
-        throw Error( "Date out of acceptable range" );
-
-    m_date = ( year << 19 ) +
-             ( glib_date.get_month() << 15 ) +
-             ( glib_date.get_day() << 10 );
+    if( parse_string( &m_date, str_date ) != OK )
+        m_date = NOT_SET;
 }
 
 // TODO: later...
 //Date::Date( time_t t )
 //{
-//    struct tm *timeinfo = localtime( &t );
+//    struct tm* timeinfo = localtime( &t );
 //    m_date = make_date( timeinfo->tm_year + 1900,
 //                        timeinfo->tm_mon +1,
 //                        timeinfo->tm_mday );
@@ -79,7 +65,7 @@ Date::Date( const Glib::ustring &str_date )
 Glib::Date::Month
 Date::get_month_glib() const
 {
-    switch( ( m_date & 0x78000 ) >> 15 )
+    switch( ( m_date & MONTH_FILTER ) >> 15 )
     {
         case 1:
             return Glib::Date::JANUARY;
@@ -110,8 +96,115 @@ Date::get_month_glib() const
     }
 }
 
+Result
+Date::parse_string( Date::date_t* date, const Glib::ustring& str_date )
+{
+    char c_cur;
+    unsigned int num[ 4 ] = { 0, 0, 0, 0 };  // fourth int is for trailing spaces
+    int i( 0 );
+
+    for( unsigned j = 0; j < str_date.size(); j++ )
+    {
+        c_cur = str_date[ j ];
+        switch( c_cur )
+        {
+            case '0': case '1': case '2': case '3': case '4':
+            case '5': case '6': case '7': case '8': case '9':
+                if( i > 2 )
+                    return INVALID;
+                num[ i ] *= 10;
+                num[ i ] += ( c_cur - '0' );
+                break;
+            case ' ':
+                if( num[ i ] > 0 )
+                    i++;
+                break;
+            case '.':
+            case '-':
+            case '/':
+                if( num[ i ] == 0 || i == 2 )
+                    return INVALID;
+                else
+                    i++;
+                break;
+            default:
+                return INVALID;
+        }
+    }
+
+    if( num[ 2 ] ) // temporal
+    {
+        unsigned int year( 0 );
+        unsigned int month( 0 );
+        unsigned int day( 0 );
+
+        if( num[ 0 ] > 31 && num[ 1 ] <= 12 && num[ 2 ] <= 31 ) // YMD
+        {
+            year = num[ 0 ];
+            month = num[ 1 ];
+            day = num[ 2 ];
+        }
+        else
+        {
+            if( num[ 0 ] <= 12 && num[ 1 ] <= 12 ) // both DMY and MDY possible
+            {
+                if( s_date_format_template[ 1 ] == '2' )
+                {
+                    month = num[ 0 ];
+                    day = num[ 1 ];
+                }
+                else
+                {
+                    day = num[ 0 ];
+                    month = num[ 1 ];
+                }
+            }
+            else if( num[ 0 ] <= 31 && num[ 1 ] <= 12 ) // DMY
+            {
+                month = num[ 1 ];
+                day = num[ 0 ];
+            }
+            else if( num[ 0 ] <= 12 && num[ 1 ] <= 31 ) // MDY
+            {
+                month = num[ 1 ];
+                day = num[ 0 ];
+            }
+            else
+                return INVALID;
+
+            year = num[ 2 ];
+
+            if( year < 100 )
+                year += ( year < 30 ? 2000 : 1900 );
+        }
+
+        if( year < YEAR_MIN || year > YEAR_MAX )
+            return OUT_OF_RANGE;
+
+        Date date_tmp( year, month, day );
+        if( ! date_tmp.is_valid() ) // checks days in month
+            return INVALID;
+
+        if( date )  // pass NULL when just used for checking
+            *date = date_tmp.m_date;
+
+    }
+    else if( num[ 1 ] )   // ordinal
+    {
+        if( num[ 0 ] > CHAPTER_MAX || num[ 1 ] > ORDER_MAX )
+            return OUT_OF_RANGE;
+
+        if( date )  // pass NULL when just used for checking
+            *date = make_date( num[ 0 ], num[ 1 ] );
+    }
+    else
+        return INVALID;
+
+    return OK;
+}
+
 Glib::ustring
-Date::format_string( const date_t d, const std::string &format )
+Date::format_string( const date_t d, const std::string& format )
 {
     if( d & ORDINAL_FLAG )
     {
@@ -130,7 +223,7 @@ Date::format_string( const date_t d, const std::string &format )
 Glib::ustring
 Date::format_string_dt( const time_t time )
 {
-    struct tm *timeinfo = localtime( &time );
+    struct tm* timeinfo = localtime( &time );
     return Glib::ustring::compose( s_date_format_template + ", %4:%5",
             1900 + timeinfo->tm_year,
             Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mon + 1 ),
@@ -143,7 +236,7 @@ Date::format_string_dt( const time_t time )
 Glib::ustring
 Date::format_string_d( const time_t time )
 {
-    struct tm *timeinfo = localtime( &time );
+    struct tm* timeinfo = localtime( &time );
     return Glib::ustring::compose( s_date_format_template,
             1900 + timeinfo->tm_year,
             Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mon + 1 ),
@@ -206,7 +299,7 @@ Date::get_ctime( const Date::date_t d )
 {
     time_t t;
     time( &t );
-    struct tm *timeinfo = localtime( &t );
+    struct tm* timeinfo = localtime( &t );
     timeinfo->tm_year = get_year( d ) - 1900;
     timeinfo->tm_mon = get_month( d ) - 1;
     timeinfo->tm_mday = get_day( d );
@@ -220,8 +313,8 @@ Date::get_ctime( const Date::date_t d )
 void
 Date::forward_months( int months )
 {
-    months += ( ( m_date & 0x78000 ) >> 15 ); // get month
-    m_date &= 0x7FF80000;   // isolate year
+    months += ( ( m_date & MONTH_FILTER ) >> 15 ); // get month
+    m_date &= YEAR_FILTER;   // isolate year
     const int mod_months = months % 12;
     if( mod_months == 0 )
     {
@@ -239,7 +332,7 @@ void
 Date::forward_month()
 {
     int months = get_month() + 1;
-    m_date &= 0x7FF80000;   // isolate year
+    m_date &= YEAR_FILTER;   // isolate year
     const int mod_months = months % 12;
     if( mod_months == 0 )
     {
@@ -256,8 +349,8 @@ Date::forward_month()
 void
 Date::forward_day()
 {
-    int day = get_day();
-    if( day >= Glib::Date::get_days_in_month( get_month_glib(), get_year() ) )
+    unsigned int day = get_day();
+    if( day >= get_days_in_month() )
     {
         set_day( 1 );
         forward_month();
@@ -267,7 +360,7 @@ Date::forward_day()
 }
 
 unsigned int
-Date::calculate_days_between( const Date &date2 ) const
+Date::calculate_days_between( const Date& date2 ) const
 {
     // TODO: create own implementation
     Glib::Date gdate_begin( get_glib() );
@@ -290,22 +383,22 @@ Date::calculate_months_between( Date::date_t date1, Date::date_t date2 )
     return( dist < 0 ? -dist : dist );
 }
 
-// CONSOLE MESSAGES
+// CONSOLE MESSAGES ================================================================================
 void
-print_error( const Glib::ustring &description )
+print_error( const Glib::ustring& description )
 {
     std::cerr << "ERROR: " << description << std::endl;
 }
 
 void
-print_info( const Glib::ustring &description )
+print_info( const Glib::ustring& description )
 {
     std::cout << "INFO: " << description << std::endl;
 }
 
 // STRING PROCESSING
 long
-convert_string( const std::string &str )
+convert_string( const std::string& str )
 {
     //TODO: add negative number support
     long result( 0 );   // result
@@ -319,7 +412,7 @@ convert_string( const std::string &str )
 }
 
 bool
-str_ends_with ( const std::string &str, std::string const &end )
+str_ends_with ( const std::string& str, const std::string& end )
 {
     if( str.length() > end.length() )
     {
@@ -333,7 +426,7 @@ str_ends_with ( const std::string &str, std::string const &end )
 
 // COLOR PROCESSING
 Gdk::RGBA
-contrast2( const Gdk::RGBA &bg, const Gdk::RGBA &c1, const Gdk::RGBA &c2 )
+contrast2( const Gdk::RGBA& bg, const Gdk::RGBA& c1, const Gdk::RGBA& c2 )
 {
     double dist1 = ( fabs( bg.get_red() - c1.get_red() ) +
                      fabs( bg.get_green() - c1.get_green() ) +
@@ -351,7 +444,7 @@ contrast2( const Gdk::RGBA &bg, const Gdk::RGBA &c1, const Gdk::RGBA &c2 )
 
 // deprecated: this needs lots of love and it is not worth the effort
 /*Gdk::RGBA
-contrast( const Gdk::RGBA &bg, const Gdk::RGBA &fg )
+contrast( const Gdk::RGBA& bg, const Gdk::RGBA& fg )
 {
     Gdk::RGBA contrast( fg );
     int dom_index = 0;  // 1,2,3 = R,G,B
@@ -410,7 +503,7 @@ contrast( const Gdk::RGBA &bg, const Gdk::RGBA &fg )
 }*/
 
 Gdk::RGBA
-midtone( const Gdk::RGBA &c1, const Gdk::RGBA &c2 )
+midtone( const Gdk::RGBA& c1, const Gdk::RGBA& c2 )
 {
     Gdk::RGBA midtone;
     midtone.set_red_u( ( c1.get_red_u() + c2.get_red_u() ) / 2.0 );
@@ -421,7 +514,7 @@ midtone( const Gdk::RGBA &c1, const Gdk::RGBA &c2 )
 }
 
 Gdk::RGBA
-midtone( const Gdk::RGBA &c1, const Gdk::RGBA &c2, float ratio )
+midtone( const Gdk::RGBA& c1, const Gdk::RGBA& c2, float ratio )
 {
     Gdk::RGBA midtone;
     midtone.set_red_u( ( c1.get_red_u() * ratio ) + ( c2.get_red_u() * ( 1.0 - ratio ) ) );
@@ -432,7 +525,7 @@ midtone( const Gdk::RGBA &c1, const Gdk::RGBA &c2, float ratio )
 }
 // FILE FUNCTIONS
 std::ios::pos_type
-get_file_size( std::ifstream &file )
+get_file_size( std::ifstream& file )
 {
    std::ios::pos_type size;
    const std::ios::pos_type currentPosition = file.tellg();
@@ -498,7 +591,7 @@ get_env_lang()
     return s_lang_env;
 }
 
-// ENCRYPTION
+// ENCRYPTION ======================================================================================
 bool
 Cipher::init()
 {
@@ -534,24 +627,24 @@ Cipher::init()
 }
 
 void
-Cipher::create_iv( unsigned char **iv )
+Cipher::create_iv( unsigned char** iv )
 {
     // (Allocate memory for and fill with strong random data)
-    *iv = (unsigned char *) gcry_random_bytes( Cipher::cIV_SIZE, GCRY_STRONG_RANDOM );
+    *iv = ( unsigned char* ) gcry_random_bytes( Cipher::cIV_SIZE, GCRY_STRONG_RANDOM );
 
     if( ! *iv )
         throw Error( "Unable to create IV" );
 }
 
 void
-Cipher::expand_key( const char *passphrase,
-                    const unsigned char *salt,
-                    unsigned char **key )
+Cipher::expand_key( const char* passphrase,
+                    const unsigned char* salt,
+                    unsigned char** key )
 {
     gcry_md_hd_t hash;
     gcry_error_t error = 0;
     int hashdigestsize;
-    unsigned char *hashresult;
+    unsigned char* hashresult;
 
     // OPEN MESSAGE DIGEST ALGORITHM
     error = gcry_md_open( &hash, cHASH_ALGORITHM, 0 );
@@ -605,12 +698,12 @@ Cipher::expand_key( const char *passphrase,
 
 // create new expanded key
 void
-Cipher::create_new_key( char const *passphrase,
-                        unsigned char **salt,
-                        unsigned char **key )
+Cipher::create_new_key( char const * passphrase,
+                        unsigned char** salt,
+                        unsigned char** key )
 {
     // ALLOCATE MEMORY FOR AND FILL WITH STRONG RANDOM DATA
-    *salt = (unsigned char *) gcry_random_bytes( cSALT_SIZE, GCRY_STRONG_RANDOM );
+    *salt = ( unsigned char* ) gcry_random_bytes( cSALT_SIZE, GCRY_STRONG_RANDOM );
 
     if( ! *salt )
         throw Error( "Unable to create salt value" );
@@ -619,10 +712,10 @@ Cipher::create_new_key( char const *passphrase,
 }
 
 void
-Cipher::encrypt_buffer ( unsigned char *buffer,
+Cipher::encrypt_buffer ( unsigned char* buffer,
                          size_t& size,
-                         const unsigned char *key,
-                         const unsigned char *iv )
+                         const unsigned char* key,
+                         const unsigned char* iv )
 {
     gcry_cipher_hd_t    cipher;
     gcry_error_t        error = 0;
@@ -666,10 +759,10 @@ Cipher::encrypt_buffer ( unsigned char *buffer,
 }
 
 void
-Cipher::decrypt_buffer ( unsigned char * buffer,
-                         size_t& size,
-                         const unsigned char * key,
-                         const unsigned char * iv )
+Cipher::decrypt_buffer ( unsigned char* buffer,
+                         size_t size,
+                         const unsigned char* key,
+                         const unsigned char* iv )
 {
     gcry_cipher_hd_t cipher;
     gcry_error_t error = 0;
@@ -714,12 +807,12 @@ Cipher::decrypt_buffer ( unsigned char * buffer,
 
 // MARKED UP MENU ITEM
 Gtk::MenuItem*
-create_menuitem_markup( const Glib::ustring &str_markup,
-                        const Glib::SignalProxy0< void >::SlotType &handler )
+create_menuitem_markup( const Glib::ustring& str_markup,
+                        const Glib::SignalProxy0< void >::SlotType& handler )
 {
     // thanks to GNote for showing the way
-    Gtk::MenuItem *menuitem = Gtk::manage( new Gtk::MenuItem( str_markup ) );
-    Gtk::Label *label = dynamic_cast< Gtk::Label* >( menuitem->get_child() );
+    Gtk::MenuItem* menuitem = Gtk::manage( new Gtk::MenuItem( str_markup ) );
+    Gtk::Label* label = dynamic_cast< Gtk::Label* >( menuitem->get_child() );
     if( label )
         label->set_use_markup( true );
     menuitem->signal_activate().connect( handler );
@@ -728,16 +821,28 @@ create_menuitem_markup( const Glib::ustring &str_markup,
 
 // ENTRYCLEAR ======================================================================================
 EntryClear::EntryClear( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& )
-    :   Gtk::Entry( cobject )
+    :   Gtk::Entry( cobject ), m_pressed( false )
 {
-    signal_icon_release().connect( sigc::mem_fun( this, &EntryClear::handle_clear_icon ) );
+    signal_icon_press().connect( sigc::mem_fun( this, &EntryClear::handle_icon_press ) );
+    signal_icon_release().connect( sigc::mem_fun( this, &EntryClear::handle_icon_release ) );
 }
 
 void
-EntryClear::handle_clear_icon( Gtk::EntryIconPosition icon_pos, const GdkEventButton *event )
+EntryClear::handle_icon_press( Gtk::EntryIconPosition pos, const GdkEventButton* event )
 {
-    if( icon_pos == Gtk::ENTRY_ICON_SECONDARY && event->button == 1 )
-        set_text( "" );
+    if( pos == Gtk::ENTRY_ICON_SECONDARY && event->button == 1 )
+        m_pressed = true;
+}
+
+void
+EntryClear::handle_icon_release( Gtk::EntryIconPosition pos, const GdkEventButton* event )
+{
+    if( pos == Gtk::ENTRY_ICON_SECONDARY && event->button == 1 )
+    {
+        if( m_pressed )
+            set_text( "" );
+        m_pressed = false;
+    }
 }
 
 void
@@ -768,7 +873,7 @@ EntryClear::on_changed()
 }
 
 bool
-EntryClear::on_key_release_event( GdkEventKey *event )
+EntryClear::on_key_release_event( GdkEventKey* event )
 {
     if( event->keyval == GDK_KEY_Escape )
         set_text( "" );
@@ -781,22 +886,22 @@ EntryClear::on_key_release_event( GdkEventKey *event )
 
 Glib::ustring       Menubutton::s_builder_name;
 
-Menubutton::Menubutton( const Gtk::StockID &stockid,
-                        const Glib::ustring &label,
+Menubutton::Menubutton( const Gtk::StockID& stockid,
+                        const Glib::ustring& label,
                         Gtk::ReliefStyle style,
                         Gtk::IconSize iconsize,
-                        Menu2 *menu )
+                        Menu2* menu )
     :   Gtk::ToggleButton(), m_menu( menu )
 {
     set_relief( style );
 
     if( menu == NULL )
         m_menu = new Menu2;
-    Gtk::Box *hbox = Gtk::manage( new Gtk::Box );
-    Gtk::Image *icon = Gtk::manage( new Gtk::Image( stockid, iconsize ) );
+    Gtk::Box* hbox = Gtk::manage( new Gtk::Box );
+    Gtk::Image* icon = Gtk::manage( new Gtk::Image( stockid, iconsize ) );
     m_label = Gtk::manage( new Gtk::Label( label ) );
-    Gtk::Arrow *arrow = Gtk::manage(
-            new Gtk::Arrow(Gtk::ARROW_DOWN, Gtk::SHADOW_IN) );
+    Gtk::Arrow* arrow = Gtk::manage(
+            new Gtk::Arrow( Gtk::ARROW_DOWN, Gtk::SHADOW_IN ) );
 
     hbox->pack_start( *icon, Gtk::PACK_SHRINK );
     hbox->pack_start( *m_label, Gtk::PACK_EXPAND_WIDGET );
@@ -809,16 +914,16 @@ Menubutton::Menubutton( const Gtk::StockID &stockid,
 }
 
 //FIXME: code duplication
-Menubutton::Menubutton( const Glib::RefPtr< Gdk::Pixbuf > *pixbuf,
-                        const Glib::ustring &label,
+Menubutton::Menubutton( const Glib::RefPtr< Gdk::Pixbuf >* pixbuf,
+                        const Glib::ustring& label,
                         Gtk::ReliefStyle style,
-                        Menu2 *menu )
+                        Menu2* menu )
 :   Gtk::ToggleButton(), m_menu( menu )
 {
     set_relief( style );
-    Gtk::Arrow *arrow( NULL );
-    Gtk::Image *icon( NULL );
-    Gtk::Box *hbox( NULL );
+    Gtk::Arrow* arrow( NULL );
+    Gtk::Image* icon( NULL );
+    Gtk::Box* hbox( NULL );
     try
     {
         if( menu == NULL )
@@ -845,7 +950,7 @@ Menubutton::Menubutton( const Glib::RefPtr< Gdk::Pixbuf > *pixbuf,
     add_events( Gdk::BUTTON_PRESS_MASK );
 }
 
-Menubutton::Menubutton( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder> &builder )
+Menubutton::Menubutton( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder )
 :   Gtk::ToggleButton( cobject ), m_menu( NULL )
 {
     if( !s_builder_name.empty() )
@@ -882,7 +987,7 @@ Menubutton::get_menu() const
 }
 
 void
-Menubutton::set_menu( Menu2 *menu )
+Menubutton::set_menu( Menu2* menu )
 {
     if( m_menu == menu )
         return;
@@ -944,7 +1049,7 @@ Menubutton::get_menu_position( int& x, int& y, bool& push_in )
 }
 
 bool
-Menubutton::on_button_press_event( GdkEventButton *l_event )
+Menubutton::on_button_press_event( GdkEventButton* l_event )
 {
     m_menu->popup( sigc::mem_fun(
             *this, &Menubutton::get_menu_position), l_event->button, l_event->time);
@@ -958,7 +1063,7 @@ Menubutton::on_button_press_event( GdkEventButton *l_event )
 
 // MENUITEMRECENT ==================================================================================
 #if( GTKMM_MAJOR_VERSION < 3 ) // to be ported to gtkmm3 if needed
-MenuitemRecent::MenuitemRecent( const std::string &path )
+MenuitemRecent::MenuitemRecent( const std::string& path )
 :   Gtk::MenuItem(), m_icon_remove( Gtk::Stock::DELETE, Gtk::ICON_SIZE_MENU ),
     m_path( path ), m_flag_deletepressed( false )
 {
@@ -982,7 +1087,7 @@ MenuitemRecent::MenuitemRecent( const std::string &path )
 }
 
 bool
-MenuitemRecent::on_motion_notify_event( GdkEventMotion *event )
+MenuitemRecent::on_motion_notify_event( GdkEventMotion* event )
 {
     if( !( event->state &
             ( Gdk::BUTTON1_MASK | Gdk::BUTTON2_MASK | Gdk::BUTTON3_MASK ) ) )
@@ -992,7 +1097,7 @@ MenuitemRecent::on_motion_notify_event( GdkEventMotion *event )
 }
 
 bool
-MenuitemRecent::on_leave_notify_event( GdkEventCrossing *event )
+MenuitemRecent::on_leave_notify_event( GdkEventCrossing* event )
 {
     m_icon_remove.hide();
 
@@ -1000,7 +1105,7 @@ MenuitemRecent::on_leave_notify_event( GdkEventCrossing *event )
 }
 
 bool
-MenuitemRecent::on_button_press_event( GdkEventButton *event )
+MenuitemRecent::on_button_press_event( GdkEventButton* event )
 {
     if( event->x >= m_icon_remove.get_allocation().get_x() &&
         event->x < m_icon_remove.get_allocation().get_x() +
@@ -1013,7 +1118,7 @@ MenuitemRecent::on_button_press_event( GdkEventButton *event )
 }
 
 bool
-MenuitemRecent::on_button_release_event( GdkEventButton *event )
+MenuitemRecent::on_button_release_event( GdkEventButton* event )
 {
     if( m_flag_deletepressed )
     {
@@ -1033,8 +1138,8 @@ MenuitemRecent::on_button_release_event( GdkEventButton *event )
 Glib::ustring   FilebuttonRecent::fallback_label = _( "Select or Create a Diary" );
 
 /*
-FilebuttonRecent::FilebuttonRecent( const Glib::RefPtr< Gdk::Pixbuf > &pixbuf,
-                                    ListPaths *list_recent,
+FilebuttonRecent::FilebuttonRecent( const Glib::RefPtr< Gdk::Pixbuf >& pixbuf,
+                                    ListPaths* list_recent,
                                     const Glib::ustring& label_fallback )
 :   Menubutton( &pixbuf, label_fallback, Gtk::RELIEF_NORMAL ),
     m_icon_new( Gtk::Stock::NEW, Gtk::ICON_SIZE_MENU ),
@@ -1070,7 +1175,7 @@ FilebuttonRecent::FilebuttonRecent( const Glib::RefPtr< Gdk::Pixbuf > &pixbuf,
     drag_dest_add_uri_targets();
 }*/
 
-FilebuttonRecent::FilebuttonRecent( BaseObjectType *cobj, const Glib::RefPtr<Gtk::Builder> &bui )
+FilebuttonRecent::FilebuttonRecent( BaseObjectType* cobj, const Glib::RefPtr<Gtk::Builder>& bui )
 :   Menubutton( cobj, bui ),
     m_icon_new( Gtk::Stock::NEW, Gtk::ICON_SIZE_MENU ),
     m_icon_browse( Gtk::Stock::OPEN, Gtk::ICON_SIZE_MENU ),
@@ -1099,7 +1204,7 @@ FilebuttonRecent::FilebuttonRecent( BaseObjectType *cobj, const Glib::RefPtr<Gtk
 }
 
 void
-FilebuttonRecent::set( ListPaths *list_recent )
+FilebuttonRecent::set( ListPaths* list_recent )
 {
     m_list_recent = list_recent;
 }
@@ -1111,7 +1216,7 @@ FilebuttonRecent::get_filename() const
 }
 
 void
-FilebuttonRecent::set_filename( const std::string &path )
+FilebuttonRecent::set_filename( const std::string& path )
 {
     if( ! m_list_recent->empty() )
         if( path == * m_list_recent->begin() )
@@ -1131,13 +1236,12 @@ FilebuttonRecent::update_filenames()
         for( ListPaths::reverse_iterator iter = m_list_recent->rbegin();
              iter != m_list_recent->rend(); ++iter )
         {
-            MenuitemRecent *menuitem = Gtk::manage( new MenuitemRecent( * iter ) );
+            MenuitemRecent* menuitem = Gtk::manage( new MenuitemRecent( *iter ) );
 
             menuitem->signal_activate().connect(
-                    sigc::bind( sigc::mem_fun( *this, &FilebuttonRecent::set_filename ),
-                                * iter ) );
+                    sigc::bind( sigc::mem_fun( this, &FilebuttonRecent::set_filename ), *iter ) );
             menuitem->signal_removerecent().connect(
-                    sigc::mem_fun( *this, &FilebuttonRecent::remove_recent ) );
+                    sigc::mem_fun( this, &FilebuttonRecent::remove_recent ) );
 
             m_menu->items().push_front( Gtk::Menu_Helpers::Element( *menuitem ) );
 
@@ -1150,7 +1254,7 @@ FilebuttonRecent::update_filenames()
 }
 
 bool
-FilebuttonRecent::add_recent( const std::string &path )
+FilebuttonRecent::add_recent( const std::string& path )
 {
     // do not add a file twice:
     Gtk::Menu_Helpers::MenuList::iterator iter_menu = m_menu->items().begin();
@@ -1167,7 +1271,7 @@ FilebuttonRecent::add_recent( const std::string &path )
             ++iter_menu;
     }
 
-    MenuitemRecent *menuitem = Gtk::manage( new MenuitemRecent( path ) );
+    MenuitemRecent* menuitem = Gtk::manage( new MenuitemRecent( path ) );
 
     menuitem->signal_activate().connect(
             sigc::bind( sigc::mem_fun( *this, &FilebuttonRecent::set_filename ),
@@ -1191,7 +1295,7 @@ FilebuttonRecent::add_recent( const std::string &path )
 }
 
 void
-FilebuttonRecent::remove_recent( const std::string &path )
+FilebuttonRecent::remove_recent( const std::string& path )
 {
     Gtk::Menu_Helpers::MenuList::iterator   iter_menu = m_menu->items().begin();
     std::list< std::string >::iterator      iter_recent = m_list_recent->begin();
@@ -1283,7 +1387,7 @@ FilebuttonRecent::on_drag_data_received( const Glib::RefPtr<Gdk::DragContext>& c
 }
 
 void
-FilebuttonRecent::on_size_allocate( Gtk::Allocation &allocation )
+FilebuttonRecent::on_size_allocate( Gtk::Allocation& allocation )
 {
     Menubutton::on_size_allocate( allocation );
     m_menu->set_size_request( allocation.get_width(), -1 );
@@ -1314,10 +1418,10 @@ DialogEvent::handle_logout()
 Gtk::Frame*
 create_frame( const Glib::ustring& str_label, Gtk::Widget& content )
 {
-    Gtk::Frame *frame = Gtk::manage( new Gtk::Frame );
-    Gtk::Label *label = Gtk::manage( new Gtk::Label );
+    Gtk::Frame* frame = Gtk::manage( new Gtk::Frame );
+    Gtk::Label* label = Gtk::manage( new Gtk::Label );
 
-    Gtk::Alignment *alignment = Gtk::manage( new Gtk::Alignment );
+    Gtk::Alignment* alignment = Gtk::manage( new Gtk::Alignment );
 
     label->set_markup( Glib::ustring::compose( "<b>%1</b>", str_label ) );
     frame->set_shadow_type( Gtk::SHADOW_NONE );
@@ -1330,7 +1434,7 @@ create_frame( const Glib::ustring& str_label, Gtk::Widget& content )
 }
 
 // TREEVIEW ========================================================================================
-bool treepath_is_less( const Gtk::TreePath& p, const Gtk::TreePath& pb )
+bool is_treepath_less( const Gtk::TreePath& p, const Gtk::TreePath& pb )
 {
     for( unsigned int i = 0; i < p.size(); i++ )
     {
@@ -1347,7 +1451,7 @@ bool treepath_is_less( const Gtk::TreePath& p, const Gtk::TreePath& pb )
     return false; // more or equal
 }
 
-bool treepath_is_more( const Gtk::TreePath& p, const Gtk::TreePath& pe )
+bool is_treepath_more( const Gtk::TreePath& p, const Gtk::TreePath& pe )
 {
     for( unsigned int i = 0; i < p.size(); i++ )
     {
