@@ -46,6 +46,33 @@ class Error
                         Error( const Glib::ustring& );
 };
 
+enum Result
+{
+    OK,
+    ABORTED,
+    SUCCESS,
+    FAILURE,
+    COULD_NOT_START,
+    COULD_NOT_FINISH,
+    WRONG_PASSWORD,
+    //APPARENTLY_ENCRYTED_FILE,
+    //APPARENTLY_PLAIN_FILE,
+    INCOMPATIBLE_FILE_OLD,
+    INCOMPATIBLE_FILE_NEW,
+    CORRUPT_FILE,
+    // EMPTY_DATABASE, // not used anymore
+
+    // RESULTS USED BY set_path():
+    FILE_NOT_FOUND,
+    FILE_NOT_READABLE,
+    FILE_NOT_WRITABLE,
+    FILE_LOCKED,
+
+    // RESULTS USED BY Date
+    OUT_OF_RANGE,
+    INVALID
+};
+
 // RESPONSE IDS
 static const int        RESPONSE_CANCEL     = 0;
 static const int        RESPONSE_GO         = 1;
@@ -60,30 +87,47 @@ static const int        RESPONSE_GO         = 1;
 class Date
 {
     public:
-        static const unsigned long  NOTSET           = 0xFFFFFFFF;
-        static const unsigned long  DATE_MAX         = 0xFFFFFFFF;
-        static const unsigned long  YEARMONTH_FILTER = 0x7FFF8000;
-        static const unsigned int   YEAR_MAX         = 2199;
-        static const unsigned int   YEAR_MIN         = 1900;
+        static const unsigned long  NOT_APPLICABLE      = 0x0;
+        static const unsigned long  NOT_SET             = 0xFFFFFFFF;
+        static const unsigned long  DATE_MAX            = 0xFFFFFFFF;
 
-        static const unsigned int   ORDER_FILTER     = 0x3FF;
+        static const unsigned int   YEAR_MIN            = 1900;
+        static const unsigned int   YEAR_MAX            = 2199;
+        static const unsigned int   CHAPTER_MAX         = 1024;
+
+        static const unsigned int   ORDER_FILTER        =      0x3FF;
+        static const unsigned long  DAY_FILTER          =     0x7C00;
+        static const unsigned long  MONTH_FILTER        =    0x78000;
+        static const unsigned long  YEAR_FILTER         = 0x7FF80000;
+        static const unsigned long  ORDER_FILTER_INV    = DATE_MAX ^ ORDER_FILTER;
+        static const unsigned long  DAY_FILTER_INV      = DATE_MAX ^ DAY_FILTER;
+        static const unsigned long  MONTH_FILTER_INV    = DATE_MAX ^ MONTH_FILTER;
+        static const unsigned long  YEAR_FILTER_INV     = DATE_MAX ^ YEAR_FILTER;
+        static const unsigned long  YEARMONTH_FILTER    = YEAR_FILTER|MONTH_FILTER;
+        static const unsigned int   PURE_FILTER         = DATE_MAX ^ ORDER_FILTER;
+
+        // hidden elements' sequence numbers are not shown
+        static const unsigned long  VISIBLE_FLAG        = 0x40000000;  // only for ordinal items
+
+        static const unsigned long  ORDINAL_STEP        =      0x400;
+        static const unsigned long  ORDINAL_FLAG        = 0x80000000;
+        static const unsigned long  ORDINAL_FILTER      = ORDINAL_STEP * ( CHAPTER_MAX - 1 );
+        static const unsigned long  ORDINAL_LAST        = ORDINAL_FILTER;
+
+        static const unsigned long  ORDER_MAX           = ORDER_FILTER;
 
-        static const unsigned long  ORDINAL_STEP     = 0x400;
-        static const unsigned long  ORDINAL_FLAG     = 0x80000000;
-        static const unsigned long  ORDINAL_FILTER   = 0x1FFFFC00;
-        static const unsigned long  TOPIC_MAX        = ORDINAL_FILTER;
         static const unsigned long  TOPIC_NO_FLAGS_FILTER   = ORDINAL_FILTER|ORDER_FILTER;
 
-        static const unsigned long  TODO_FLAG        = 0x40000000;
-        static const unsigned long  TODO_FILTER      = TODO_FLAG;
+        static const unsigned long  TOPIC_MIN           = VISIBLE_FLAG|ORDINAL_FLAG;
+        static const unsigned long  GROUP_MIN           = ORDINAL_FLAG;
 
         static std::string          s_date_format_template;
 
         typedef unsigned long date_t;
 
-        void operator=( const Date &date )
+        void operator=( const Date& date )
         { m_date = date.m_date; }
-        void operator=( const Date::date_t &date )
+        void operator=( const Date::date_t& date )
         { m_date = date; }
 
         bool operator>( const Date& date_r )
@@ -93,12 +137,12 @@ class Date
         bool operator<( const Date& date_r )
         { return( m_date < date_r.m_date ); }
 
-        bool operator==( const Date &date )
+        bool operator==( const Date& date )
         { return( m_date == date.m_date ); }
-        bool operator==( const Date::date_t &date )
+        bool operator==( const Date::date_t& date )
         { return( m_date == date ); }
 
-        bool operator!=( const Date &date )
+        bool operator!=( const Date& date )
         { return( m_date != date.m_date ); }
 
         explicit                    Date( date_t date )
@@ -110,12 +154,12 @@ class Date
         // TODO: later: explicit                    Date( time_t );
         // ORDINAL C'TOR
                                     Date( unsigned int o1, unsigned int o2 )
-            :   m_date( ORDINAL_FLAG | ( o1 << 10 ) | o2 ) {}
+            :   m_date( VISIBLE_FLAG | ORDINAL_FLAG | ( o1 << 10 ) | o2 ) {}
 
         static date_t               get_today( int order = 0 )
         {
             time_t t = time( NULL );
-            struct tm *ti = localtime( &t );
+            struct tm* ti = localtime( &t );
             return make_date( ti->tm_year + 1900, ti->tm_mon + 1, ti->tm_mday, order );
         }
 
@@ -123,24 +167,9 @@ class Date
         { m_date = get_today( order ); }
 
         date_t                      get_pure() const
-        { return( m_date & 0xFFFFFC00 ); }
+        { return( m_date & PURE_FILTER ); }
         static date_t               get_pure( const date_t d )
-        { return( d & 0xFFFFFC00 ); }
-
-        date_t                      get_sort() const
-        {
-            // TODO: this is a temporary function. will be removed when default flags get adjusted
-            // as per sorting order in the new diary version
-            if( is_ordinal() )
-            {
-                if( is_todo() )
-                    return( ( m_date & TOPIC_NO_FLAGS_FILTER ) | ORDINAL_FLAG );
-                else
-                    return( m_date | TODO_FLAG );
-            }
-            else
-                return( m_date );
-        }
+        { return( d & PURE_FILTER ); }
 
         date_t                      get_yearmonth() const
         { return( m_date & YEARMONTH_FILTER ); }
@@ -148,9 +177,9 @@ class Date
         { return( d & YEARMONTH_FILTER ); }
 
         unsigned int                get_year() const
-        { return ( ( m_date & 0x7FF80000 ) >> 19 ); }
+        { return ( ( m_date & YEAR_FILTER ) >> 19 ); }
         static unsigned int         get_year( const date_t d )
-        { return ( ( d & 0x7FF80000 ) >> 19 ); }
+        { return ( ( d & YEAR_FILTER ) >> 19 ); }
 
         Glib::ustring               get_year_str() const;
         Glib::ustring               get_month_str() const;
@@ -173,16 +202,16 @@ class Date
         }
 
         unsigned int                get_month() const
-        { return( ( m_date & 0x78000 ) >> 15 ); }
+        { return( ( m_date & MONTH_FILTER ) >> 15 ); }
         static unsigned int         get_month( const date_t d )
-        { return( ( d & 0x78000 ) >> 15 ); }
+        { return( ( d & MONTH_FILTER ) >> 15 ); }
 
         Glib::Date::Month           get_month_glib() const;
 
         unsigned int                get_day() const
-        { return( ( m_date & 0x7C00 ) >> 10 ); }
+        { return( ( m_date & DAY_FILTER ) >> 10 ); }
         static unsigned int         get_day( const date_t d )
-        { return( ( d & 0x7C00 ) >> 10 ); }
+        { return( ( d & DAY_FILTER ) >> 10 ); }
 
         unsigned int                get_order() const
         { return( m_date & ORDER_FILTER ); }
@@ -206,28 +235,36 @@ class Date
 
         void                        set_year( unsigned int y )
         {
-            m_date &= 0x8007FFFF;
-            m_date |= ( y << 19 );
+            if( y >= YEAR_MIN && y <= YEAR_MAX )
+            {
+                m_date &= YEAR_FILTER_INV;
+                m_date |= ( y << 19 );
+            }
         }
         void                        set_month( unsigned int m )
         {
-            m_date &= 0xFFF87FFF;
             if( m < 13 )
+            {
+                m_date &= MONTH_FILTER_INV;
                 m_date |= ( m << 15 );
+            }
         }
         void                        set_day( unsigned int d )
         {
-            m_date &= 0xFFFF83FF;
             if( d < 32 )
+            {
+                m_date &= DAY_FILTER_INV;
                 m_date |= ( d << 10 );
+            }
         }
         void                        reset_order_0()
-        { m_date &= 0xFFFFFC00; }
+        { m_date &= ORDER_FILTER_INV; }
         void                        reset_order_1()
-        { m_date |= 0x1; m_date &= 0xFFFFFC01; }
-        static void                 reset_order_1( date_t &date )
-        { date |= 0x1; date &= 0xFFFFFC01; }
+        { m_date &= ORDER_FILTER_INV; m_date |= 0x1; }
+        static void                 reset_order_1( date_t& date )
+        { date &= ORDER_FILTER_INV; date |= 0x1; }
 
+        static Result               parse_string( Date::date_t*, const Glib::ustring& );
         Glib::ustring               format_string() const
         { return format_string( m_date, s_date_format_template ); }
         static Glib::ustring        format_string( const date_t date )
@@ -236,35 +273,35 @@ class Date
         static Glib::ustring        format_string_dt( const time_t );
         static Glib::ustring        format_string_d( const time_t );
 
-        static date_t               parse_string( const Glib::ustring& );
-
         bool                        is_valid() const
         {
             return( get_day() > 0 && get_day() <= get_days_in_month() );
         }
-
-        bool                        is_todo() const
-        { return( m_date & TODO_FLAG ); }
-        static bool                 is_todo( const date_t d )
-        { return( d & TODO_FLAG ); }
+        bool                        is_set() const
+        { return( m_date != NOT_SET ); }
 
         bool                        is_ordinal() const
         { return( m_date & ORDINAL_FLAG ); }
         static bool                 is_ordinal( const date_t d )
         { return( d & ORDINAL_FLAG ); }
 
+        bool                        is_hidden() const
+        { return( is_ordinal() && !( m_date & VISIBLE_FLAG ) ); }
+        static bool                 is_hidden( const date_t d )
+        { return( is_ordinal( d ) && !( d & VISIBLE_FLAG ) ); }
+
         void                        forward_months( int months );
         void                        forward_month();
         void                        forward_day();
 
         void                        backward_ordinal_order()
         { if( get_ordinal_order() > 0 ) m_date -= ORDINAL_STEP; }
-        static void                 backward_ordinal_order( Date::date_t &d )
+        static void                 backward_ordinal_order( Date::date_t& d )
         { if( get_ordinal_order( d ) > 0 ) d -= ORDINAL_STEP; }
         void                        forward_ordinal_order()
-        { if( ( m_date & ORDINAL_FILTER ) != TOPIC_MAX ) m_date += ORDINAL_STEP; }
-        static void                 forward_ordinal_order( Date::date_t &d )
-        { if( ( d & ORDINAL_FILTER ) != TOPIC_MAX ) d += ORDINAL_STEP; }
+        { if( ( m_date & ORDINAL_FILTER ) < ORDINAL_LAST ) m_date += ORDINAL_STEP; }
+        static void                 forward_ordinal_order( Date::date_t& d )
+        { if( ( d & ORDINAL_FILTER ) != ORDINAL_LAST ) d += ORDINAL_STEP; }
 
         static date_t               make_year( unsigned int y )
         { return( y << 19 ); }
@@ -275,6 +312,8 @@ class Date
         static date_t               make_date( unsigned int y, unsigned int m, unsigned int d,
                                                unsigned int o = 0 )
         { return( ( y << 19 ) | ( m << 15 ) | ( d << 10 ) | o ); }
+        static date_t               make_date( unsigned int c, unsigned int o = 0 )
+        { return( TOPIC_MIN | ( ( c - 1 ) * ORDINAL_STEP ) | o ); }
 
         unsigned int                calculate_days_between( const Date& ) const;
         unsigned int                calculate_months_between( Date::date_t ) const;
@@ -294,25 +333,31 @@ subtract_months( Date d1, Date d2 )
 */
 
 inline bool
-compare_dates( const Date::date_t &date_l, const Date::date_t &date_r )
+compare_dates( const Date::date_t& date_l, const Date::date_t& date_r )
 {
     return( date_l > date_r );
 }
 
 typedef bool( *FuncCompareDates )( const Date::date_t&, const Date::date_t& ) ;
 
-// GLOBAL FUNCTIONS
+// GLOBAL FUNCTIONS ================================================================================
 void                print_error( const Glib::ustring& );
 void                print_info( const Glib::ustring& );
 
 #if LIFEOGRAPH_DEBUG_BUILD
-#define PRINT_DEBUG( message )  std::cout << "DEBUG: " << message << std::endl
+#define PRINT_DEBUG( msg )  std::cout << "DEBUG: " << msg << std::endl
+#define PRINT_DEBUG2( a1, a2 )  std::cout << "DEBUG: " << a1 << a2 << std::endl
+#define PRINT_DEBUG3( a1, a2, a3 )  std::cout << "DEBUG: " << a1 << a2 << a3 << std::endl
+#define PRINT_DEBUG4( a1, a2, a3, a4 )  std::cout << "DEBUG: " << a1 << a2 << a3 << a4 << std::endl
 #else
-#define PRINT_DEBUG( message )  ;
+#define PRINT_DEBUG( msg )  ;
+#define PRINT_DEBUG2( a1, a2 )  ;
+#define PRINT_DEBUG3( a1, a2, a3 )  ;
+#define PRINT_DEBUG4( a1, a2, a3, a4 )  ;
 #endif
 
 long                convert_string( const std::string& );
-bool                str_ends_with ( const std::string&, std::string const& );
+bool                str_ends_with ( const std::string&, const std::string& );
 
 Gdk::RGBA           contrast2( const Gdk::RGBA&, const Gdk::RGBA&, const Gdk::RGBA& );
 //Gdk::RGBA           contrast( const Gdk::RGBA&, const Gdk::RGBA& ); DEPRECATED
@@ -320,7 +365,7 @@ Gdk::RGBA           midtone( const Gdk::RGBA&, const Gdk::RGBA& );
 Gdk::RGBA           midtone( const Gdk::RGBA&, const Gdk::RGBA&, float );
 
 inline Glib::ustring
-convert_gdkcolor_to_html( const Gdk::RGBA &gdkcolor )
+convert_gdkcolor_to_html( const Gdk::RGBA& gdkcolor )
 {
     // this function's source of inspiration is Geany
     char buffer[ 8 ];
@@ -333,7 +378,7 @@ convert_gdkcolor_to_html( const Gdk::RGBA &gdkcolor )
 }
 
 inline Glib::ustring
-convert_gdkrgba_to_string( const Gdk::RGBA &gdkcolor )
+convert_gdkrgba_to_string( const Gdk::RGBA& gdkcolor )
 {
     char buffer[ 14 ];
     g_snprintf( buffer, 14, "#%04X%04X%04X",
@@ -351,32 +396,11 @@ std::string         get_env_lang();
 Gtk::MenuItem*      create_menuitem_markup( const Glib::ustring&,
                                             const Glib::SignalProxy0< void >::SlotType& );
 
-// COMMON SIGNALS
+// COMMON SIGNALS ==================================================================================
 typedef sigc::signal< void >        SignalVoid;
 typedef std::set< std::string >     ListPaths;
 
-// MEMORY POOL
-template< class T >
-class Pool : public std::list< T* >
-{
-    public:
-        virtual                 ~Pool()
-        { clear(); }
-
-        void                    clear()
-        {
-            for(    typename std::list< T* >::const_iterator iter = this->begin();
-                    iter != this->end();
-                    ++iter )
-            {
-                delete *iter;
-            }
-
-            std::list< T* >::clear();
-        }
-};
-
-
+// ENCRYPTION ======================================================================================
 class Cipher
 {
     public:
@@ -401,9 +425,9 @@ class Cipher
                                             const unsigned char*,
                                             const unsigned char* );
         static void         decrypt_buffer( unsigned char*,
-                                            size_t&,
+                                            size_t,
                                             const unsigned char*,
-                                            const unsigned char * );
+                                            const unsigned char* );
 
     protected:
 
@@ -437,9 +461,11 @@ class EntryClear : public Gtk::Entry
                             EntryClear( BaseObjectType*, const Glib::RefPtr<Gtk::Builder>& );
 
     protected:
-        void                handle_clear_icon( Gtk::EntryIconPosition, const GdkEventButton* );
+        void                handle_icon_press( Gtk::EntryIconPosition, const GdkEventButton* );
+        void                handle_icon_release( Gtk::EntryIconPosition, const GdkEventButton* );
         virtual void        on_changed();
         virtual bool        on_key_release_event( GdkEventKey* );
+        bool                m_pressed;
 };
 
 // MENU 2 ==========================================================================================
@@ -489,55 +515,13 @@ class Menubutton : public Gtk::ToggleButton
     protected:
         bool                on_button_press_event( GdkEventButton* );
 
-        Menu2               *m_menu;
-        Gtk::Label          *m_label;
+        Menu2*              m_menu;
+        Gtk::Label*         m_label;
         sigc::connection    m_connection;
 
     private:
 };
 
-#endif
-
-/*
- * TO BE REWRITTEN IF NEEDED IN THE FUTURE...
-class Menutoolbutton : public Gtk::ToolItem
-{
-    public:
-        Menutoolbutton( const Gtk::StockID&, const std::string&,
-                        Menu2* = NULL, bool = false );
-
-        Menu2*          get_menu();
-
-    protected:
-        void            on_toolbar_reconfigured();
-
-        bool            m_flag_important;
-        Menubutton      m_button;
-};*/
-
-#if( GTKMM_MAJOR_VERSION < 3 )
-
-// FILE FILTERS
-//class FilefilterAny : public Gtk::FileFilter
-//{
-//  public:
-//      FilefilterAny()
-//      {
-//          set_name( _("All Files") );
-//          add_pattern( "*" );
-//      }
-//};
-//
-//class FilefilterDiary : public Gtk::FileFilter
-//{
-//  public:
-//      FilefilterDiary()
-//      {
-//          set_name( _("Diary Files (*.diary)") );
-//          add_mime_type( "application/x-lifeographdiary" );
-//      }
-//};
-
 class MenuitemRecent : public Gtk::MenuItem
 {
     public:
@@ -605,16 +589,37 @@ class FilebuttonRecent : public Menubutton
                                             const Gtk::SelectionData&, guint, guint );
 
     private:
-        Gtk::FileChooserDialog      *m_filechooserdialog;
+        Gtk::FileChooserDialog*     m_filechooserdialog;
         Gtk::Image                  m_icon_new;
         Gtk::Image                  m_icon_browse;
-        ListPaths                   *m_list_recent;
+        ListPaths*                  m_list_recent;
         SignalVoid                  m_signal_selectionchanged;
         SignalVoid                  m_signal_createfile;
 };
 
 #endif
 
+// FILE FILTERS ====================================================================================
+//class FilefilterAny : public Gtk::FileFilter
+//{
+//  public:
+//      FilefilterAny()
+//      {
+//          set_name( _("All Files") );
+//          add_pattern( "*" );
+//      }
+//};
+//
+//class FilefilterDiary : public Gtk::FileFilter
+//{
+//  public:
+//      FilefilterDiary()
+//      {
+//          set_name( _("Diary Files (*.diary)") );
+//          add_mime_type( "application/x-lifeographdiary" );
+//      }
+//};
+
 // DIALOGEVENT =====================================================================================
 class DialogEvent : public Gtk::Dialog
 {
@@ -629,25 +634,13 @@ class DialogEvent : public Gtk::Dialog
 
 };
 
-// COMBOBOXTEXT WITH GTK BUILDER (FOR GTKMM 2) =====================================================
-#if( GTKMM_MAJOR_VERSION < 3 )
-
-class ComboboxEasy : public Gtk::ComboBoxText
-{
-    public:
-                            ComboboxEasy( BaseObjectType* cobject,
-                                          const Glib::RefPtr< Gtk::Builder >& )
-    :   Gtk::ComboBoxText( cobject ) {}
-};
-#endif
-
 // FRAME FOR PRINTING ==============================================================================
 Gtk::Frame* create_frame( const Glib::ustring&, Gtk::Widget& );
 
 // TREEVIEW ========================================================================================
 // scroll_to_row( Path& ) does not work for some reason. So, implemented our own
-bool treepath_is_less( const Gtk::TreePath&, const Gtk::TreePath& );
-bool treepath_is_more( const Gtk::TreePath&, const Gtk::TreePath& );
+bool is_treepath_less( const Gtk::TreePath&, const Gtk::TreePath& );
+bool is_treepath_more( const Gtk::TreePath&, const Gtk::TreePath& );
 
 } // end of namespace HELPERS
 
