@@ -69,6 +69,8 @@ struct Icons
     Glib::RefPtr< Gdk::Pixbuf >     filter_32;
     Glib::RefPtr< Gdk::Pixbuf >     todo_open_16;
     Glib::RefPtr< Gdk::Pixbuf >     todo_open_32;
+    Glib::RefPtr< Gdk::Pixbuf >     todo_progressed_16;
+    Glib::RefPtr< Gdk::Pixbuf >     todo_progressed_32;
     Glib::RefPtr< Gdk::Pixbuf >     todo_done_16;
     Glib::RefPtr< Gdk::Pixbuf >     todo_done_32;
     Glib::RefPtr< Gdk::Pixbuf >     todo_canceled_16;
@@ -115,18 +117,6 @@ class Lifeograph : public Gtk::Application
                 bool,
                 Glib::RefPtr< Gtk::Action >&,
                 const Glib::ustring&,
-                const Gtk::StockID&,
-                const Glib::ustring&,
-                const Glib::ustring&,
-                const Gtk::AccelKey&,
-                const Glib::SignalProxy0< void >::SlotType&,
-                Gtk::Activatable* = NULL );
-
-        static void                 create_action(
-                bool,
-                Glib::RefPtr< Gtk::Action >&,
-                const Glib::ustring&,
-                const Glib::ustring&,
                 const Glib::ustring&,
                 const Glib::ustring&,
                 const Gtk::AccelKey&,
@@ -139,22 +129,12 @@ class Lifeograph : public Gtk::Application
                 const Glib::ustring&,
                 const Glib::ustring&,
                 const Glib::ustring&,
-                const Glib::ustring&,
                 const Gtk::AccelKey&,
                 const Glib::SignalProxy0< void >::SlotType&,
                 Gtk::Activatable* = NULL );
 
         bool                        load_gui( const std::string& );
 
-        // AUTO LOGOUT FUNCTIONALITY
-        bool                        handle_idle();
-        void                        handle_event();
-        void                        freeze_auto_logout();
-        void                        unfreeze_auto_logout();
-
-        int                         m_seconds_remaining;
-        sigc::connection            m_connection_timeout;
-
         static SignalVoid           s_signal_logout;
 
         static int                  m_internaloperation;
@@ -195,8 +175,6 @@ class Lifeograph : public Gtk::Application
         bool                        m_flag_open_directly;
         bool                        m_flag_read_only; // for command-line supplied file
 
-        bool                        m_flag_auto_logout_frozen;
-
     protected:
         static void                 fill_lang_list_cb( const char* const l, const char* const,
                                                        const char* const, const char* const,
