@@ -35,29 +35,46 @@
 
 using namespace LIFEO;
 
+// TEMPORARY: until SearchEntry::signal_search_changed() is implemented in Gtkmm
+void handle_search_changed_tmp( GtkSearchEntry* entry, gpointer data )
+{
+    PanelDiary* pd( reinterpret_cast< PanelDiary* >( data ) );
+    pd->handle_search_string_changed();
+}
 
 PanelDiary::PanelDiary()
 : m_entry_count( 0 )
 {
-    Gtk::Button *button_today;
+    Gtk::Button* button_today;
     try
     {
-        Lifeograph::builder->get_widget( "button_logout", m_button_logout );
-        Lifeograph::builder->get_widget( "button_today", button_today );
+        Lifeograph::builder->get_widget( "G_elem_header", m_grid_elem_header );
+        Lifeograph::builder->get_widget( "Bx_new_elem", m_Bx_new_elem );
+        Lifeograph::builder->get_widget( "B_today", button_today );
+        Lifeograph::builder->get_widget( "MB_diary_add", m_MB_add );
+        Lifeograph::builder->get_widget( "MI_add_entry", m_menuitem_add_entry );
+        Lifeograph::builder->get_widget( "MI_add_topic", m_menuitem_add_topic );
+        Lifeograph::builder->get_widget( "MI_add_group", m_menuitem_add_group );
+        Lifeograph::builder->get_widget( "MI_add_chapter", m_menuitem_add_chapter );
 
-        Gtk::MenuButton *mb_tools;
-        Lifeograph::builder->get_widget( "menubutton_tools", mb_tools );
-        Lifeograph::builder->get_widget( "menuitem_sort_by_date", m_menuitem_sort_by_date );
-        Lifeograph::builder->get_widget( "menuitem_sort_by_size", m_menuitem_sort_by_size );
-        Lifeograph::builder->get_widget( "menuitem_sort_by_change", m_menuitem_sort_by_change );
+        Lifeograph::builder->get_widget( "Bx_logout", m_Bx_logout );
+        Lifeograph::builder->get_widget( "B_logout", m_button_logout );
+        Lifeograph::builder->get_widget( "MB_logout", m_MB_logout );
+        Lifeograph::builder->get_widget( "MI_logout_disable", m_MI_logout_disable_auto );
+        Lifeograph::builder->get_widget( "MI_logout_wo_saving", m_MI_logout_wo_saving );
 
-        Lifeograph::builder->get_widget_derived( "entry_search", m_entry_search );
-        Lifeograph::builder->get_widget_derived( "entry_replace", m_entry_replace );
-        Lifeograph::builder->get_widget( "button_match_prev", m_button_match_prev );
-        Lifeograph::builder->get_widget( "button_match_next", m_button_match_next );
-        Lifeograph::builder->get_widget( "grid_replace", m_grid_replace );
-        Lifeograph::builder->get_widget( "button_replace", m_button_replace );
-        Lifeograph::builder->get_widget( "button_replace_all", m_button_replace_all );
+        Lifeograph::builder->get_widget( "MB_tools", m_button_tools );
+        Lifeograph::builder->get_widget( "MI_sort_by_date", m_menuitem_sort_by_date );
+        Lifeograph::builder->get_widget( "MI_sort_by_size", m_menuitem_sort_by_size );
+        Lifeograph::builder->get_widget( "MI_sort_by_change", m_menuitem_sort_by_change );
+
+        Lifeograph::builder->get_widget( "E_search", m_E_search );
+        Lifeograph::builder->get_widget_derived( "E_replace", m_E_replace );
+        Lifeograph::builder->get_widget( "B_match_prev", m_B_match_prev );
+        Lifeograph::builder->get_widget( "B_match_next", m_B_match_next );
+        Lifeograph::builder->get_widget( "G_replace", m_G_replace );
+        Lifeograph::builder->get_widget( "B_replace", m_B_replace );
+        Lifeograph::builder->get_widget( "B_replace_all", m_B_replace_all );
 
         // FALLBACK ICON FOR SYSTEMS WITHOUT SYMBOLIC ICONS
         Glib::RefPtr< Gtk::IconTheme > theme = Gtk::IconTheme::get_default();
@@ -66,17 +83,16 @@ PanelDiary::PanelDiary()
         {
             Glib::RefPtr< Gdk::Pixbuf > icon_tools = theme->load_icon( "gtk-preferences", 16 );
             Gtk::Image *img_tools = Gtk::manage( new Gtk::Image( icon_tools ) );
-            mb_tools->set_image( *img_tools );
+            m_button_tools->set_image( *img_tools );
         }
 
         Lifeograph::builder->get_widget( "calendar_main", m_calendar );
         Lifeograph::builder->get_widget_derived( "treeview_main", m_treeview_entries );
 
-        Lifeograph::builder->get_widget( "menubutton_diary_add", m_button_add );
-        Lifeograph::builder->get_widget( "mnitem_add_entry", m_menuitem_add_entry );
-        Lifeograph::builder->get_widget( "mnitem_add_topic", m_menuitem_add_topic );
-        Lifeograph::builder->get_widget( "mnitem_add_todo_group", m_menuitem_add_todo_group );
-        Lifeograph::builder->get_widget( "mnitem_add_chapter", m_menuitem_add_chapter );
+        m_PO_replace.add( *m_G_replace );
+        m_PO_replace.set_relative_to( *m_E_search );
+        m_PO_replace.set_modal( false );
+        m_PO_replace.set_opacity( 0.9 );
     }
     catch( ... )
     {
@@ -119,51 +135,59 @@ PanelDiary::PanelDiary()
             sigc::mem_fun( this, &PanelDiary::handle_add_entry ) );
     m_menuitem_add_topic->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_topic ) );
-    m_menuitem_add_todo_group->signal_activate().connect(
-            sigc::mem_fun( this, &PanelDiary::handle_add_todo_group ) );
+    m_menuitem_add_group->signal_activate().connect(
+            sigc::mem_fun( this, &PanelDiary::handle_add_group ) );
     m_menuitem_add_chapter->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_chapter ) );
 
-    m_entry_search->signal_changed().connect(
+    m_E_search->signal_changed().connect(
             sigc::mem_fun( this, &PanelDiary::handle_search_string_changed ) );
-    m_entry_search->signal_activate().connect(
+
+    g_signal_connect( m_E_search->gobj(), "search-changed",
+                      ( GCallback ) handle_search_changed_tmp, this );
+    m_E_search->signal_activate().connect(
             sigc::mem_fun( AppWindow::p->panel_diary, &PanelDiary::go_next_match ) );
 
-    m_entry_replace->signal_activate().connect(
+    m_E_replace->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::replace_match ) );
-    m_button_replace->signal_clicked().connect(
+    m_B_replace->signal_clicked().connect(
             sigc::mem_fun( this, &PanelDiary::replace_match ) );
-    m_button_replace_all->signal_clicked().connect(
+    m_B_replace_all->signal_clicked().connect(
             sigc::mem_fun( this, &PanelDiary::replace_all_matches ) );
 
+    m_MI_logout_disable_auto->signal_activate().connect(
+            sigc::mem_fun( this, &PanelDiary::handle_disable_auto_logout_toggled ) );
+    m_MI_logout_wo_saving->signal_activate().connect(
+            sigc::bind( sigc::mem_fun( AppWindow::p, &AppWindow::logout ), false ) );
+
     // ACTIONS
     Lifeograph::create_action(
-            true, m_action_today, "Today", "x-office-calendar", _( "Today" ),
+            true, m_action_today, "Today", _( "Today" ),
             _( "Go to today (creates a new entry if there isn't any or when already at today)" ),
             Gtk::AccelKey( GDK_KEY_d, Gdk::CONTROL_MASK ),
             sigc::mem_fun( this, &PanelDiary::show_today ),
             button_today );
 
     Lifeograph::create_action(
-            false, m_action_previous_list, "ListPrevious", Gtk::Stock::GO_UP, _( "Previous" ),
+            false, m_action_previous_list, "ListPrevious", _( "Previous" ),
             _( "Go to the previous entry in the list" ),
             Gtk::AccelKey( GDK_KEY_Page_Up, Gdk::CONTROL_MASK ),
             sigc::bind( sigc::mem_fun( m_treeview_entries, &WidgetEntryList::go_up ), false ) );
 
     Lifeograph::create_action(
-            false, m_action_next_list, "ListNext", Gtk::Stock::GO_DOWN, _( "Next" ),
+            false, m_action_next_list, "ListNext", _( "Next" ),
             _( "Go to the next entry in the list" ),
             Gtk::AccelKey( GDK_KEY_Page_Down, Gdk::CONTROL_MASK ),
             sigc::bind( sigc::mem_fun( m_treeview_entries, &WidgetEntryList::go_down ), false ) );
 
     Lifeograph::create_action(
-            false, m_action_jump2current, "Jump", Gtk::Stock::JUMP_TO,
+            false, m_action_jump2current, "Jump",
             "", "",     // no grachical interface yet!
             Gtk::AccelKey( GDK_KEY_j, Gdk::CONTROL_MASK ),
             sigc::mem_fun( this, &PanelDiary::present_current_row ) );
 
     Lifeograph::create_action(
-            false, m_action_show_prev_session_elem, "PrevSessElem", Gtk::Stock::JUMP_TO,
+            false, m_action_show_prev_session_elem, "PrevSessElem",
             "", "",     // no grachical interface yet!
             Gtk::AccelKey( GDK_KEY_l, Gdk::CONTROL_MASK ),
             sigc::mem_fun( this, &PanelDiary::show_prev_session_elem ) );
@@ -178,91 +202,45 @@ PanelDiary::PanelDiary()
     // ACTIONS
     Lifeograph::create_action(
             false, m_action_focusfilter, "FocusFilter",
-            Gtk::Stock::FIND, "", "",     // no grachical interface yet!
+            "", "",     // no grachical interface yet!
             Gtk::AccelKey( GDK_KEY_f, Gdk::CONTROL_MASK ),
-            sigc::mem_fun( m_entry_search, &Gtk::Widget::grab_focus ) );
+            sigc::mem_fun( m_E_search, &Gtk::Widget::grab_focus ) );
 
     Lifeograph::create_action(
-            false, m_action_previous_match, "MatchPrevious", Gtk::Stock::GO_BACK,
+            false, m_action_previous_match, "MatchPrevious",
 // TRANSLATORS: label and tooltip of the go-to-previous-match-of-filtered-text action
             _( "Previous Match" ),
             _( "Go to previous match" ),
             Gtk::AccelKey( GDK_KEY_F3, Gdk::SHIFT_MASK ),
             sigc::mem_fun( this, &PanelDiary::go_prev_match ),
-            m_button_match_prev );
+            m_B_match_prev );
 
     Lifeograph::create_action(
-            false, m_action_next_match, "MatchNext", Gtk::Stock::GO_FORWARD,
+            false, m_action_next_match, "MatchNext",
 // TRANSLATORS: label and tooltip of the go-to-next-match-of-filtered-text action
             _( "Next Match" ),
             _( "Go to next match" ),
             Gtk::AccelKey( GDK_KEY_F3, Gdk::ModifierType( 0 ) ),
             sigc::mem_fun( this, &PanelDiary::go_next_match ),
-            m_button_match_next );
-
-    // becoming proxy widgets makes them visible:
-    m_button_match_prev->set_visible( false );
-    m_button_match_next->set_visible( false );
+            m_B_match_next );
 }
 
-void
-PanelDiary::add_chapter_category_to_list( const CategoryChapters* chapters )
+inline void
+fill_elem_row( Gtk::TreeRow& row, DiaryElement* elem )
 {
-    Gtk::TreeRow	row_container;
-    Chapter			*chapter = NULL;
-
-    for( CategoryChapters::const_iterator iter_chapter = chapters->begin();
-         iter_chapter != chapters->end();
-         ++iter_chapter )
-    {
-        chapter = iter_chapter->second;
-        if( ! chapter->is_initialized() )
-            continue;
-
-        // show all folders even when they are empty:
-        row_container = * m_treeview_entries->m_treestore->append( l_row_diary.children() );
-        row_container[ ListData::colrec->ptr ] = chapter;	// ptr must be first:
-        row_container[ ListData::colrec->info ] = chapter->get_list_str();
-        row_container[ ListData::colrec->icon ] = chapter->get_icon();
-
-        chapter->reset_size();
-
-        if( l_entry == NULL )
-            continue;
-
-        while( l_entry->get_date() >= chapter->get_date() )
-        {
-            chapter->increase_size();
-            if( l_entry->get_filtered_out() == false )
-            {
-                m_entry_count++;
-                l_row_entry = * m_treeview_entries->m_treestore->append(
-                        row_container.children() );
-                l_row_entry[ ListData::colrec->ptr ] = l_entry;
-                l_row_entry[ ListData::colrec->icon ] = l_entry->get_icon();
-                l_row_entry[ ListData::colrec->info ] = l_entry->get_list_str();
-            }
-
-            ++l_itr_entry;
-            if( l_itr_entry != Diary::d->m_entries.end() )
-                l_entry = l_itr_entry->second;
-            else
-            {
-                l_entry = NULL;
-                break;
-            }
-        }
-    }
+    row[ ListData::colrec->ptr ] = elem; // ptr must be first
+    row[ ListData::colrec->info ] = elem->get_list_str();
+    row[ ListData::colrec->icon ] = elem->get_icon();
 }
 
 void
-PanelDiary::fill_child_rows( const Gtk::TreeModel::Children& children )
+PanelDiary::fill_treepaths( const Gtk::TreeModel::Children& children )
 {
     for( Gtk::TreeModel::Children::const_iterator iter = children.begin();
             iter != children.end(); ++iter )
     {
         Gtk::TreeModel::Row row = *iter;
-        DiaryElement *ptr = row[ ListData::colrec->ptr ];
+        DiaryElement* ptr = row[ ListData::colrec->ptr ];
 
         if( ptr )
             ptr->m_list_data->treepath = m_treeview_entries->m_treestore->get_path( row );
@@ -271,7 +249,7 @@ PanelDiary::fill_child_rows( const Gtk::TreeModel::Children& children )
         {
             case DiaryElement::ET_CHAPTER:
             case DiaryElement::ET_TOPIC:
-            case DiaryElement::ET_TODO_GRP:
+            case DiaryElement::ET_GROUP:
                 if( dynamic_cast< Chapter* >( ptr )->get_expanded() )
                     m_treeview_entries->expand_to_path( ptr->m_list_data->treepath );
                 break;
@@ -279,7 +257,40 @@ PanelDiary::fill_child_rows( const Gtk::TreeModel::Children& children )
                 break;
         }
 
-        fill_child_rows( row.children() );
+        fill_treepaths( row.children() );
+    }
+}
+
+void
+PanelDiary::add_chapter_category_to_list( const CategoryChapters* chapters )
+{
+    Gtk::TreeRow    row_container;
+    Gtk::TreeRow    row_entry;
+    Chapter*        chapter = NULL;
+    Entry*          entry = NULL;
+
+    for( CategoryChapters::const_iterator iter_chapter = chapters->begin();
+         iter_chapter != chapters->end();
+         ++iter_chapter )
+    {
+        chapter = iter_chapter->second;
+
+        // show all folders even when they are empty:
+        row_container = * m_treeview_entries->m_treestore->append( l_row_diary.children() );
+        fill_elem_row( row_container, chapter );
+
+        for( Chapter::Set::iterator iter_entry = chapter->begin();
+             iter_entry != chapter->end(); ++iter_entry )
+        {
+            entry = *iter_entry;
+
+            if( entry->get_filtered_out() == false )
+            {
+                m_entry_count++;
+                row_entry = * m_treeview_entries->m_treestore->append( row_container.children() );
+                fill_elem_row( row_entry, entry );
+            }
+        }
     }
 }
 
@@ -291,45 +302,54 @@ PanelDiary::update_entry_list()
 
     AppWindow::p->m_entry_view->sync();
 
-    l_itr_entry = Diary::d->m_entries.begin();
-    l_entry = ( l_itr_entry != Diary::d->m_entries.end() ? l_itr_entry->second : NULL );
-
-    m_treeview_entries->m_treestore->clear();
-    m_entry_count = 0;
-
     // REMOVE MODEL AND DISBLE SORTING FOR SPEED-UP
     m_treeview_entries->unset_model();
     m_treeview_entries->m_treestore->set_sort_column(
             Gtk::TreeSortable::DEFAULT_UNSORTED_COLUMN_ID, Gtk::SORT_ASCENDING );
 
+    m_treeview_entries->m_treestore->clear();
+    m_entry_count = 0;
+
     // DIARY ITEM
     l_row_diary = * m_treeview_entries->m_treestore->append();
-    l_row_diary[ ListData::colrec->ptr ] = Diary::d; // ptr must be first
-    l_row_diary[ ListData::colrec->info ] = Diary::d->get_list_str();
-    l_row_diary[ ListData::colrec->icon ] = Lifeograph::icons->diary_16;
+    fill_elem_row( l_row_diary, Diary::d );
 
     // CHAPTERS
-    if( Diary::d->get_sorting_criteria() == SC_DATE /* TODO: maybe later: &&
-        !( Diary::d->get_filtering_status() & Filter::FS_FILTER_TRASH )*/ )
+    if( Diary::d->get_sorting_criteria() == SC_DATE )
     {
-        add_chapter_category_to_list( Diary::d->get_todo_groups() );
         add_chapter_category_to_list( Diary::d->get_topics() );
+        add_chapter_category_to_list( Diary::d->get_groups() );
         add_chapter_category_to_list( Diary::d->get_current_chapter_ctg() );
-    }
 
-    // ENTRIES NOT PART OF A CHAPTER
-    for( ; l_itr_entry != Diary::d->m_entries.end(); ++l_itr_entry )
-    {
-        l_entry = ( *l_itr_entry ).second;
-        if( l_entry->get_filtered_out() == false )
+        // ENTRIES NOT PART OF A CHAPTER (ORPHANED)
+        for( EntrySetIter iter = Diary::d->m_orphans.begin();
+             iter != Diary::d->m_orphans.end(); ++iter )
         {
-            m_entry_count++;
+            Entry* entry = *iter;
+            if( entry->get_filtered_out() == false )
+            {
+                m_entry_count++;
+                Gtk::TreeRow row = * m_treeview_entries->m_treestore->append(
+                        l_row_diary.children() );
+                fill_elem_row( row, entry );
+            }
+
+        }
+    }
+    else
+    {
+        for( EntryIter iter = Diary::d->m_entries.begin();
+             iter != Diary::d->m_entries.end(); ++iter )
+        {
+            Entry* entry( iter->second );
+            if( entry->get_filtered_out() == false )
+            {
+                m_entry_count++;
+                Gtk::TreeRow row = * m_treeview_entries->m_treestore->append(
+                        l_row_diary.children() );
+                fill_elem_row( row, entry );
+            }
 
-            l_row_entry = *m_treeview_entries->m_treestore->append(
-                    l_row_diary.children() );
-            l_row_entry[ ListData::colrec->ptr ] = l_entry; // ptr must be first
-            l_row_entry[ ListData::colrec->icon ] = l_entry->get_icon();
-            l_row_entry[ ListData::colrec->info ] = l_entry->get_list_str();
         }
     }
 
@@ -338,8 +358,8 @@ PanelDiary::update_entry_list()
             Gtk::TreeSortable::DEFAULT_SORT_COLUMN_ID, Gtk::SORT_ASCENDING );
     m_treeview_entries->set_model( m_treeview_entries->m_treestore );
 
-    // set treepath values in of listed elements
-    fill_child_rows( m_treeview_entries->m_treestore->children() );
+    // set treepath values of listed elements
+    fill_treepaths( m_treeview_entries->m_treestore->children() );
 
     // always expand diary
     m_treeview_entries->expand_element( Diary::d );
@@ -425,6 +445,19 @@ PanelDiary::update_calendar()
 void
 PanelDiary::handle_login()
 {
+    m_MB_logout->set_visible( Diary::d->is_encrypted() || ! Diary::d->is_read_only() );
+    m_MI_logout_disable_auto->set_visible( Diary::d->is_encrypted() );
+    m_MI_logout_wo_saving->set_visible( ! Diary::d->is_read_only() );
+    update_disable_auto_logout_MI();
+
+    static Gtk::Label *dummy_title = new Gtk::Label;
+    AppWindow::p->m_headerbar.pack_start( *m_Bx_new_elem );
+    AppWindow::p->m_headerbar.set_custom_title( *dummy_title );
+    AppWindow::p->m_headerbar.pack_start( *m_grid_elem_header );
+    AppWindow::p->m_headerbar.pack_end( *m_Bx_logout );
+    AppWindow::p->m_headerbar.pack_end( *m_button_tools );
+    AppWindow::p->m_headerbar.pack_end( *m_E_search );
+
     switch( Diary::d->get_sorting_criteria() )
     {
         default: // future-proofing
@@ -456,7 +489,7 @@ PanelDiary::handle_login()
 
     update_entry_list();
 
-    m_button_add->set_visible( ! Diary::d->is_read_only() );
+    m_MB_add->set_visible( ! Diary::d->is_read_only() );
 }
 
 void
@@ -464,14 +497,19 @@ PanelDiary::handle_logout()
 {
     Lifeograph::m_internaloperation++;
 
+    m_PO_replace.hide();
+
+    AppWindow::p->m_headerbar.remove( *m_Bx_new_elem );
+    gtk_header_bar_set_custom_title( AppWindow::p->m_headerbar.gobj(), NULL );
+    AppWindow::p->m_headerbar.remove( *m_grid_elem_header );
+    AppWindow::p->m_headerbar.remove( *m_Bx_logout );
+    AppWindow::p->m_headerbar.remove( *m_button_tools );
+    AppWindow::p->m_headerbar.remove( *m_E_search );
+
     m_treeview_entries->clear();
 
-    m_entry_search->set_text( "" );
-    m_entry_replace->set_text( "" );
-
-    m_button_match_prev->hide();
-    m_button_match_next->hide();
-    m_grid_replace->hide();
+    m_E_search->set_text( "" );
+    m_E_replace->set_text( "" );
 
     Lifeograph::m_internaloperation--;
 }
@@ -481,8 +519,8 @@ PanelDiary::show( const DiaryElement* element )
 {
     if( element->get_type() >= DiaryElement::ET_DIARY ) // if a list element
         m_treeview_entries->present_element( element );
-    else
-        m_treeview_entries->get_selection()->unselect_all();
+    //else - selected rows on the list no longer have any relation with the current view
+        //m_treeview_entries->get_selection()->unselect_all();
 
     if( element->get_type() > DiaryElement::ET_DIARY )
     {
@@ -491,8 +529,8 @@ PanelDiary::show( const DiaryElement* element )
 
         if( element->get_date().is_ordinal() )
         {
-            Chapter *c = element->get_date().is_todo() ?
-                    Diary::d->get_todo_groups()->get_chapter( element->get_date().get_pure() ) :
+            Chapter* c = element->get_date().is_hidden() ?
+                    Diary::d->get_groups()->get_chapter( element->get_date().get_pure() ) :
                     Diary::d->get_topics()->get_chapter( element->get_date().get_pure() );
             if( c == NULL )
                 m_menuitem_add_entry->set_sensitive( false );
@@ -511,8 +549,8 @@ PanelDiary::show( const DiaryElement* element )
                     Glib::ustring::compose( _( "Create a new chapter on %1" ),
                                             element->get_date().format_string() ) );
             m_menuitem_add_chapter->set_sensitive(
-                    Diary::d->get_current_chapter_ctg()->get_chapter( element->get_date().m_date )
-                    == NULL );
+                    Diary::d->get_current_chapter_ctg()->get_chapter(
+                            element->get_date().get_pure() ) == NULL );
         }
     }
     else
@@ -521,7 +559,7 @@ PanelDiary::show( const DiaryElement* element )
         m_menuitem_add_entry->set_sensitive( false );
         m_menuitem_add_chapter->set_sensitive( false );
 
-        m_menuitem_add_entry->set_tooltip_text( _( "Please select a date or topic" ) );
+        m_menuitem_add_entry->set_tooltip_text( _( "Please select a date or chapter" ) );
         m_menuitem_add_chapter->set_tooltip_text( _( "Please select a date" ) );
     }
 }
@@ -583,11 +621,7 @@ PanelDiary::handle_calendar_dayselected()
     m_calendar->get_date( year, month, day );
     Date date( year, month + 1, day );
 
-    m_menuitem_add_entry->set_sensitive( day > 0 );
-    m_menuitem_add_chapter->set_sensitive( day > 0 &&
-            Diary::d->get_current_chapter_ctg()->get_chapter( date.m_date ) == NULL );
-
-    Entry *entry;
+    Entry* entry;
     if( date.m_date == ( AppWindow::p->panel_main->get_cur_elem()->get_date().get_pure() ) )
     {
         entry = Diary::d->get_entry_next_in_day(
@@ -602,6 +636,10 @@ PanelDiary::handle_calendar_dayselected()
         entry->show();
     else
     {
+        m_menuitem_add_entry->set_sensitive( bool( day > 0 ) );
+        m_menuitem_add_chapter->set_sensitive( bool ( day > 0 &&
+                Diary::d->get_current_chapter_ctg()->get_chapter( date.m_date ) == NULL ) );
+
         m_menuitem_add_entry->set_tooltip_text(
                 Glib::ustring::compose( _( "Create a new entry on %1" ), date.format_string() ) );
         m_menuitem_add_chapter->set_tooltip_text(
@@ -636,7 +674,7 @@ PanelDiary::handle_add_entry()
     else
         date.m_date = Date::make_date( year, month + 1, day );
 
-    Entry *entry( Diary::d->create_entry( date.m_date ) );
+    Entry* entry( Diary::d->create_entry( date.m_date ) );
 
     update_entry_list();
     update_calendar();
@@ -650,9 +688,10 @@ PanelDiary::handle_add_entry()
 }
 
 void
-PanelDiary::handle_add_todo_group()
+PanelDiary::handle_add_group()
 {
-    Chapter *c( Diary::d->add_todo_group( _( "New todo group" ) ) );
+    Chapter *c( Diary::d->get_groups()->create_chapter_ordinal( _( STRING::NEW_CHAPTER_NAME ) ) );
+    Diary::d->update_entries_in_chapters();
     update_entry_list();
     c->show();
     AppWindow::p->panel_main->start_title_edit();
@@ -661,7 +700,8 @@ PanelDiary::handle_add_todo_group()
 void
 PanelDiary::handle_add_topic()
 {
-    Chapter *c( Diary::d->add_topic( _( "New topic" ) ) );
+    Chapter *c( Diary::d->get_topics()->create_chapter_ordinal( _( STRING::NEW_CHAPTER_NAME ) ) );
+    Diary::d->update_entries_in_chapters();
     update_entry_list();
     c->show();
     AppWindow::p->panel_main->start_title_edit();
@@ -679,6 +719,7 @@ PanelDiary::handle_add_chapter()
         Chapter *c( Diary::d->get_current_chapter_ctg()->create_chapter(
                 _( "Untitled chapter" ), date ) );
 
+        Diary::d->update_entries_in_chapters();
         update_entry_list();
         c->show();
         AppWindow::p->panel_main->start_title_edit();
@@ -783,7 +824,7 @@ PanelDiary::handle_treeview_row_expanded( const Gtk::TreeIter& iter,
     {
         case DiaryElement::ET_CHAPTER:
         case DiaryElement::ET_TOPIC:
-        case DiaryElement::ET_TODO_GRP:
+        case DiaryElement::ET_GROUP:
         {
             Chapter* chapter = dynamic_cast< Chapter* >( element );
             chapter->set_expanded( m_treeview_entries->row_expanded( path ) );
@@ -803,7 +844,7 @@ PanelDiary::handle_search_string_changed()
     // ...changes since it was selected:
     //AppWindow::p->m_entry_view->sync(); update_entry_list() does the syncing
 
-    const std::string filterstring( m_entry_search->get_text().lowercase() );
+    const std::string filterstring( m_E_search->get_text().lowercase() );
 
     Diary::d->set_search_text( filterstring );
     AppWindow::p->panel_diary->update_entry_list();    // syncs current entry
@@ -817,7 +858,7 @@ PanelDiary::handle_search_string_changed()
                 AppWindow::p->m_entry_view->get_buffer()->select_searchstr_next();
         }
 
-        m_entry_search->set_tooltip_markup(
+        m_E_search->set_tooltip_markup(
                 Glib::ustring::compose(
                         _( "Found in <b>%1</b> of <b>%2</b> entrie(s)" ),
                         AppWindow::p->panel_diary->get_entry_count(), Diary::d->get_size() ) );
@@ -825,23 +866,20 @@ PanelDiary::handle_search_string_changed()
     else
     {
         AppWindow::p->m_entry_view->get_buffer()->set_search_str( "" );
-        m_entry_search->set_tooltip_text( _( "Enter text to be filtered" ) );
+        m_E_search->set_tooltip_text( _( "Search text within entries" ) );
     }
 
     AppWindow::p->panel_diary->update_calendar();
 
     if( AppWindow::p->panel_diary->get_entry_count() < 1 || filterstring.size() < 1 )
-    {
-        m_button_match_prev->hide();
-        m_button_match_next->hide();
-        m_grid_replace->hide();
-    }
+        m_PO_replace.hide();
     else
     {
-        m_button_match_prev->show();
-        m_button_match_next->show();
-        if( ! Diary::d->is_read_only() )
-            m_grid_replace->show();
+        m_PO_replace.show();
+        bool show_replace( ! Diary::d->is_read_only() );
+        m_E_replace->set_visible( show_replace );
+        m_B_replace->set_visible( show_replace );
+        m_B_replace_all->set_visible( show_replace );
     }
 }
 
@@ -853,7 +891,7 @@ PanelDiary::replace_match()
     if( AppWindow::p->m_entry_view->get_buffer()->get_has_selection() )
     {
         AppWindow::p->m_entry_view->get_buffer()->erase_selection();
-        AppWindow::p->m_entry_view->get_buffer()->insert_at_cursor( m_entry_replace->get_text() );
+        AppWindow::p->m_entry_view->get_buffer()->insert_at_cursor( m_E_replace->get_text() );
         AppWindow::p->panel_diary->go_next_match();
     }
 }
@@ -863,7 +901,7 @@ PanelDiary::replace_all_matches()
 {
     AppWindow::p->m_entry_view->sync();
 
-    Diary::d->replace_text( m_entry_replace->get_text() );
+    Diary::d->replace_text( m_E_replace->get_text() );
     // update current entry:
     if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
     {
@@ -872,3 +910,23 @@ PanelDiary::replace_all_matches()
     }
 }
 
+// AUTO LOGOUT
+void
+PanelDiary::handle_disable_auto_logout_toggled()
+{
+    if( AppWindow::p->is_auto_logout_in_use() )
+        AppWindow::p->freeze_auto_logout();
+    else
+        AppWindow::p->unfreeze_auto_logout();
+
+    update_disable_auto_logout_MI();
+}
+
+void
+PanelDiary::update_disable_auto_logout_MI()
+{
+    if( AppWindow::p->is_auto_logout_in_use() )
+        m_MI_logout_disable_auto->set_label( _( "Disable Auto Logout for This Session" ) );
+    else
+        m_MI_logout_disable_auto->set_label( _( "Re-enable Auto Logout" ) );
+}
