@@ -36,8 +36,7 @@ using namespace LIFEO;
 class ListHeader : public DiaryElement
 {
     public:
-                                    ListHeader( DiaryElement::Type type )
-        : DiaryElement( NULL, ES::VOID ), m_type( type ) {}
+                                    ListHeader( DiaryElement::Type type ) : m_type( type ) {}
 
         void                        show() {}
 
@@ -53,11 +52,8 @@ class ListHeader : public DiaryElement
 static ListHeader s_header( DiaryElement::ET_HEADER ), s_none( DiaryElement::ET_NONE );
 
 // TAG PANEL =======================================================================================
-// STATIC MEMBERS
-PanelExtra::Colrec*     PanelExtra::colrec;
-
 PanelExtra::PanelExtra( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& )
-:   Gtk::TreeView( cobject ), m_treestore_all_tags( NULL )
+:   Gtk::TreeView( cobject ), m_treestore( NULL )
 {
     Gtk::CellRendererPixbuf* cellr_icon( NULL );
     Gtk::CellRendererPixbuf* cellr_filter( NULL );
@@ -66,8 +62,6 @@ PanelExtra::PanelExtra( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder
 
     try
     {
-        colrec = new Colrec;
-
         cellr_icon = Gtk::manage( new Gtk::CellRendererPixbuf );
         cellr_filter = Gtk::manage( new Gtk::CellRendererPixbuf );
         cellr_name = Gtk::manage( new Gtk::CellRendererText );
@@ -80,20 +74,21 @@ PanelExtra::PanelExtra( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder
         throw LIFEO::Error( "Failed to create the extra panel" );
     }
 
+    m_treestore = TreeStoreExtra::create();
+
     cellr_name->property_ellipsize() = Pango::ELLIPSIZE_END;
 
     column->pack_start( *cellr_icon, false );
     column->pack_start( *cellr_name );
     column->pack_start( *cellr_filter, false );
 
-    column->add_attribute( cellr_icon->property_pixbuf(), PanelExtra::colrec->icon );
-    column->add_attribute( cellr_name->property_markup(), PanelExtra::colrec->name );
-    column->add_attribute( cellr_filter->property_pixbuf(), PanelExtra::colrec->filter );
+    column->add_attribute( cellr_icon->property_pixbuf(), m_treestore->colrec.icon );
+    column->add_attribute( cellr_name->property_markup(), m_treestore->colrec.name );
+    column->add_attribute( cellr_filter->property_pixbuf(), m_treestore->colrec.filter );
 
-    m_treestore_all_tags = Gtk::TreeStore::create( *PanelExtra::colrec );
 
     // ALL TAGS
-    this->set_model( m_treestore_all_tags );
+    this->set_model( m_treestore );
     column->set_cell_data_func( *cellr_icon,
                                 sigc::mem_fun( this, &PanelExtra::cell_data_func_icon ) );
     column->set_cell_data_func( *cellr_name,
@@ -105,20 +100,18 @@ PanelExtra::PanelExtra( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder
 
     this->append_column( *column );
 
-    this->override_background_color(
-            AppWindow::p->get_style_context()->get_background_color( Gtk::STATE_FLAG_NORMAL ),
-            Gtk::STATE_FLAG_NORMAL );
-    this->override_background_color(
-            AppWindow::p->get_style_context()->get_background_color( Gtk::STATE_FLAG_SELECTED ),
-            Gtk::STATE_FLAG_SELECTED );
+    // STYLE
+    const Glib::ustring data( "GtkTreeView { background-color: transparent } "
+                              "GtkTreeView:Selected { color: #bb3333; "
+                                                     "background-color: #dddddd }" );
+    Glib::RefPtr< Gtk::CssProvider > css = Gtk::CssProvider::create();
+    if( css->load_from_data( data ) )
+        this->get_style_context()->add_provider( css, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION );
 
     // SIGNALS
     this->signal_row_activated().connect(
             sigc::mem_fun( this, &PanelExtra::handle_treeview_row_activated ) );
 
-    this->signal_drag_begin().connect_notify(
-            sigc::mem_fun( this, &PanelExtra::handle_treeview_drag_begin ) );
-
     this->signal_row_expanded().connect(
             sigc::mem_fun( this, &PanelExtra::handle_treeview_row_expanded ) );
     this->signal_row_collapsed().connect(
@@ -140,6 +133,7 @@ PanelExtra::handle_login()
     {
         enable_model_drag_source( Lifeograph::p->drag_targets_tag );
         enable_model_drag_dest( Lifeograph::p->drag_targets_tag, Gdk::ACTION_MOVE );
+        enable_model_drag_dest( Lifeograph::p->drag_targets_entry, Gdk::ACTION_COPY );
     }
 
     populate();
@@ -150,7 +144,7 @@ PanelExtra::handle_logout()
 {
     Lifeograph::m_internaloperation++;
 
-    m_treestore_all_tags->clear();
+    m_treestore->clear();
 
     Lifeograph::m_internaloperation--;
 }
@@ -158,7 +152,7 @@ PanelExtra::handle_logout()
 void
 PanelExtra::cell_data_func_icon( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& iter )
 {
-    DiaryElement* elem( ( * iter )[ colrec->ptr ] );
+    DiaryElement* elem( ( * iter )[ m_treestore->colrec.ptr ] );
     if( elem != NULL )
         cell->set_property( "visible", elem->get_type() != DiaryElement::ET_HEADER );
 }
@@ -166,7 +160,7 @@ PanelExtra::cell_data_func_icon( Gtk::CellRenderer* cell, const Gtk::TreeModel::
 void
 PanelExtra::cell_data_func_text( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& iter )
 {
-    DiaryElement* elem( ( * iter )[ colrec->ptr ] );
+    DiaryElement* elem( ( * iter )[ m_treestore->colrec.ptr ] );
 
     if( elem != NULL )
     {
@@ -191,7 +185,7 @@ PanelExtra::cell_data_func_text( Gtk::CellRenderer* cell, const Gtk::TreeModel::
 void
 PanelExtra::cell_data_func_filter( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& iter )
 {
-    DiaryElement *elem( ( * iter )[ colrec->ptr ] );
+    DiaryElement *elem( ( * iter )[ m_treestore->colrec.ptr ] );
     if( elem != NULL )
     {
         if( elem->get_type() == DiaryElement::ET_TAG ||
@@ -214,20 +208,20 @@ PanelExtra::populate()
 {
     Lifeograph::m_internaloperation++;
 
-    m_treestore_all_tags->clear();
+    m_treestore->clear();
 
     Gtk::TreeRow row;
 
     // TAGS HEADER
-    row = * m_treestore_all_tags->append();
-    row[ colrec->ptr ] = &s_header;
-    row[ colrec->name ] = Glib::ustring::compose( "<b>%1</b>", _( "TAGS" ) );
+    row = * m_treestore->append();
+    row[ m_treestore->colrec.ptr ] = &s_header;
+    row[ m_treestore->colrec.name ] = Glib::ustring::compose( "<b>%1</b>", _( "TAGS" ) );
 
     if( Diary::d->get_tags()->size() < 1 && Diary::d->m_tag_categories.size() < 1 )
     {
-        row = * m_treestore_all_tags->append();
-        row[ colrec->ptr ] = &s_none;
-        row[ colrec->name ] = Glib::ustring::compose( "<i>%1</i>", _( "None" ) );
+        row = * m_treestore->append();
+        row[ m_treestore->colrec.ptr ] = &s_none;
+        row[ m_treestore->colrec.name ] = Glib::ustring::compose( "<i>%1</i>", _( "None" ) );
     }
 
     // ROOT TAGS
@@ -256,19 +250,19 @@ PanelExtra::populate()
         }
 
         if( category->get_expanded() )
-            this->expand_row( m_treestore_all_tags->get_path( row ), false );
+            this->expand_row( m_treestore->get_path( row ), false );
     }
 
     // EMPTY SEPARATOR ROW
-    row = * m_treestore_all_tags->append();
-    row[ colrec->ptr ] = &s_none;
+    row = * m_treestore->append();
+    row[ m_treestore->colrec.ptr ] = &s_none;
 
     // UNTAGGED PSEUDO TAG
     add_elem_to_list( &Diary::d->m_untagged );
 
     // EMPTY SEPARATOR ROW
-    row = * m_treestore_all_tags->append();
-    row[ colrec->ptr ] = &s_none;
+    //row = * m_treestore->append();
+    //row[ m_treestore->colrec.ptr ] = &s_none;
 
     // FILTERS GROUP
     //add_elem_to_list( Diary::d->m_filter_active );
@@ -282,14 +276,14 @@ PanelExtra::populate()
 inline Gtk::TreeIter
 PanelExtra::add_elem_to_list( DiaryElement* elem, const Gtk::TreeNodeChildren* children )
 {
-    Gtk::TreeRow row = * ( children != NULL ? m_treestore_all_tags->append( *children ) :
-                                              m_treestore_all_tags->append() );
+    Gtk::TreeRow row = * ( children != NULL ? m_treestore->append( *children ) :
+                                              m_treestore->append() );
 
-    row[ colrec->ptr ] = elem;
-    row[ colrec->name ] = elem->get_list_str();
-    row[ colrec->icon ] = elem->get_icon();
+    row[ m_treestore->colrec.ptr ] = elem;
+    row[ m_treestore->colrec.name ] = elem->get_list_str();
+    row[ m_treestore->colrec.icon ] = elem->get_icon();
 
-    elem->m_list_data->treepath = m_treestore_all_tags->get_path( row );
+    elem->m_list_data->treepath = m_treestore->get_path( row );
 
     return row;
 }
@@ -297,7 +291,7 @@ PanelExtra::add_elem_to_list( DiaryElement* elem, const Gtk::TreeNodeChildren* c
 Gtk::TreeRow
 PanelExtra::get_row( const Gtk::TreePath& path )
 {
-    return( * m_treestore_all_tags->get_iter( path ) );
+    return( * m_treestore->get_iter( path ) );
     // TODO: check validity
 }
 
@@ -309,29 +303,42 @@ PanelExtra::set_filtered_tag( const Tag* tag )
     if( tag != tag_old && tag_old != NULL )
     {
         Gtk::TreeRow row = get_row( tag_old->m_list_data->treepath );
-        row[ colrec->filter ] = Lifeograph::icons->filter_16;
+        row[ m_treestore->colrec.filter ] = Lifeograph::icons->filter_16;
     }
     if( tag != NULL )
     {
         Gtk::TreeRow row = get_row( tag->m_list_data->treepath );
-        row[ colrec->filter ] = Lifeograph::icons->filter_16;
+        row[ m_treestore->colrec.filter ] = Lifeograph::icons->filter_16;
     }
 
     tag_old = tag;
 }
 
 void
-PanelExtra::refresh_elem_icon( DiaryElement* elem )
+PanelExtra::refresh_elem( DiaryElement* elem )
 {
     Gtk::TreeRow row = get_row( elem->m_list_data->treepath );
-    row[ PanelExtra::colrec->icon ] = elem->get_icon();
+    row[ m_treestore->colrec.icon ] = elem->get_icon();
+    row[ m_treestore->colrec.name ] = elem->get_list_str();
 }
 
 void
-PanelExtra::handle_treeview_drag_begin( const Glib::RefPtr< Gdk::DragContext >& )
+PanelExtra::on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& context )
 {
-    Lifeograph::s_flag_dragging = true;
-    this->get_selection()->unselect_all();
+    if( Lifeograph::s_elem_dragged )
+    {
+        Lifeograph::s_flag_dragging = true;
+
+        //Gtk::TreeView::on_drag_begin( context );
+        context->set_icon( Lifeograph::s_elem_dragged->get_icon32(), 0, 0 );
+    }
+}
+
+void
+PanelExtra::on_drag_end( const Glib::RefPtr< Gdk::DragContext >& context )
+{
+    Gtk::TreeView::on_drag_end( context );
+    Lifeograph::s_elem_dragged = NULL;
 }
 
 bool
@@ -344,13 +351,10 @@ PanelExtra::on_drag_motion( const Glib::RefPtr< Gdk::DragContext >& context,
     if( ! Lifeograph::s_elem_dragged )
         return false;
 
-    if( Lifeograph::s_elem_dragged->get_type() != DiaryElement::ET_TAG )
-        return false;
-
     bool retval( false );
-    DiaryElement *element;
+    Gdk::DragAction action( Gdk::ACTION_MOVE );
     Gtk::TreePath path;
-    Tag *tag_dragged( dynamic_cast< Tag* >( Lifeograph::s_elem_dragged ) );
+    DiaryElement* element;
 
     // AUTOSCROLL
     Gdk::Rectangle rect;
@@ -379,21 +383,41 @@ PanelExtra::on_drag_motion( const Glib::RefPtr< Gdk::DragContext >& context,
     // EVALUATE THE HOVERED ELEMENT
     if( get_path_at_pos( x, y, path ) )
     {
-        Gtk::TreeRow row( * m_treestore_all_tags->get_iter( path ) );
-        element = row[ colrec->ptr ];
-        if( element != NULL )
+        Gtk::TreeRow row( * m_treestore->get_iter( path ) );
+        element = row[ m_treestore->colrec.ptr ];
+        if( element != NULL && element != Lifeograph::s_elem_dragged )
         {
-            if( element->get_type() == DiaryElement::ET_TAG_CTG )
+            switch( Lifeograph::s_elem_dragged->get_type() )
             {
-                CategoryTags *ctg_dropped( dynamic_cast< CategoryTags* >( element ) );
-                if( tag_dragged->get_category() != ctg_dropped )
-                    retval = true;
-            }
-            else if( element->get_type() == DiaryElement::ET_TAG )
-            {
-                Tag *tag_dropped( dynamic_cast< Tag* >( element ) );
-                if( tag_dragged->get_category() != tag_dropped->get_category() )
-                    retval = true;
+                case DiaryElement::ET_TAG:
+                {
+                    Tag *tag_dragged( dynamic_cast< Tag* >( Lifeograph::s_elem_dragged ) );
+
+                    if( element->get_type() == DiaryElement::ET_TAG_CTG )
+                    {
+                        CategoryTags* ctg_dropped( dynamic_cast< CategoryTags* >( element ) );
+                        if( tag_dragged->get_category() != ctg_dropped )
+                            retval = true;
+                    }
+                    else if( element->get_type() == DiaryElement::ET_TAG )
+                    {
+                        Tag* tag_dropped( dynamic_cast< Tag* >( element ) );
+                        if( tag_dragged->get_category() != tag_dropped->get_category() )
+                            retval = true;
+                    }
+                    break;
+                }
+                case DiaryElement::ET_ENTRY:
+                case DiaryElement::ET_MULTIPLE_ENTRIES:
+                    if( element->get_type() == DiaryElement::ET_TAG ||
+                        element->get_type() == DiaryElement::ET_UNTAGGED )
+                    {
+                        retval = true;
+                        action = Gdk::ACTION_COPY;
+                    }
+                    break;
+                default:
+                    break;
             }
         }
     }
@@ -401,7 +425,7 @@ PanelExtra::on_drag_motion( const Glib::RefPtr< Gdk::DragContext >& context,
     if( retval )
     {
         m_elem_drop_target = element;
-        context->drag_status( Gdk::ACTION_MOVE, time );
+        context->drag_status( action, time );
         get_selection()->select( path );
     }
     else
@@ -420,21 +444,41 @@ PanelExtra::on_drag_drop( const Glib::RefPtr< Gdk::DragContext >& context,
     {
         if( Lifeograph::s_elem_dragged != NULL || m_elem_drop_target != NULL )
         {
-            if( Lifeograph::s_elem_dragged->get_type() == DiaryElement::ET_TAG )
+            switch( Lifeograph::s_elem_dragged->get_type() )
             {
-                Tag *tag( dynamic_cast< Tag* >( Lifeograph::s_elem_dragged ) );
-                if( m_elem_drop_target->get_type() == DiaryElement::ET_TAG_CTG )
+                case DiaryElement::ET_TAG:
                 {
-                    CategoryTags *ctg( dynamic_cast< CategoryTags* >( m_elem_drop_target ) );
-                    tag->set_category( ctg );
-                    flag_successful = true;
-                }
-                else if( m_elem_drop_target->get_type() == DiaryElement::ET_TAG )
-                {
-                    Tag *target_tag( dynamic_cast< Tag* >( m_elem_drop_target ) );
-                    tag->set_category( target_tag->get_category() );
-                    flag_successful = true;
+                    Tag* tag( dynamic_cast< Tag* >( Lifeograph::s_elem_dragged ) );
+                    if( m_elem_drop_target->get_type() == DiaryElement::ET_TAG_CTG )
+                    {
+                        CategoryTags* ctg( dynamic_cast< CategoryTags* >( m_elem_drop_target ) );
+                        tag->set_category( ctg );
+                        flag_successful = true;
+                    }
+                    else if( m_elem_drop_target->get_type() == DiaryElement::ET_TAG )
+                    {
+                        Tag* target_tag( dynamic_cast< Tag* >( m_elem_drop_target ) );
+                        tag->set_category( target_tag->get_category() );
+                        flag_successful = true;
+                    }
+                    break;
                 }
+                case DiaryElement::ET_ENTRY:
+                case DiaryElement::ET_MULTIPLE_ENTRIES:
+                    if( m_elem_drop_target->get_type() == DiaryElement::ET_TAG ||
+                        m_elem_drop_target->get_type() == DiaryElement::ET_UNTAGGED )
+                    {
+                        Tag* target_tag( dynamic_cast< Tag* >( m_elem_drop_target ) );
+
+                        sigc::slot< void, Entry* > s = sigc::bind(
+                                 sigc::mem_fun( this, &PanelExtra::tag_entry ), target_tag );
+                        AppWindow::p->panel_diary->do_for_each_selected_entry( s );
+
+                        flag_successful = true;
+                    }
+                    break;
+                default:
+                    break;
             }
         }
     }
@@ -457,8 +501,8 @@ PanelExtra::on_button_press_event( GdkEventButton* event )
     Gtk::TreePath path;
     if( this->get_path_at_pos( event->x, event->y, path ) )
     {
-        Gtk::TreeRow row = * m_treestore_all_tags->get_iter( path );
-        Lifeograph::s_elem_dragged = row[ colrec->ptr ];
+        Gtk::TreeRow row = * m_treestore->get_iter( path );
+        Lifeograph::s_elem_dragged = row[ m_treestore->colrec.ptr ];
         if( Lifeograph::s_elem_dragged == NULL )
             return true;    // ignore
         else
@@ -467,10 +511,8 @@ PanelExtra::on_button_press_event( GdkEventButton* event )
             {
                 case DiaryElement::ET_TAG:
                 case DiaryElement::ET_UNTAGGED:
-                case DiaryElement::ET_FILTER:
-                    break;
+                case DiaryElement::ET_FILTER:   // actually not included now
                 case DiaryElement::ET_TAG_CTG:
-                    // TODO: prevent start of a drag action
                     break;
                 default:
                     Lifeograph::s_elem_dragged = NULL;
@@ -493,6 +535,8 @@ PanelExtra::on_button_release_event( GdkEventButton* event )
     {
         if( Lifeograph::s_elem_dragged )
             Lifeograph::s_elem_dragged->show();
+
+        Lifeograph::s_elem_dragged = NULL;
     }
 
     get_selection()->unselect_all();
@@ -507,7 +551,7 @@ PanelExtra::handle_treeview_row_expanded( const Gtk::TreeIter& iter,
     if( Lifeograph::m_internaloperation )
         return;
 
-    DiaryElement *element = ( * iter )[ colrec->ptr ];
+    DiaryElement *element = ( * iter )[ m_treestore->colrec.ptr ];
     if( element )
     {
         if( element->get_type() == DiaryElement::ET_TAG_CTG )
@@ -521,8 +565,8 @@ PanelExtra::handle_treeview_row_expanded( const Gtk::TreeIter& iter,
 void
 PanelExtra::handle_treeview_row_activated( const Gtk::TreePath& path, Gtk::TreeViewColumn* )
 {
-    Gtk::TreeRow row( * m_treestore_all_tags->get_iter( path ) );
-    DiaryElement* element( row[ colrec->ptr ] );
+    Gtk::TreeRow row( * m_treestore->get_iter( path ) );
+    DiaryElement* element( row[ m_treestore->colrec.ptr ] );
 
     if( element == NULL )
         return;
@@ -542,3 +586,47 @@ PanelExtra::handle_treeview_row_activated( const Gtk::TreePath& path, Gtk::TreeV
         AppWindow::p->panel_diary->update_entry_list();
     }
 }
+
+// HELPER FUNCTION
+void
+PanelExtra::tag_entry( Entry* entry, Tag* tag )
+{
+    if( entry->add_tag( tag ) ) // if does not already have the tag
+    {
+        if( AppWindow::p->panel_main->is_cur_elem( entry ) )
+        {
+            AppWindow::p->m_entry_view->update_tag_widget();
+            AppWindow::p->m_entry_view->update_theme();
+        }
+    }
+}
+
+// TREESTORE EXTRA =================================================================================
+TreeStoreExtra::TreeStoreExtra()
+{
+    set_column_types( colrec );
+}
+
+Glib::RefPtr<TreeStoreExtra> TreeStoreExtra::create()
+{
+    return Glib::RefPtr< TreeStoreExtra >( new TreeStoreExtra() );
+}
+
+bool
+TreeStoreExtra::row_draggable_vfunc( const Gtk::TreeModel::Path& path ) const
+{
+    TreeStoreExtra* unconstThis = const_cast< TreeStoreExtra* >( this );
+    const_iterator iter = unconstThis->get_iter( path );
+
+    if( iter )
+    {
+        Row row = *iter;
+        DiaryElement* elem = row[ colrec.ptr ];
+        if( !elem )
+            return false;
+        else
+            return( elem->get_type() != DiaryElement::ET_TAG_CTG );
+    }
+
+    return Gtk::TreeStore::row_draggable_vfunc( path );
+}
