@@ -27,9 +27,12 @@
 namespace LIFEO
 {
 
-// PANEL EXTRA ITEMS
-class PanelExtra : public Gtk::TreeView
+// CUSTOM TREESTORE
+class TreeStoreExtra : public Gtk::TreeStore
 {
+    protected:
+        TreeStoreExtra();
+
     public:
         class Colrec : public Gtk::TreeModel::ColumnRecord
         {
@@ -46,7 +49,19 @@ class PanelExtra : public Gtk::TreeView
                 Gtk::TreeModelColumn< Glib::RefPtr< Gdk::Pixbuf > >     filter;
                 Gtk::TreeModelColumn< DiaryElement* >                   ptr;
         };
-        static Colrec*              colrec;
+
+        Colrec colrec;
+
+        static Glib::RefPtr< TreeStoreExtra > create();
+
+    protected:
+        virtual bool row_draggable_vfunc( const Gtk::TreeModel::Path& path ) const;
+};
+
+// PANEL EXTRA ITEMS
+class PanelExtra : public Gtk::TreeView
+{
+    public:
 
                                     PanelExtra( BaseObjectType*,
                                                 const Glib::RefPtr<Gtk::Builder>& );
@@ -62,11 +77,11 @@ class PanelExtra : public Gtk::TreeView
 
         void                        set_filtered_tag( const Tag* );
 
-        void                        refresh_elem_icon( DiaryElement* );
+        void                        refresh_elem( DiaryElement* );
 
     protected:
-        void                        handle_treeview_drag_begin(
-                                            const Glib::RefPtr< Gdk::DragContext >& );
+        void                        on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& );
+        void                        on_drag_end( const Glib::RefPtr< Gdk::DragContext >& );
         bool                        on_drag_motion( const Glib::RefPtr< Gdk::DragContext >&,
                                                     int, int, guint );
         bool                        on_drag_drop( const Glib::RefPtr< Gdk::DragContext >&,
@@ -85,8 +100,11 @@ class PanelExtra : public Gtk::TreeView
         void                        cell_data_func_filter( Gtk::CellRenderer*,
                                                            const Gtk::TreeModel::iterator& );
 
-        Glib::RefPtr< Gtk::TreeStore >
-                                    m_treestore_all_tags;
+        // HELPER FUNCTION
+        void                        tag_entry( Entry*, Tag* );
+
+        Glib::RefPtr< TreeStoreExtra >
+                                    m_treestore;
 
         Entry*                      m_ptr2entry;
         DiaryElement*               m_elem_drop_target;
