@@ -48,6 +48,7 @@ class PanelMain
 
         void                    show( ElementShowerProto* );
 
+        void                    handle_login();
         void                    handle_logout();
 
         void                    go_back();
@@ -71,12 +72,15 @@ class PanelMain
         void                    update_overlay_icon()
         {
             m_image_overlay->set_visible(
-                    ( m_cur_shower->get_element()->get_type() == DiaryElement::ET_ENTRY) &&
-                    ( m_cur_shower->get_element()->get_status() & ES::FAVORED ) );
+                    m_cur_shower->get_element()->get_type() == DiaryElement::ET_ENTRY &&
+                    m_cur_shower->get_element()->is_favored() );
         }
 
+        void                    hide_popover()
+        { m_popover_elem.hide(); }
+
         void                    start_title_edit();
-        void                    cancel_title_edit();
+        bool                    cancel_title_edit();
         void                    apply_title_edit();
         // for entries whose title is partly defined by contents of entry text editor:
         void                    refresh_title()
@@ -88,11 +92,10 @@ class PanelMain
             m_label_elem_extra->set_text( m_cur_shower->get_info_str() );
         }
 
-        bool                    handle_entry_title_focus_out( GdkEventFocus* );
+        //bool                    handle_entry_title_focus_out( GdkEventFocus* );
         void                    handle_entry_title_changed();
         bool                    handle_entry_title_key_press( GdkEventKey* );
-        void                    handle_entry_icon_release( Gtk::EntryIconPosition,
-                                                           const GdkEventButton* );
+        void                    handle_title_button_clicked();
         bool                    handle_title_click( GdkEventButton* );
         bool                    handle_title_hover( GdkEventCrossing* );
         bool                    handle_title_hover_out( GdkEventCrossing* );
@@ -113,15 +116,18 @@ class PanelMain
         Gtk::Widget*            m_ptr2widget;
         Gtk::Box*               m_vbox_content;
 
-        Gtk::Alignment*         m_align_elem_title;
         Gtk::EventBox*          m_eventbox_elem_title;
         Gtk::Label*             m_label_elem_title;
-        Gtk::Entry*             m_entry_elem_title;
+        Gtk::Box*               m_Bx_elem_title;
+        Gtk::Box*               m_Bx_elem_title_edit;
+        EntryClear*             m_E_elem_title;
+        Gtk::Button*            m_B_elem_title;
         Gtk::Label*             m_label_elem_extra;
         Gtk::Button*            m_button_back;
         Gtk::Image*             m_image_elem;
         Gtk::Image*             m_image_overlay;
-        Gtk::MenuButton*        m_button_menu;
+        Gtk::MenuButton*        m_button_elem;
+        Gtk::Popover            m_popover_elem;
         Gtk::Alignment*         m_alignment_extra_tools;
 
         Glib::RefPtr< Gtk::Action > m_action_previous_browsing;
