@@ -118,7 +118,7 @@ PrintOpr::clear_content()
 }
 
 void
-PrintOpr::init_variables( const Glib::RefPtr< Gtk::PrintContext > &print_context  )
+PrintOpr::init_variables( const Glib::RefPtr< Gtk::PrintContext >& print_context  )
 {
     m_n_pages = 1;
     m_v_offset = 0.0;
@@ -138,7 +138,7 @@ PrintOpr::init_variables( const Glib::RefPtr< Gtk::PrintContext > &print_context
             throw LIFEO::Error( "Current element is not an entry. Printing aborted." );
 
         m_iter_entry_end = EntryIterReverse( Diary::d->get_entries().find(
-                AppWindow::p->panel_main->get_cur_elem()->get_date().m_date ) );
+                AppWindow::p->panel_main->get_cur_elem()->get_date_t() ) );
         m_iter_entry = m_iter_entry_end;
         m_iter_entry--;
     }
@@ -203,7 +203,7 @@ PrintOpr::on_create_custom_widget()
 }
 
 void
-PrintOpr::on_custom_widget_apply( Gtk::Widget *widget )
+PrintOpr::on_custom_widget_apply( Gtk::Widget* widget )
 {
     m_opt_one_entry = m_rbutton_entry->get_active();
     m_opt_entire_diary = m_rbutton_diary->get_active();
@@ -282,7 +282,7 @@ PrintOpr::add_page()
 }
 
 void
-PrintOpr::handle_text( const Glib::RefPtr< Gtk::PrintContext > &print_context )
+PrintOpr::handle_text( const Glib::RefPtr< Gtk::PrintContext >& print_context )
 {
     m_layout = print_context->create_pango_layout();
 
@@ -342,7 +342,7 @@ PrintOpr::handle_text( const Glib::RefPtr< Gtk::PrintContext > &print_context )
 }
 
 void
-PrintOpr::handle_entry_break( const Glib::RefPtr< Gtk::PrintContext > &print_context )
+PrintOpr::handle_entry_break( const Glib::RefPtr< Gtk::PrintContext >& print_context )
 {
     const double break_height = print_context->get_height() / 10;
     const double height = print_context->get_height();
@@ -359,7 +359,7 @@ PrintOpr::handle_entry_break( const Glib::RefPtr< Gtk::PrintContext > &print_con
 }
 
 void
-PrintOpr::handle_image( const Glib::RefPtr< Gtk::PrintContext > &print_context )
+PrintOpr::handle_image( const Glib::RefPtr< Gtk::PrintContext >& print_context )
 {
     const int image_height = m_parser.m_pango_pixbuf->get_height();
     const double height = print_context->get_height();
@@ -375,8 +375,8 @@ PrintOpr::handle_image( const Glib::RefPtr< Gtk::PrintContext > &print_context )
 Printable::Type
 PrintOpr::get_more()
 {
-    Chapter *chapter( NULL );
-    Entry   *entry( NULL );
+    Chapter* chapter( NULL );
+    Entry* entry( NULL );
     Printable::Type return_type( Printable::PT_PAGE_BREAK );
 
     m_marked_up_text.clear();
@@ -409,42 +409,45 @@ PrintOpr::get_more()
             if( m_iter_chapter == m_chapters->rend() )
             {
                 if( m_flag_chapter_round == DiaryElement::ET_CHAPTER )
+                {
+                    m_chapters = Diary::d->get_groups();
+                    m_iter_chapter = m_chapters->rbegin();
+                    m_flag_chapter_round = DiaryElement::ET_GROUP;
+                    continue;   // to check if rbegin() == rend()
+                }
+                else if( m_flag_chapter_round == DiaryElement::ET_GROUP )
                 {
                     m_chapters = Diary::d->get_topics();
                     m_iter_chapter = m_chapters->rbegin();
                     m_flag_chapter_round = DiaryElement::ET_TOPIC;
                     continue;   // to check if rbegin() == rend()
                 }
-                else if( m_flag_chapter_round == DiaryElement::ET_TOPIC )
-                {
-                    m_chapters = Diary::d->get_todo_groups();
-                    m_iter_chapter = m_chapters->rbegin();
-                    m_flag_chapter_round = DiaryElement::ET_TODO_GRP;
-                    continue;   // to check if rbegin() == rend()
-                }
                 else
                     break;
             }
 
             chapter = m_iter_chapter->second;
 
-            if( chapter->is_initialized() )
+            if( entry->get_date() >= chapter->get_date() &&
+                chapter->get_date_t() > m_last_chapter_date )
             {
-                if( entry->get_date() >= chapter->get_date() &&
-                    chapter->get_date().m_date > m_last_chapter_date )
-                {
-                    if( m_content.back()->get_type() != Printable::PT_PAGE_BREAK )
-                        return Printable::PT_PAGE_BREAK; // page break before chapter
+                if( m_content.back()->get_type() != Printable::PT_PAGE_BREAK )
+                    return Printable::PT_PAGE_BREAK; // page break before chapter
 
+                if( ! chapter->get_date().is_hidden() )
+                {
                     m_marked_up_text += Glib::ustring::compose(
-                            "<big>%1\n<big><b>%2</b></big></big>\n\n\n",
-                            chapter->get_date().format_string(),
-                            Glib::Markup::escape_text( chapter->get_name() ) );
-                    m_last_chapter_date = chapter->get_date().m_date;
+                            "<big>%1</big>\n", chapter->get_date().format_string() );
                 }
-                else
-                    break;
+
+                m_marked_up_text += Glib::ustring::compose(
+                        "<big><big><b>%1</b></big></big>\n\n\n",
+                        Glib::Markup::escape_text( chapter->get_name() ) );
+
+                m_last_chapter_date = chapter->get_date_t();
             }
+            else
+                break;
 
             ++m_iter_chapter;
         }
@@ -467,7 +470,7 @@ PrintOpr::get_more()
 }
 
 void
-PrintOpr::on_begin_print( const Glib::RefPtr< Gtk::PrintContext > &print_context )
+PrintOpr::on_begin_print( const Glib::RefPtr< Gtk::PrintContext >& print_context )
 {
     clear_content();
     init_variables( print_context );
@@ -529,7 +532,7 @@ PrintOpr::on_draw_page( const Glib::RefPtr< Gtk::PrintContext >& print_context,
 
 // PANGO ENTRY PARSER ==============================================================================
 void
-EntryParserPango::set( const Entry *entry )
+EntryParserPango::set( const Entry* entry )
 {
     m_pango_text.clear();
     if( m_ptr2entry != entry )
@@ -547,8 +550,11 @@ EntryParserPango::parse()
 
     if( m_pango_begin == 0 )
     {
-        m_pango_text = Glib::ustring::compose( "<b>%1</b>\n",
-                                               m_ptr2entry->get_date().format_string() );
+        if( ! m_ptr2entry->get_date().is_hidden() )
+        {
+            m_pango_text = Glib::ustring::compose(
+                    "<b>%1</b>\n", m_ptr2entry->get_date().format_string() );
+        }
 
         if( option_use_theme_font && m_ptr2entry->get_theme_is_set() )
         {
@@ -579,7 +585,7 @@ EntryParserPango::apply_regular()
 }
 
 void
-EntryParserPango::apply_markup( const Glib::ustring &tag_o, const Glib::ustring &tag_c,
+EntryParserPango::apply_markup( const Glib::ustring& tag_o, const Glib::ustring& tag_c,
                                 int off_o, int off_c )
 {
     // before adding any marked up text, last regular text chunk must be handled:
@@ -702,7 +708,7 @@ EntryParserPango::apply_link()
 
         if( word_last.find( "file:///" ) == 0 &&
             // there can be no text on the same line as the image:
-            get_char_at( m_pos_start - 1 ) == '\n' && m_cc_current == CC_NEWLINE )
+            get_char_at( m_pos_start - 1 ) == '\n' && char_current == '\n' )
         {
             try
             {
