@@ -39,30 +39,33 @@ EntryView::EntryView()
 {
     Entry::shower = this;
 
-    Gtk::MenuItem *menuitem_print;
+    Gtk::Button* button_print;
 
-    Gtk::MenuItem *menuitem_hide( NULL );
-    Gtk::MenuItem *menuitem_hide_before( NULL );
-    Gtk::MenuItem *menuitem_hide_after( NULL );
+    Gtk::Button* button_hide( NULL );
+    Gtk::Button* button_hide_before( NULL );
+    Gtk::Button* button_hide_after( NULL );
 
     try
     {
         Lifeograph::builder->get_widget( "Bx_entry", m_vbox );
-        Lifeograph::builder->get_widget( "M_entry_elem", m_menu );
-        Lifeograph::builder->get_widget( "menuitem_entry_todo", m_menuitem_todo );
-        Lifeograph::builder->get_widget( "menuitem_entry_done", m_menuitem_done );
-        Lifeograph::builder->get_widget( "menuitem_entry_canceled", m_menuitem_canceled );
-        Lifeograph::builder->get_widget( "menuseparator_entry_4", m_menuseparator_4 );
-        Lifeograph::builder->get_widget( "menuitem_entry_favorite", m_menuitem_toggle_favorite );
-        Lifeograph::builder->get_widget( "menuseparator_entry_1", m_menuseparator_1 );
-        Lifeograph::builder->get_widget( "menuitem_entry_print", menuitem_print );
-        Lifeograph::builder->get_widget( "menuitem_entry_filter", menuitem_hide );
-        Lifeograph::builder->get_widget( "menuitem_entry_filter_before", menuitem_hide_before );
-        Lifeograph::builder->get_widget( "menuitem_entry_filter_after", menuitem_hide_after );
-        Lifeograph::builder->get_widget( "menuseparator_entry_2", m_menuseparator_2 );
-        Lifeograph::builder->get_widget( "menuitem_entry_trash", m_menuitem_trash );
-        Lifeograph::builder->get_widget( "menuitem_entry_restore", m_menuitem_restore );
-        Lifeograph::builder->get_widget( "menuitem_entry_dismiss", m_menuitem_dismiss );
+        Lifeograph::builder->get_widget( "G_entry_popover", m_grid_popover );
+        Lifeograph::builder->get_widget( "RB_entry_not_todo", m_button_not_todo );
+        Lifeograph::builder->get_widget( "RB_entry_todo", m_button_todo );
+        Lifeograph::builder->get_widget( "RB_entry_progressed", m_button_progressed );
+        Lifeograph::builder->get_widget( "RB_entry_done", m_button_done );
+        Lifeograph::builder->get_widget( "RB_entry_canceled", m_button_canceled );
+        Lifeograph::builder->get_widget( "L_entry_info", m_label_info );
+        Lifeograph::builder->get_widget( "TB_entry_favorite", m_button_toggle_favorite );
+        Lifeograph::builder->get_widget( "B_entry_print", button_print );
+        Lifeograph::builder->get_widget( "B_entry_filter", button_hide );
+        Lifeograph::builder->get_widget( "B_entry_filter_before", button_hide_before );
+        Lifeograph::builder->get_widget( "B_entry_filter_after", button_hide_after );
+        Lifeograph::builder->get_widget( "B_entry_trash", m_button_trash );
+        Lifeograph::builder->get_widget( "B_entry_restore", m_button_restore );
+        Lifeograph::builder->get_widget( "B_entry_dismiss", m_button_dismiss );
+
+
+        Lifeograph::builder->get_widget( "hbox_entry_toolbar_text", m_hbox_editing_toolbar );
         Lifeograph::builder->get_widget( "button_entry_bold", m_button_bold );
         Lifeograph::builder->get_widget( "button_entry_italic", m_button_italic );
         Lifeograph::builder->get_widget( "button_entry_strikethrough", m_button_strikethrough );
@@ -73,12 +76,13 @@ EntryView::EntryView()
         Lifeograph::builder->get_widget( "button_entry_add_checkbox", m_button_add_checkbox );
         Lifeograph::builder->get_widget( "tgglbutton_entry_comments", m_button_toggle_comments );
         Lifeograph::builder->get_widget_derived( "textview_entry", m_textview );
-        Lifeograph::builder->get_widget_derived( "entry_tag_filter", m_tag_widget );
-        Lifeograph::builder->get_widget( "button_entry_tag", m_button_tag_operation );
-        Lifeograph::builder->get_widget( "button_entry_tag_theme", m_button_set_theme );
+
+        Lifeograph::builder->get_widget( "Bx_entry_tag_edit", m_box_tag_edit );
+        Lifeograph::builder->get_widget( "Bx_entry_tag_linked", m_Bx_tag_linked );
+        Lifeograph::builder->get_widget_derived( "E_tag_filter", m_tag_widget );
+        Lifeograph::builder->get_widget( "B_entry_tag", m_button_tag_operation );
+        Lifeograph::builder->get_widget( "B_entry_tag_theme", m_button_set_theme );
         Lifeograph::builder->get_widget_derived( "drawingarea_entry_tags", m_widgettaglist );
-        Lifeograph::builder->get_widget( "hbox_entry_toolbar_text", m_hbox_editing_toolbar );
-        Lifeograph::builder->get_widget( "box_entry_tag_edit", m_box_tag_edit );
     }
     catch( ... )
     {
@@ -96,27 +100,31 @@ EntryView::EntryView()
     m_textview->m_buffer->signal_changed().connect(
             sigc::mem_fun( this, &LIFEO::EntryView::handle_textview_changed ) );
 
-    m_menuitem_todo->signal_activate().connect(
+    m_button_not_todo->signal_toggled().connect(
+            sigc::bind( sigc::mem_fun( this, &EntryView::set_todo_status ), ES::NOT_TODO ) );
+    m_button_todo->signal_toggled().connect(
             sigc::bind( sigc::mem_fun( this, &EntryView::set_todo_status ), ES::TODO ) );
-    m_menuitem_done->signal_activate().connect(
+    m_button_progressed->signal_toggled().connect(
+            sigc::bind( sigc::mem_fun( this, &EntryView::set_todo_status ), ES::PROGRESSED ) );
+    m_button_done->signal_toggled().connect(
             sigc::bind( sigc::mem_fun( this, &EntryView::set_todo_status ), ES::DONE ) );
-    m_menuitem_canceled->signal_activate().connect(
+    m_button_canceled->signal_toggled().connect(
             sigc::bind( sigc::mem_fun( this, &EntryView::set_todo_status ), ES::CANCELED ) );
 
-    m_menuitem_toggle_favorite->signal_activate().connect(
+    m_button_toggle_favorite->signal_toggled().connect(
             sigc::mem_fun( this, &LIFEO::EntryView::toggle_favoredness ) );
-    m_menuitem_trash->signal_activate().connect(
+    m_button_trash->signal_clicked().connect(
             sigc::mem_fun( this, &LIFEO::EntryView::trash_entry ) );
-    m_menuitem_restore->signal_activate().connect(
+    m_button_restore->signal_clicked().connect(
             sigc::mem_fun( this, &LIFEO::EntryView::restore_entry ) );
-    m_menuitem_dismiss->signal_activate().connect(
+    m_button_dismiss->signal_clicked().connect(
             sigc::mem_fun( this, &LIFEO::EntryView::dismiss_entry ) );
-    menuitem_print->signal_activate().connect(
+    button_print->signal_clicked().connect(
             sigc::mem_fun( this, &EntryView::print ) );
-    menuitem_hide->signal_activate().connect( sigc::mem_fun( this, &EntryView::hide ) );
-    menuitem_hide_before->signal_activate().connect(
+    button_hide->signal_clicked().connect( sigc::mem_fun( this, &EntryView::hide ) );
+    button_hide_before->signal_clicked().connect(
             sigc::mem_fun( this, &EntryView::hide_before ) );
-    menuitem_hide_after->signal_activate().connect(
+    button_hide_after->signal_clicked().connect(
             sigc::mem_fun( this, &EntryView::hide_after ) );
 
     m_button_add_bullet->signal_clicked().connect(
@@ -146,66 +154,66 @@ EntryView::EntryView()
 
     // EDITOR ACTIONS
     Lifeograph::create_action(
-            true, m_action_bold, "Bold", "", "", "",
+            true, m_action_bold, "Bold", "", "",
             Gtk::AccelKey( GDK_KEY_b, Gdk::CONTROL_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::toggle_bold ),
             m_button_bold );
     Lifeograph::create_action(
-            true, m_action_italic, "Italic", "", "", "",
+            true, m_action_italic, "Italic", "", "",
             Gtk::AccelKey( GDK_KEY_i, Gdk::CONTROL_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::toggle_italic ),
             m_button_italic );
     Lifeograph::create_action(
-            true, m_action_strikethrough, "Strikethrough", "", "", "",
+            true, m_action_strikethrough, "Strikethrough", "", "",
             Gtk::AccelKey( GDK_KEY_s, Gdk::CONTROL_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::toggle_strikethrough ),
             m_button_strikethrough );
     Lifeograph::create_action(
-            true, m_action_highlight, "Highlight", "", "", "",
+            true, m_action_highlight, "Highlight", "", "",
             Gtk::AccelKey( GDK_KEY_h, Gdk::CONTROL_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::toggle_highlight ),
             m_button_highlight );
 
     Lifeograph::create_action(
-            true, m_action_focus_tag, "FocusTag", "", "", "",
+            true, m_action_focus_tag, "FocusTag", "", "",
             Gtk::AccelKey( GDK_KEY_t, Gdk::CONTROL_MASK ),
             sigc::mem_fun( this, &EntryView::focus_tag_entry ) );
 
     Lifeograph::create_toggle_action(
-            false, m_action_toggle_comments, "ToggleComments", "", "", "",
+            false, m_action_toggle_comments, "ToggleComments", "", "",
             Gtk::AccelKey( GDK_KEY_c, Gdk::MOD1_MASK ),
             sigc::mem_fun( this, &EntryView::toggle_comments ),
             m_button_toggle_comments );
 
     Lifeograph::create_action(
-            true, m_action_indent, "Indent", "", "", "",
+            true, m_action_indent, "Indent", "", "",
             Gtk::AccelKey( GDK_KEY_i, Gdk::MOD1_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::handle_indent ) );
     Lifeograph::create_action(
-            true, m_action_unindent, "Unindent", "", "", "",
+            true, m_action_unindent, "Unindent", "", "",
             Gtk::AccelKey( GDK_KEY_u, Gdk::MOD1_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::handle_unindent ) );
 
     Lifeograph::create_action(
-            true, m_action_add_empty_line_above, "AddEmptyLineAbove", "", "", "",
+            true, m_action_add_empty_line_above, "AddEmptyLineAbove", "", "",
             Gtk::AccelKey( GDK_KEY_l, Gdk::MOD1_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::add_empty_line_above ) );
     Lifeograph::create_action(
-            true, m_action_remove_empty_line_above, "RemoveEmptyLineAbove", "", "", "",
+            true, m_action_remove_empty_line_above, "RemoveEmptyLineAbove", "", "",
             Gtk::AccelKey( GDK_KEY_l, Gdk::MOD1_MASK|Gdk::SHIFT_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::remove_empty_line_above ) );
 
     Lifeograph::create_action(
-            true, m_action_move_line_up, "MoveLineUp", "", "", "",
+            true, m_action_move_line_up, "MoveLineUp", "", "",
             Gtk::AccelKey( GDK_KEY_Up, Gdk::MOD1_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::move_line_up ) );
     Lifeograph::create_action(
-            true, m_action_move_line_down, "MoveLineDown", "", "", "",
+            true, m_action_move_line_down, "MoveLineDown", "", "",
             Gtk::AccelKey( GDK_KEY_Down, Gdk::MOD1_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::move_line_down ) );
 
     Lifeograph::create_action(
-            true, m_action_time_stamp, "TimeStamp", "", "", "",
+            true, m_action_time_stamp, "TimeStamp", "", "",
             Gtk::AccelKey( GDK_KEY_t, Gdk::MOD1_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::insert_time_stamp ) );
 }
@@ -215,8 +223,8 @@ EntryView::sync()
 {
     if( m_flag_entrychanged )
     {
-        m_entry_sync->m_date_changed = time( NULL );
-        m_entry_sync->m_text = m_textview->m_buffer->get_text();
+        m_entry_sync->set_date_changed( time( NULL ) );
+        m_entry_sync->set_text( m_textview->m_buffer->get_text() );
         m_flag_entrychanged = false;
         PRINT_DEBUG( "entry synced" );
     }
@@ -232,8 +240,8 @@ EntryView::remove_selected_tags()
          ++iter )
     {
         Gtk::TreeRow row = *m_liststore_tags->get_iter( *iter );
-        DiaryElement *element = row[ PanelExtra::colrec->ptr ];
-        Tag *tag = dynamic_cast< Tag* >( element );
+        DiaryElement* element = row[ PanelExtra::colrec->ptr ];
+        Tag* tag = dynamic_cast< Tag* >( element );
 
         m_ptr2elem->remove_tag( tag );
         m_liststore_tags->erase( row );
@@ -249,16 +257,18 @@ EntryView::handle_login()
     bool editable( ! Diary::d->is_read_only() );
     m_textview->set_editable( editable );
     m_widgettaglist->set_editable( editable );
-    m_menuitem_todo->set_visible( editable );
-    m_menuitem_done->set_visible( editable );
-    m_menuitem_canceled->set_visible( editable );
-    m_menuseparator_4->set_visible( editable );
-    m_menuitem_toggle_favorite->set_visible( editable );
-    m_menuseparator_1->set_visible( editable );
-    m_menuseparator_2->set_visible( editable );
-    m_menuitem_trash->set_visible( editable );
-    m_menuitem_restore->set_visible( editable );
-    m_menuitem_dismiss->set_visible( editable );
+    m_button_not_todo->set_visible( editable );
+    m_button_todo->set_visible( editable );
+    m_button_progressed->set_visible( editable );
+    m_button_done->set_visible( editable );
+    m_button_canceled->set_visible( editable );
+    //m_menuseparator_4->set_visible( editable );
+    m_button_toggle_favorite->set_visible( editable );
+    //m_menuseparator_1->set_visible( editable );
+    //m_menuseparator_2->set_visible( editable );
+    m_button_trash->set_visible( editable );
+    m_button_restore->set_visible( editable );
+    m_button_dismiss->set_visible( editable );
     m_hbox_editing_toolbar->set_visible( Lifeograph::settings.show_formatting_toolbar &&
                                          editable );
 }
@@ -279,9 +289,9 @@ EntryView::handle_textview_changed()
 
 void
 EntryView::handle_drag_data_received(
-                const Glib::RefPtr< Gdk::DragContext > &context,
+                const Glib::RefPtr< Gdk::DragContext >& context,
                 int x, int y,
-                const Gtk::SelectionData &selection_data,
+                const Gtk::SelectionData& selection_data,
                 uint info,
                 guint time )
 {
@@ -290,7 +300,7 @@ EntryView::handle_drag_data_received(
 
     context->drag_finish( true, false, time );
 
-    if( Lifeograph::s_elem_dragged == NULL || Lifeograph::s_flag_dragging == false )
+    if( Lifeograph::s_elem_dragged == NULL )
         return;
 
     switch( Lifeograph::s_elem_dragged->get_type() )
@@ -300,7 +310,7 @@ EntryView::handle_drag_data_received(
             break;
         case DiaryElement::ET_TAG:
         {
-            Tag *tag = dynamic_cast< Tag* >( Lifeograph::s_elem_dragged );
+            Tag* tag = dynamic_cast< Tag* >( Lifeograph::s_elem_dragged );
             if( m_ptr2elem->add_tag( tag ) ) // if does not already have the tag
             {
                 m_widgettaglist->update();
@@ -351,16 +361,18 @@ EntryView::set_todo_status( ElemStatus status )
 void
 EntryView::print()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     AppWindow::p->m_entry_view->sync();
 
     Glib::RefPtr< PrintOpr > print = PrintOpr::create();
 
     try
     {
-        Lifeograph::p->freeze_auto_logout();
+        AppWindow::p->freeze_auto_logout();
         print->set_hide_comments( m_button_toggle_comments->get_active() );
         print->run( Gtk::PRINT_OPERATION_ACTION_PRINT_DIALOG, *AppWindow::p );
-        Lifeograph::p->unfreeze_auto_logout();
+        AppWindow::p->unfreeze_auto_logout();
     }
     catch( const Gtk::PrintError &ex )
     {
@@ -373,6 +385,8 @@ EntryView::print()
 void
 EntryView::hide()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     Diary::d->get_filter()->add_entry( m_ptr2elem );
     AppWindow::p->panel_diary->update_calendar();
     AppWindow::p->panel_diary->update_entry_list();
@@ -381,7 +395,7 @@ EntryView::hide()
 void
 EntryView::hide_before()
 {
-    Diary::d->set_filter_date_begin( m_ptr2elem->get_date().m_date );
+    Diary::d->set_filter_date_begin( m_ptr2elem->get_date_t() );
     AppWindow::p->panel_diary->update_calendar();
     AppWindow::p->panel_diary->update_entry_list();
 }
@@ -389,7 +403,7 @@ EntryView::hide_before()
 void
 EntryView::hide_after()
 {
-    Diary::d->set_filter_date_end( m_ptr2elem->get_date().m_date );
+    Diary::d->set_filter_date_end( m_ptr2elem->get_date_t() );
     AppWindow::p->panel_diary->update_calendar();
     AppWindow::p->panel_diary->update_entry_list();
 }
@@ -404,6 +418,8 @@ EntryView::update_theme()
 void
 EntryView::trash_entry()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     Diary::d->show();
 
     AppWindow::p->panel_main->remove_element_from_history( m_ptr2elem );
@@ -426,6 +442,8 @@ EntryView::trash_entry()
 void
 EntryView::restore_entry()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     Diary::d->show();
 
     m_ptr2elem->set_trashed( false );
@@ -442,6 +460,8 @@ EntryView::restore_entry()
 void
 EntryView::dismiss_entry()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     if( ! AppWindow::p->confirm_dismiss_element( m_ptr2elem ) )
         return;
 
@@ -457,8 +477,6 @@ EntryView::dismiss_entry()
     AppWindow::p->panel_diary->update_calendar();
     AppWindow::p->panel_diary->update_entry_list();
 
-    AppWindow::p->m_diary_view->update_startup_elem();
-
     Lifeograph::m_internaloperation--;
 }
 
@@ -473,33 +491,23 @@ EntryView::toggle_comments()
 bool
 EntryView::check_title_applicable( const Glib::ustring& str ) const
 {
-    try
-    {
-        Date date( str );
-    }
-    catch( LIFEO::Error &er )
-    {
-        return false;
-    }
-
-    return true;
+    return( Date::parse_string( NULL, str ) == OK );
+    // TODO communicate the nature of the error to the user (possibly via a tooltip)
 }
 
 bool
 EntryView::apply_title( const Glib::ustring& str )
 {
-    try
-    {
-        Date date( str );
-        date.reset_order_1();
-        Diary::d->set_entry_date( m_ptr2elem, date );
-        AppWindow::p->panel_diary->update_entry_list();
-        AppWindow::p->panel_diary->select_date_in_calendar( m_ptr2elem->get_date() );
-    }
-    catch( LIFEO::Error &er )
-    {
+    Date date( str );
+    if( !date.is_set() )
         return false;
-    }
+
+    if( !date.is_ordinal() )
+        date.reset_order_1();
+
+    Diary::d->set_entry_date( m_ptr2elem, date );
+    AppWindow::p->panel_diary->update_entry_list();
+    AppWindow::p->panel_diary->select_date_in_calendar( m_ptr2elem->get_date() );
 
     return true;
 }
@@ -513,13 +521,16 @@ EntryView::handle_entry_tag_changed()
 
     if( filter.empty() )
     {
+        m_Bx_tag_linked->get_style_context()->remove_class( "linked" );
         m_button_tag_operation->hide();
         m_tag_operation_cur = TO_NONE;
+
     }
     else
     {
+        m_Bx_tag_linked->get_style_context()->add_class( "linked" );
         m_button_tag_operation->show();
-        Tag *tag = Diary::d->get_tags()->get_tag( filter );
+        Tag* tag = Diary::d->get_tags()->get_tag( filter );
         if( tag == NULL )
         {
             m_button_tag_operation->set_label( _( "Create Tag" ) );
@@ -634,32 +645,34 @@ EntryView::show( Entry& entry )
     m_box_tag_edit->set_visible( false );
     AppWindow::p->panel_main->show( this );
 
+    m_label_info->set_markup( get_extended_info_str() );
+
     Lifeograph::m_internaloperation++;
 
     if( ! Diary::d->is_read_only() )
     {
-        m_menuitem_todo->set_visible( entry.is_todo() );
-        m_menuitem_done->set_visible( entry.is_todo() );
-        m_menuitem_canceled->set_visible( entry.is_todo() );
-        m_menuseparator_4->set_visible( entry.is_todo() );
-        m_menuitem_trash->set_visible( !entry.is_trashed() );
-        m_menuitem_restore->set_visible( entry.is_trashed() );
-        m_menuitem_dismiss->set_visible( entry.is_trashed() );
+        m_button_toggle_favorite->set_active( entry.is_favored() );
+        m_button_trash->set_visible( !entry.is_trashed() );
+        m_button_restore->set_visible( entry.is_trashed() );
+        m_button_dismiss->set_visible( entry.is_trashed() );
 
-        if( entry.is_todo() )
+        switch( entry.get_todo_status() )
         {
-            switch( entry.get_todo_status() )
-            {
-                case ES::TODO:
-                    m_menuitem_todo->set_active();
-                    break;
-                case ES::DONE:
-                    m_menuitem_done->set_active();
-                    break;
-                case ES::CANCELED:
-                    m_menuitem_canceled->set_active();
-                    break;
-            }
+            case ES::NOT_TODO:
+                m_button_not_todo->set_active();
+                break;
+            case ES::TODO:
+                m_button_todo->set_active();
+                break;
+            case ES::PROGRESSED:
+                m_button_progressed->set_active();
+                break;
+            case ES::DONE:
+                m_button_done->set_active();
+                break;
+            case ES::CANCELED:
+                m_button_canceled->set_active();
+                break;
         }
     }
 
