@@ -46,36 +46,35 @@ class EntryView : public ElementShower< Entry >
 
         Glib::ustring           get_title_str() const
         {
+            Glib::ustring title;
+
+            if( ! m_ptr2elem->get_date().is_hidden() )
+            {
+                title = m_ptr2elem->get_date().format_string();
+                title += "  ";
+            }
+
             if( m_ptr2elem->get_date().is_ordinal() )
-                return Glib::ustring::compose( "%1: %2",
-                                               m_ptr2elem->get_date().format_string(),
-                                               m_ptr2elem->m_name );
+                title += m_ptr2elem->get_name();
             else
-                return Glib::ustring::compose( "%1, %2",
-                                               m_ptr2elem->get_date().format_string(),
-                                               m_ptr2elem->get_date().get_weekday_str() );
+                title += m_ptr2elem->get_date().get_weekday_str();
+
+            return title;
         }
         Glib::ustring           get_info_str() const
         { return Glib::ustring::compose( _( "Entry last changed on %1" ),
-                Date::format_string_d( m_ptr2elem->m_date_changed ) ); }
-        Glib::ustring           get_tip_str() const
+                Date::format_string_d( m_ptr2elem->get_date_changed() ) ); }
+        Glib::ustring           get_extended_info_str() const
         {
-            return Glib::ustring::compose( "%1: <b>%2</b>\n%3: <b>%4</b>"
-#if LIFEOGRAPH_DEBUG_BUILD
-                    "\nDEID: %5"
-#endif
+            return Glib::ustring::compose( "%1: <b>%2</b>\n%3: <b>%4</b>",
                     // TRANSLATORS: label of creation date
-                    , _( "Created"), m_ptr2elem->get_date_created_str(),
+                    _( "Created"), m_ptr2elem->get_date_created_str(),
                     // TRANSLATORS: label of last change date
-                    _( "Changed"), m_ptr2elem->get_date_changed_str()
-#if LIFEOGRAPH_DEBUG_BUILD
-                    , m_ptr2elem->get_id()
-#endif
-                    );
+                    _( "Changed"), m_ptr2elem->get_date_changed_str() );
         }
 
         bool                    is_title_editable() const
-        { return( ! m_ptr2elem->get_date().is_ordinal() ); }
+        { return( ! m_ptr2elem->get_date().is_hidden() ); }
         Glib::ustring           get_title_edit_str() const
         { return( m_ptr2elem->get_date().format_string() ); }
         bool                    check_title_applicable( const Glib::ustring& ) const;
@@ -126,16 +125,16 @@ class EntryView : public ElementShower< Entry >
         void                    remove_selected_tags();
 
         // WIDGETS
-        Gtk::RadioMenuItem*     m_menuitem_todo;
-        Gtk::RadioMenuItem*     m_menuitem_done;
-        Gtk::RadioMenuItem*     m_menuitem_canceled;
-        Gtk::MenuItem*          m_menuitem_toggle_favorite;
-        Gtk::SeparatorMenuItem* m_menuseparator_1;
-        Gtk::SeparatorMenuItem* m_menuseparator_2;
-        Gtk::SeparatorMenuItem* m_menuseparator_4;
-        Gtk::MenuItem*          m_menuitem_trash;
-        Gtk::MenuItem*          m_menuitem_restore;
-        Gtk::MenuItem*          m_menuitem_dismiss;
+        Gtk::RadioButton*       m_button_not_todo;
+        Gtk::RadioButton*       m_button_todo;
+        Gtk::RadioButton*       m_button_progressed;
+        Gtk::RadioButton*       m_button_done;
+        Gtk::RadioButton*       m_button_canceled;
+        Gtk::Label*             m_label_info;
+        Gtk::ToggleButton*      m_button_toggle_favorite;
+        Gtk::Button*            m_button_trash;
+        Gtk::Button*            m_button_restore;
+        Gtk::Button*            m_button_dismiss;
 
         Gtk::Button*            m_button_bold;
         Gtk::Button*            m_button_italic;
@@ -148,6 +147,7 @@ class EntryView : public ElementShower< Entry >
         Gtk::ToggleButton*      m_button_toggle_comments;
 
         TextviewDiary*          m_textview;
+        Gtk::Box*               m_Bx_tag_linked;
         Gtk::Box*               m_box_tag_edit;
         TagWidget*              m_tag_widget;
         Gtk::Button*            m_button_tag_operation;
