@@ -41,8 +41,11 @@ std::string         ViewLogin::m_path_cur;
 ViewLogin::ViewLogin()
 :   m_flag_info_is_visible( false ), m_sort_date_type( SDT_SAVE )
 {
-    Gtk::Button *button_new_diary, *button_browse_diary;
-    Gtk::TreeView::Column *col_diary, *col_date;
+    Gtk::Button* button_new_diary;
+    Gtk::Button* button_browse_diary;
+    Gtk::TreeView::Column* col_diary;
+    Gtk::TreeView::Column* col_date;
+    Gtk::Grid* grid_add;
 
     try
     {
@@ -50,8 +53,10 @@ ViewLogin::ViewLogin()
 
         Lifeograph::builder->get_widget( "G_login", m_grid_login );
         Lifeograph::builder->get_widget( "TV_diaries", m_treeview_diaries );
-        Lifeograph::builder->get_widget( "B_new_diary", button_new_diary );
-        Lifeograph::builder->get_widget( "B_open_diary", button_browse_diary );
+        Lifeograph::builder->get_widget( "MB_login_add", m_button_add );
+        Lifeograph::builder->get_widget( "G_login_add", grid_add );
+        Lifeograph::builder->get_widget( "B_login_new_diary", button_new_diary );
+        Lifeograph::builder->get_widget( "B_login_open_diary", button_browse_diary );
         Lifeograph::builder->get_widget( "B_login_edit", m_button_edit_diary );
         Lifeograph::builder->get_widget( "B_login_read", m_button_read_diary );
         Lifeograph::builder->get_widget( "B_login_remove_diary", m_button_remove_diary );
@@ -63,6 +68,10 @@ ViewLogin::ViewLogin()
         col_date = Gtk::manage( new Gtk::TreeView::Column( _( STRING::COLHEAD_BY_LAST_SAVE ),
                                                            colrec->date ) );
 
+        m_popover_add = Gtk::manage( new Gtk::Popover );
+        m_popover_add->add( *grid_add );
+        m_button_add->set_popover( *m_popover_add );
+
         m_treestore_diaries = Gtk::ListStore::create( *colrec );
         m_treesel_diaries = m_treeview_diaries->get_selection();
     }
@@ -152,21 +161,51 @@ ViewLogin::ViewLogin()
 }
 
 void
-ViewLogin::handle_start()
+ViewLogin::initialize()
 {
-    AppWindow::p->remove();
     AppWindow::p->add( *m_grid_login );
     AppWindow::p->set_title( PROGRAM_NAME );
+
+    AppWindow::p->m_headerbar.pack_start( *m_button_add );
+
     if( Lifeograph::p->m_flag_open_directly )
         if( open_selected_diary( Lifeograph::p->m_flag_read_only ) == LIFEO::SUCCESS )
             return;
+
     populate_diaries();
 }
 
+void
+ViewLogin::handle_start()
+{
+    initialize();
+
+    if( Lifeograph::settings.flag_maiden_voyage || Lifeograph::p->m_flag_force_welcome )
+    {
+        Gtk::Grid* grid_welcome;
+        Gtk::Button* button_new_diary;
+        Lifeograph::builder->get_widget( "G_welcome", grid_welcome );
+        Lifeograph::builder->get_widget( "B_welcome_new_diary", button_new_diary );
+
+        m_grid_login->insert_row( 1 );
+        m_grid_login->attach( *grid_welcome, 0, 1, 1, 1 );
+
+        button_new_diary->signal_clicked().connect(
+                sigc::mem_fun( this, &ViewLogin::create_new_diary ) );
+    }
+}
+
+void
+ViewLogin::handle_login()
+{
+    AppWindow::p->m_headerbar.remove( *m_button_add );
+}
+
 void
 ViewLogin::handle_logout()
 {
-    handle_start();
+    AppWindow::p->remove();
+    initialize();
     if( Lifeograph::loginstatus == Lifeograph::LOGGED_TIME_OUT )
         show_info( Gtk::MESSAGE_INFO, _( STRING::ENTER_PASSWORD_TIMEOUT ) );
     else if( m_flag_info_is_visible )
@@ -261,8 +300,8 @@ ViewLogin::sort_by_name()
 }
 
 int
-ViewLogin::sort_by_date_func( const Gtk::TreeModel::iterator &itr1,
-                              const Gtk::TreeModel::iterator &itr2 )
+ViewLogin::sort_by_date_func( const Gtk::TreeModel::iterator& itr1,
+                              const Gtk::TreeModel::iterator& itr2 )
 {
     // SORT BY DATE (ONLY DESCENDINGLY FOR NOW)
     time_t item1 = ( *itr1 )[ colrec->date_sort ];
@@ -280,8 +319,8 @@ ViewLogin::sort_by_date_func( const Gtk::TreeModel::iterator &itr1,
 }
 
 int
-ViewLogin::sort_by_name_func( const Gtk::TreeModel::iterator &itr1,
-                              const Gtk::TreeModel::iterator &itr2 )
+ViewLogin::sort_by_name_func( const Gtk::TreeModel::iterator& itr1,
+                              const Gtk::TreeModel::iterator& itr2 )
 {
     // SORT BY DATE (ONLY DESCENDINGLY FOR NOW)
     Glib::ustring item1 = ( *itr1 )[ colrec->name ];
@@ -304,7 +343,8 @@ ViewLogin::open_selected_diary( bool read_only )
     // BEWARE: clear the diary before returning any result but SUCCESS
 
     // SET PATH
-    Result result( Diary::d->set_path( m_path_cur, false, read_only ) );
+    Result result( Diary::d->set_path( m_path_cur,
+                                       read_only ? Diary::SPT_READ_ONLY : Diary::SPT_NORMAL ) );
     switch( result )
     {
         case LIFEO::SUCCESS:
@@ -368,14 +408,13 @@ ViewLogin::open_selected_diary( bool read_only )
     }
     if( result != LIFEO::SUCCESS )
     {
-        Diary::d->clear();
         return result;
     }
 
     // HANDLE OLD DIARY
     if( Diary::d->is_old() && read_only == false )
     {
-        Gtk::MessageDialog *messagedialog
+        Gtk::MessageDialog* messagedialog
                 = new Gtk::MessageDialog( *AppWindow::p,
                                           "",
                                           false,
@@ -415,14 +454,12 @@ ViewLogin::open_selected_diary( bool read_only )
             AppWindow::p->login();
             break;
         case WRONG_PASSWORD:
-            Diary::d->clear();
             m_password_attempt_no++;
             return open_selected_diary( read_only );
         case CORRUPT_FILE:
             show_info( Gtk::MESSAGE_ERROR, _( STRING::CORRUPT_DIARY ) );
             // no break
         default:
-            Diary::d->clear();  // clear partially read content if any
             return result;
     }
 
@@ -443,20 +480,10 @@ ViewLogin::remove_selected_diary()
 void
 ViewLogin::create_new_diary()
 {
-    /*DialogSaveDiary *dialogsavediary = new DialogSaveDiary;
-    dialogsavediary->set_current_folder( Glib::get_home_dir() );
+    m_popover_add->hide();
 
-    if( dialogsavediary->run() == Gtk::RESPONSE_ACCEPT )
-    {
-        Diary::d->init_new(
-                dialogsavediary->get_filename_default() );
-        delete dialogsavediary;
-        Lifeograph::p->login();
-    }
-    else
-        delete dialogsavediary;*/
-    std::string path(Glib::get_home_dir() + "/new diary.diary" );
-    std::string pass;
+    std::string path( Glib::get_home_dir() + "/new diary.diary" );
+    std::string pass( "" );
 
     if( DialogSaveDiary::launch( path, pass ) == Gtk::RESPONSE_ACCEPT )
     {
@@ -485,7 +512,9 @@ ViewLogin::create_new_diary()
 void
 ViewLogin::add_existing_diary()
 {
-    DialogOpenDiary *filechooserdialog = new DialogOpenDiary;
+    m_popover_add->hide();
+
+    DialogOpenDiary* filechooserdialog = new DialogOpenDiary;
 
     if( m_treesel_diaries->count_selected_rows() > 0 )
         filechooserdialog->set_current_folder( Glib::path_get_dirname( m_path_cur ) );
@@ -506,7 +535,7 @@ ViewLogin::add_existing_diary()
 }
 
 void
-ViewLogin::show_info( Gtk::MessageType type, const Glib::ustring &text,
+ViewLogin::show_info( Gtk::MessageType type, const Glib::ustring& text,
                       const Glib::ustring &button, InfoResponse response )
 {
     m_label_info->set_markup( text );
@@ -562,7 +591,7 @@ ViewLogin::handle_diary_selection_changed()
 }
 
 void
-ViewLogin::handle_diary_activated( const Gtk::TreePath &path, Gtk::TreeView::Column *col )
+ViewLogin::handle_diary_activated( const Gtk::TreePath &path, Gtk::TreeView::Column* col )
 {
     // not handled directly to prevent BUTTON RELEASE event to be sent to edit screen widgets
     m_flag_diary_activated = true;
@@ -576,7 +605,7 @@ ViewLogin::handle_button_release( GdkEventButton* )
 }
 
 void
-ViewLogin::handle_key_release( GdkEventKey *event )
+ViewLogin::handle_key_release( GdkEventKey* event )
 {
     if( m_flag_diary_activated && event->keyval == GDK_KEY_Return )
         open_activated_diary();
@@ -592,10 +621,10 @@ ViewLogin::open_activated_diary()
 }
 
 bool
-ViewLogin::handle_diary_tooltip( int x, int y, bool, const Glib::RefPtr<Gtk::Tooltip> &tooltip )
+ViewLogin::handle_diary_tooltip( int x, int y, bool, const Glib::RefPtr<Gtk::Tooltip>& tooltip )
 {
     Gtk::TreeModel::Path path;
-    Gtk::TreeView::Column *column;
+    Gtk::TreeView::Column* column;
     int cell_x, cell_y;
     int bx, by;
     m_treeview_diaries->convert_widget_to_bin_window_coords( x, y, bx, by );
