@@ -43,9 +43,9 @@ TagView::TagView()
     try
     {
         Lifeograph::builder->get_widget( "Bx_tag", m_vbox );
+        Lifeograph::builder->get_widget( "G_tag_popover", m_grid_popover );
+        Lifeograph::builder->get_widget( "B_tag_dismiss", m_button_dismiss );
         Lifeograph::builder->get_widget( "frame_tag_edit", m_frame_edit );
-        Lifeograph::builder->get_widget( "M_tag_elem", m_menu );
-        Lifeograph::builder->get_widget( "menuitem_tag_dismiss", m_menuitem_dismiss );
         Lifeograph::builder->get_widget( "TB_tag_filter", m_togglebutton_filter );
         Lifeograph::builder->get_widget( "combobox_tag_category", m_combobox_category );
         Lifeograph::builder->get_widget_derived( "drawingarea_tag_chart", m_widgetchart );
@@ -70,7 +70,7 @@ TagView::TagView()
     // SIGNALS
     m_togglebutton_filter->signal_toggled().connect(
             sigc::mem_fun( this, &TagView::handle_filter_toggled ) );
-    m_menuitem_dismiss->signal_activate().connect(
+    m_button_dismiss->signal_clicked().connect(
             sigc::mem_fun( this, &TagView::dismiss_tag ) );
 
     m_combobox_category->signal_changed().connect(
@@ -151,8 +151,7 @@ TagView::apply_title( const Glib::ustring& name )
         return false;
 
     Diary::d->get_tags()->rename( m_ptr2elem, name );
-    Gtk::TreeRow row = * AppWindow::p->get_element_row( m_ptr2elem );
-    row[ PanelExtra::colrec->name ] = m_ptr2elem->get_list_str();
+    AppWindow::p->panel_extra->refresh_elem( m_ptr2elem );
 
     return true;
 }
@@ -280,11 +279,11 @@ TagView::update_theme_view()
             theme->color_base, theme->color_text, 0.9 );
     m_tag_match->property_foreground_rgba() = theme->color_base;
     m_tag_match->property_background_rgba() = contrast2(
-            theme->color_base, Theme::s_color_match, Theme::s_color_match2 );
+            theme->color_base, Theme::s_color_match1, Theme::s_color_match2 );
     m_tag_link->property_foreground_rgba() = contrast2(
-            theme->color_base, Theme::s_color_link, Theme::s_color_link2 );
+            theme->color_base, Theme::s_color_link1, Theme::s_color_link2 );
     m_tag_link_broken->property_foreground_rgba() = contrast2(
-            theme->color_base, Theme::s_color_broken, Theme::s_color_broken2 );
+            theme->color_base, Theme::s_color_broken1, Theme::s_color_broken2 );
 
     // THEME VIEW CONTENTS
     m_textview_theme->get_buffer()->set_text( "" );
@@ -377,7 +376,7 @@ TagView::reset_theme()
     m_button_theme_reset->set_sensitive( false );
     update_theme_view();
     AppWindow::p->panel_main->set_icon( m_ptr2elem->get_icon32() );
-    AppWindow::p->panel_extra->refresh_elem_icon( m_ptr2elem );
+    AppWindow::p->panel_extra->refresh_elem( m_ptr2elem );
 }
 
 void
@@ -387,7 +386,7 @@ TagView::copy_theme_from( const Tag* tag )
     m_button_theme_reset->set_sensitive( true );
     update_theme_view();
     AppWindow::p->panel_main->set_icon( m_ptr2elem->get_icon32() );
-    AppWindow::p->panel_extra->refresh_elem_icon( m_ptr2elem );
+    AppWindow::p->panel_extra->refresh_elem( m_ptr2elem );
 }
 
 void
@@ -423,10 +422,9 @@ TagView::show( Tag& tag )
 
     // CHART DATA
     ChartPoints *points( new ChartPoints );
-    for( SetDiaryElements::reverse_iterator iter = tag.get_items()->rbegin();
-         iter != tag.get_items()->rend(); ++iter )
+    for( Tag::Set::reverse_iterator iter = tag.rbegin(); iter != tag.rend(); ++iter )
     {
-        Date date( dynamic_cast< Entry* >( *iter )->get_date() );
+        Date date( ( *iter )->get_date() );
         if( ! date.is_ordinal() )
             points->increase( date.get_yearmonth() );
     }
@@ -434,16 +432,18 @@ TagView::show( Tag& tag )
     m_widgetchart->set_points( points );
 }
 
-Gtk::Menu*
-TagView::get_menu()
+Gtk::Widget*
+TagView::get_popover()
 {
     return( ( Diary::d->is_read_only() || m_ptr2elem->get_type() == DiaryElement::ET_UNTAGGED ) ?
-            NULL : m_menu );
+            NULL : m_grid_popover );
 }
 
 void
 TagView::dismiss_tag()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     Gtk::CheckButton check( _( "Also dismiss the entries associated with this tag" ) );
     if( ! AppWindow::p->confirm_dismiss_element( m_ptr2elem, &check ) )
         return;
@@ -500,7 +500,9 @@ TagView::handle_theme_button_release_event( GdkEventButton* event )
 
     if( iter.has_tag( m_tag_action ) )
     {
-        Theme* theme = m_ptr2elem->get_own_theme();
+        if( !m_ptr2elem->get_has_own_theme() )
+            m_ptr2elem->create_own_theme_duplicating( ThemeSystem::get() );
+        Theme* theme = m_ptr2elem->get_theme();
 
         if( iter.has_tag( m_tag_heading ) )
             launch_color_dialog( theme->color_heading );
@@ -517,7 +519,7 @@ TagView::handle_theme_button_release_event( GdkEventButton* event )
 
         m_button_theme_reset->set_sensitive( true );
         AppWindow::p->panel_main->set_icon( m_ptr2elem->get_icon32() );
-        AppWindow::p->panel_extra->refresh_elem_icon( m_ptr2elem );
+        AppWindow::p->panel_extra->refresh_elem( m_ptr2elem );
     }
 }
 
@@ -549,6 +551,7 @@ void
 TagView::launch_color_dialog( Gdk::RGBA& color )
 {
     Gtk::ColorChooserDialog *dlg = new Gtk::ColorChooserDialog;
+    dlg->set_transient_for( * AppWindow::p );
     dlg->set_use_alpha( false );
     dlg->set_rgba( color );
 
@@ -565,6 +568,7 @@ void
 TagView::launch_font_dialog()
 {
     Gtk::FontChooserDialog *dlg = new Gtk::FontChooserDialog;
+    dlg->set_transient_for( * AppWindow::p );
     dlg->set_font_desc( m_ptr2elem->get_theme()->font );
 
     if( dlg->run() == Gtk::RESPONSE_OK )
@@ -584,16 +588,16 @@ CategoryTagsView::CategoryTagsView()
     try
     {
         Lifeograph::builder->get_widget( "Bx_categorytags", m_vbox );
-        Lifeograph::builder->get_widget( "M_tagctg_elem", m_menu );
-        Lifeograph::builder->get_widget( "menuitem_tagctg_dismiss", m_menuitem_dismiss );
-        Lifeograph::builder->get_widget_derived( "drawingarea_ctgtag_chart", m_widgetchart );
+        Lifeograph::builder->get_widget( "G_tagctg_popover", m_grid_popover );
+        Lifeograph::builder->get_widget( "B_tagctg_dismiss", m_button_dismiss );
+        Lifeograph::builder->get_widget_derived( "DA_ctgtag_chart", m_widgetchart );
     }
     catch( ... )
     {
         throw LIFEO::Error( "Failed to create the tag category view" );
     }
 
-    m_menuitem_dismiss->signal_activate().connect(
+    m_button_dismiss->signal_clicked().connect(
             sigc::mem_fun( this, &CategoryTagsView::dismiss_category ) );
 }
 
@@ -609,17 +613,16 @@ CategoryTagsView::show( CategoryTags& category )
     AppWindow::p->panel_main->show( this );
 
     // CHART DATA
-    ChartPoints *points( new ChartPoints );
+    ChartPoints* points( new ChartPoints );
     for( CategoryTags::iterator iter_tag = category.begin();
          iter_tag != category.end();
          iter_tag++ )
     {
-        Tag *tag( *iter_tag );
+        Tag* tag( *iter_tag );
 
-        for( SetDiaryElements::iterator iter = tag->get_items()->begin();
-             iter != tag->get_items()->end(); ++iter )
+        for( Tag::Set::iterator iter = tag->begin(); iter != tag->end(); ++iter )
         {
-            Date date( dynamic_cast< Entry* >( *iter )->get_date() );
+            Date date( ( *iter )->get_date() );
             if( ! date.is_ordinal() )
                 points->increase( date.get_yearmonth() );
         }
@@ -628,10 +631,10 @@ CategoryTagsView::show( CategoryTags& category )
     m_widgetchart->set_points( points );
 }
 
-Gtk::Menu*
-CategoryTagsView::get_menu()
+Gtk::Widget*
+CategoryTagsView::get_popover()
 {
-    return( Diary::d->is_read_only() ? NULL : m_menu );
+    return( Diary::d->is_read_only() ? NULL : m_grid_popover );
 }
 
 bool
@@ -657,6 +660,8 @@ CategoryTagsView::apply_title( const Glib::ustring& name )
 void
 CategoryTagsView::dismiss_category()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     Gtk::CheckButton check( _( "Also dismiss the tags in the category" ) );
     if( ! AppWindow::p->confirm_dismiss_element( m_ptr2elem, &check ) )
         return;
@@ -677,12 +682,14 @@ ChapterView::ChapterView()
     try
     {
         Lifeograph::builder->get_widget( "Bx_chapter", m_vbox );
-        Lifeograph::builder->get_widget( "M_chapter_elem", m_menu );
-        Lifeograph::builder->get_widget( "MI_todogroup_todo", m_menuitem_todo );
-        Lifeograph::builder->get_widget( "MI_todogroup_done", m_menuitem_done );
-        Lifeograph::builder->get_widget( "MI_todogroup_canceled", m_menuitem_canceled );
-        Lifeograph::builder->get_widget( "MS_todogroup_1", m_menuseparator_1 );
-        Lifeograph::builder->get_widget( "MI_chapter_dismiss", m_menuitem_dismiss );
+        Lifeograph::builder->get_widget( "G_chapter_popover", m_grid_popover );
+        Lifeograph::builder->get_widget( "I_chapter_not_todo", m_I_not_todo );
+        Lifeograph::builder->get_widget( "RB_chapter_not_todo", m_button_not_todo );
+        Lifeograph::builder->get_widget( "RB_chapter_todo", m_button_todo );
+        Lifeograph::builder->get_widget( "RB_chapter_progressed", m_button_progressed );
+        Lifeograph::builder->get_widget( "RB_chapter_done", m_button_done );
+        Lifeograph::builder->get_widget( "RB_chapter_canceled", m_button_canceled );
+        Lifeograph::builder->get_widget( "B_chapter_dismiss", m_button_dismiss );
 
 //		Lifeograph::builder->get_widget( "label_chapter_period", m_label_period );
 //		Lifeograph::builder->get_widget( "hbox_chapter_period", m_hbox_period );
@@ -700,14 +707,18 @@ ChapterView::ChapterView()
     }
 
     // SIGNALS
-    m_menuitem_todo->signal_activate().connect(
+    m_button_not_todo->signal_toggled().connect(
+            sigc::bind( sigc::mem_fun( this, &ChapterView::set_todo_status ), ES::NOT_TODO ) );
+    m_button_todo->signal_toggled().connect(
             sigc::bind( sigc::mem_fun( this, &ChapterView::set_todo_status ), ES::TODO ) );
-    m_menuitem_done->signal_activate().connect(
+    m_button_progressed->signal_toggled().connect(
+            sigc::bind( sigc::mem_fun( this, &ChapterView::set_todo_status ), ES::PROGRESSED ) );
+    m_button_done->signal_toggled().connect(
             sigc::bind( sigc::mem_fun( this, &ChapterView::set_todo_status ), ES::DONE ) );
-    m_menuitem_canceled->signal_activate().connect(
+    m_button_canceled->signal_toggled().connect(
             sigc::bind( sigc::mem_fun( this, &ChapterView::set_todo_status ), ES::CANCELED ) );
 
-    m_menuitem_dismiss->signal_activate().connect(
+    m_button_dismiss->signal_clicked().connect(
             sigc::mem_fun( this, &ChapterView::dismiss_chapter ) );
 
     m_entry_begins->signal_changed().connect(
@@ -724,6 +735,8 @@ ChapterView::ChapterView()
 void
 ChapterView::dismiss_chapter()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     Gtk::CheckButton check( _( "Also dismiss the entries within" ) );
     if( ! AppWindow::p->confirm_dismiss_element( m_ptr2elem, &check ) )
         return;
@@ -756,16 +769,13 @@ ChapterView::apply_title( const Glib::ustring& str )
 void
 ChapterView::handle_date_changed()
 {
-    try
-    {
-        Date date( m_entry_begins->get_text() );
+    Date date( m_entry_begins->get_text() );
+
+    if( date.is_set() && ! date.is_ordinal() )
         m_button_date_apply->set_sensitive(
                 ! Diary::d->get_current_chapter_ctg()->get_chapter( date.m_date ) );
-    }
-    catch( LIFEO::Error &er )
-    {
+    else
         m_button_date_apply->set_sensitive( false );
-    }
 }
 
 void
@@ -774,10 +784,14 @@ ChapterView::handle_date_applied()
     // a caution against calls by an entry activation event:
     if( ! m_button_date_apply->is_sensitive() )
         return;
+
     Date date( m_entry_begins->get_text() );
-    if( Diary::d->get_current_chapter_ctg()->set_chapter_date( m_ptr2elem, date.m_date ) )
+
+    if( date.is_set() &&
+        Diary::d->get_current_chapter_ctg()->set_chapter_date( m_ptr2elem, date.m_date ) )
     {
         m_button_date_apply->set_sensitive( false );
+        Diary::d->update_entries_in_chapters();
         AppWindow::p->panel_diary->update_entry_list();
         update_labels();
     }
@@ -793,7 +807,7 @@ ChapterView::update_labels()
         m_entry_begins->set_text( m_ptr2elem->m_date_begin.format_string() );
 
         CategoryChapters::iterator iter( Diary::d->get_current_chapter_ctg()->find(
-                                                m_ptr2elem->get_date().m_date ) );
+                                                m_ptr2elem->get_date_t() ) );
         if( m_ptr2elem->m_time_span == 0 )
             m_label_ends->set_text( _( "Unlimited" ) );
         else
@@ -843,32 +857,33 @@ ChapterView::show( Chapter& chapter )
     if( ! Diary::d->is_read_only() )
         m_frame_actions->set_visible( flag_ordinal );
 
-    m_menuitem_todo->set_visible( chapter.m_date_begin.is_todo() );
-    m_menuitem_done->set_visible( chapter.m_date_begin.is_todo() );
-    m_menuitem_canceled->set_visible( chapter.m_date_begin.is_todo() );
-    m_menuseparator_1->set_visible( chapter.m_date_begin.is_todo() );
+    m_I_not_todo->set( chapter.get_date().is_ordinal() ?
+            Lifeograph::icons->chapter_32 : Lifeograph::icons->month_32 );
 
-    if( m_ptr2elem->get_type() == DiaryElement::ET_TODO_GRP )
+    switch( m_ptr2elem->get_todo_status() )
     {
-        switch( m_ptr2elem->get_todo_status() )
-        {
-            case ES::TODO:
-                m_menuitem_todo->set_active();
-                break;
-            case ES::DONE:
-                m_menuitem_done->set_active();
-                break;
-            case ES::CANCELED:
-                m_menuitem_canceled->set_active();
-                break;
-        }
+        case ES::NOT_TODO:
+            m_button_not_todo->set_active();
+            break;
+        case ES::TODO:
+            m_button_todo->set_active();
+            break;
+        case ES::PROGRESSED:
+            m_button_progressed->set_active();
+            break;
+        case ES::DONE:
+            m_button_done->set_active();
+            break;
+        case ES::CANCELED:
+            m_button_canceled->set_active();
+            break;
     }
 }
 
-Gtk::Menu*
-ChapterView::get_menu()
+Gtk::Widget*
+ChapterView::get_popover()
 {
-    return( Diary::d->is_read_only() ? NULL : m_menu );
+    return( Diary::d->is_read_only() ? NULL : m_grid_popover );
 }
 
 void
@@ -894,9 +909,11 @@ FilterView::FilterView()
     try
     {
         Lifeograph::builder->get_widget( "Bx_filter", m_vbox );
-        Lifeograph::builder->get_widget( "TB_filter_todo", m_tglbtn_todo );
-        Lifeograph::builder->get_widget( "TB_filter_done", m_tglbtn_done );
-        Lifeograph::builder->get_widget( "TB_filter_canceled", m_tglbtn_canceled );
+        Lifeograph::builder->get_widget( "TB_filter_not_todo", m_tglbtn_todo_not );
+        Lifeograph::builder->get_widget( "TB_filter_todo", m_tglbtn_todo_open );
+        Lifeograph::builder->get_widget( "TB_filter_progressed", m_tglbtn_todo_progressed );
+        Lifeograph::builder->get_widget( "TB_filter_done", m_tglbtn_todo_done );
+        Lifeograph::builder->get_widget( "TB_filter_canceled", m_tglbtn_todo_canceled );
         Lifeograph::builder->get_widget( "TB_filter_not_favored", m_tglbtn_not_favored );
         Lifeograph::builder->get_widget( "TB_filter_favored", m_tglbtn_favored );
         Lifeograph::builder->get_widget( "TB_filter_not_trashed", m_tglbtn_not_trashed );
@@ -912,9 +929,9 @@ FilterView::FilterView()
         Lifeograph::builder->get_widget( "B_filter_remove_entry", m_button_remove_entry );
         Lifeograph::builder->get_widget( "B_filter_rm_all_entries", m_button_rm_all_entries );
 
-        Lifeograph::builder->get_widget( "M_filter_elem", m_menu );
-        Lifeograph::builder->get_widget( "MI_filter_revert", m_menuitem_revert_to_default );
-        Lifeograph::builder->get_widget( "MI_filter_make_default", m_menuitem_make_default );
+        Lifeograph::builder->get_widget( "G_filter_popover", m_grid_popover );
+        Lifeograph::builder->get_widget( "B_filter_revert", m_button_revert_to_default );
+        Lifeograph::builder->get_widget( "B_filter_make_default", m_button_make_default );
 
         m_liststore_entries = Gtk::ListStore::create( *colrec_entries );
     }
@@ -923,16 +940,20 @@ FilterView::FilterView()
         throw LIFEO::Error( "Failed to create the filter view" );
     }
 
-    m_menuitem_revert_to_default->signal_activate().connect(
+    m_button_revert_to_default->signal_clicked().connect(
             sigc::mem_fun( this, &FilterView::revert_to_default ) );
-    m_menuitem_make_default->signal_activate().connect(
+    m_button_make_default->signal_clicked().connect(
             sigc::mem_fun( this, &FilterView::make_default ) );
 
-    m_tglbtn_todo->signal_toggled().connect(
+    m_tglbtn_todo_not->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_todo_changed ) );
-    m_tglbtn_done->signal_toggled().connect(
+    m_tglbtn_todo_open->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_todo_changed ) );
-    m_tglbtn_canceled->signal_toggled().connect(
+    m_tglbtn_todo_progressed->signal_toggled().connect(
+            sigc::mem_fun( this, &FilterView::handle_todo_changed ) );
+    m_tglbtn_todo_done->signal_toggled().connect(
+            sigc::mem_fun( this, &FilterView::handle_todo_changed ) );
+    m_tglbtn_todo_canceled->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_todo_changed ) );
 
     m_tglbtn_trashed->signal_toggled().connect(
@@ -974,7 +995,7 @@ FilterView::FilterView()
 void
 FilterView::handle_login()
 {
-    m_menuitem_make_default->set_visible( ! Diary::d->is_read_only() );
+    m_button_make_default->set_visible( ! Diary::d->is_read_only() );
 }
 
 void
@@ -1014,9 +1035,11 @@ FilterView::update()
     m_tglbtn_not_favored->set_active( fs & ES::SHOW_NOT_FAVORED );
     m_tglbtn_trashed->set_active( fs & ES::SHOW_TRASHED );
     m_tglbtn_not_trashed->set_active( fs & ES::SHOW_NOT_TRASHED );
-    m_tglbtn_todo->set_active( fs & ES::SHOW_TODO );
-    m_tglbtn_done->set_active( fs & ES::SHOW_DONE );
-    m_tglbtn_canceled->set_active( fs & ES::SHOW_CANCELED );
+    m_tglbtn_todo_not->set_active( fs & ES::SHOW_NOT_TODO );
+    m_tglbtn_todo_open->set_active( fs & ES::SHOW_TODO );
+    m_tglbtn_todo_progressed->set_active( fs & ES::SHOW_PROGRESSED );
+    m_tglbtn_todo_done->set_active( fs & ES::SHOW_DONE );
+    m_tglbtn_todo_canceled->set_active( fs & ES::SHOW_CANCELED );
 
     // TAG
     if( m_ptr2elem->get_tag() )
@@ -1052,6 +1075,8 @@ FilterView::get_info_str() const
 void
 FilterView::revert_to_default()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     m_ptr2elem->set( Diary::d->get_filter_default() );
     m_ptr2elem->set_status_outstanding();
     update();
@@ -1062,6 +1087,8 @@ FilterView::revert_to_default()
 void
 FilterView::make_default()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     Diary::d->get_filter_default()->set( m_ptr2elem );
 }
 
@@ -1123,11 +1150,12 @@ FilterView::handle_todo_changed()
     if( Lifeograph::m_internaloperation )
         return;
 
-    bool todo( m_tglbtn_todo->get_active() );
-    bool done( m_tglbtn_done->get_active() );
-    bool canceled( m_tglbtn_canceled->get_active() );
+    m_ptr2elem->set_todo( m_tglbtn_todo_not->get_active(),
+                          m_tglbtn_todo_open->get_active(),
+                          m_tglbtn_todo_progressed->get_active(),
+                          m_tglbtn_todo_done->get_active(),
+                          m_tglbtn_todo_canceled->get_active() );
 
-    m_ptr2elem->set_todo( todo, done, canceled );
     AppWindow::p->panel_diary->update_entry_list();
 }
 
@@ -1179,28 +1207,24 @@ FilterView::handle_date_begin_changed()
     if( Lifeograph::m_internaloperation )
         return;
 
-    m_entry_date_begin->unset_icon();
+    m_entry_date_begin->unset_color();
 
     if( m_entry_date_begin->get_text_length() == 0 )
     {
         Diary::d->set_filter_date_begin( 0 );
-        AppWindow::p->panel_diary->update_calendar();
-        AppWindow::p->panel_diary->update_entry_list();
     }
     else
     {
-        try
-        {
-            Date date( m_entry_date_begin->get_text() );
+        Date date( m_entry_date_begin->get_text() );
+
+        if( date.is_set() )
             Diary::d->set_filter_date_begin( date.m_date );
-            AppWindow::p->panel_diary->update_calendar();
-            AppWindow::p->panel_diary->update_entry_list();
-        }
-        catch( LIFEO::Error &er )
-        {
-            m_entry_date_begin->set_icon_from_icon_name( "dialog-error" );
-        }
+        else
+            m_entry_date_begin->override_color( Gdk::RGBA( "Red" ) );
     }
+
+    AppWindow::p->panel_diary->update_calendar();
+    AppWindow::p->panel_diary->update_entry_list();
 }
 
 void
@@ -1209,28 +1233,24 @@ FilterView::handle_date_end_changed()
     if( Lifeograph::m_internaloperation )
         return;
 
-    m_entry_date_end->unset_icon();
+    m_entry_date_end->unset_color();
 
     if( m_entry_date_end->get_text_length() == 0 )
     {
-        Diary::d->set_filter_date_end( 0 );
-        AppWindow::p->panel_diary->update_calendar();
-        AppWindow::p->panel_diary->update_entry_list();
+        Diary::d->set_filter_date_end( Date::DATE_MAX );
     }
     else
     {
-        try
-        {
-            Date date( m_entry_date_end->get_text() );
+        Date date( m_entry_date_end->get_text() );
+
+        if( date.is_set() )
             Diary::d->set_filter_date_end( date.m_date );
-            AppWindow::p->panel_diary->update_calendar();
-            AppWindow::p->panel_diary->update_entry_list();
-        }
-        catch( LIFEO::Error &er )
-        {
-            m_entry_date_end->set_icon_from_icon_name( "dialog-error" );
-        }
+        else
+            m_entry_date_end->override_color( Gdk::RGBA( "Red" ) );
     }
+
+    AppWindow::p->panel_diary->update_calendar();
+    AppWindow::p->panel_diary->update_entry_list();
 }
 
 void
@@ -1289,13 +1309,22 @@ FilterView::handle_entry_dropped( const Glib::RefPtr< Gdk::DragContext >& contex
         {
             case DiaryElement::ET_ENTRY:
             {
-                Entry *entry( dynamic_cast< Entry* >( Lifeograph::s_elem_dragged ) );
+                Entry* entry( dynamic_cast< Entry* >( Lifeograph::s_elem_dragged ) );
                 m_ptr2elem->add_entry( entry );
                 update_entries();
                 AppWindow::p->panel_diary->update_calendar();
                 AppWindow::p->panel_diary->update_entry_list();
-            }
                 break;
+            }
+            case DiaryElement::ET_MULTIPLE_ENTRIES:
+            {
+                sigc::slot< void, Entry* > s = sigc::mem_fun( *m_ptr2elem, &Filter::add_entry );
+                AppWindow::p->panel_diary->do_for_each_selected_entry( s );
+                update_entries();
+                AppWindow::p->panel_diary->update_calendar();
+                AppWindow::p->panel_diary->update_entry_list();
+                break;
+            }
             default:
                 retval = false;
                 break;
@@ -1321,20 +1350,16 @@ DiaryView::DiaryView()
     Diary::shower = this;
     m_ptr2elem = Diary::d;	// for now no other diary is shown in the view
 
-    Gtk::MenuItem*  menuitem_export( NULL );
-    Gtk::Box*       hbox_chapter_ctg( NULL );
+    Gtk::Button*    button_export( NULL );
+
     try
     {
         Lifeograph::builder->get_widget( "Bx_diary", m_vbox );
-
-        Lifeograph::builder->get_widget( "M_diary_elem", m_menu );
-        Lifeograph::builder->get_widget( "menuitem_import", m_menuitem_import );
-        Lifeograph::builder->get_widget( "menuitem_export", menuitem_export );
-        Lifeograph::builder->get_widget( "menuseparator_diary_1", m_menuseparator_1 );
-        Lifeograph::builder->get_widget( "menuitem_encryption", m_menuitem_encryption );
-        Lifeograph::builder->get_widget( "menuseparator_diary_2", m_menuseparator_2 );
-        Lifeograph::builder->get_widget( "menuitem_diary_dont_save",
-                m_menuitem_dont_save );
+        Lifeograph::builder->get_widget( "G_diary_popover", m_grid_popover );
+        Lifeograph::builder->get_widget( "B_diary_import", m_button_import );
+        Lifeograph::builder->get_widget( "B_diary_export", button_export );
+        Lifeograph::builder->get_widget( "S_diary_encryption", m_separator_encryption );
+        Lifeograph::builder->get_widget( "B_diary_encryption", m_button_encryption );
 
         Lifeograph::builder->get_widget( "label_path", m_label_path );
         Lifeograph::builder->get_widget( "combobox_diary_spellcheck", m_combobox_spellcheck );
@@ -1343,8 +1368,6 @@ DiaryView::DiaryView()
         Lifeograph::builder->get_widget( "label_startup_elem", m_label_startup_elem );
         Lifeograph::builder->get_widget( "label_startup_elem_drop", m_label_startup_elem_drop );
 
-        Lifeograph::builder->get_widget( "hbox_cur_chapter_ctg",
-                hbox_chapter_ctg );
         Lifeograph::builder->get_widget( "button_chapter_ctg_dismiss",
                 m_button_chapter_ctg_dismiss );
         Lifeograph::builder->get_widget( "button_chapter_ctg_rename",
@@ -1372,7 +1395,7 @@ DiaryView::DiaryView()
     row[ colrec_startup_type.type ] = HOME_LAST_ELEM;
     row = * m_liststore_startup_type->append();
     row[ colrec_startup_type.name ] = _( "Always Show a Fixed Item" );
-    row[ colrec_startup_type.type ] = DEID_MIN;
+    row[ colrec_startup_type.type ] = DEID_DIARY;
 
     m_label_startup_elem_drop->drag_dest_set( Lifeograph::p->drag_targets_entry );
 
@@ -1404,14 +1427,12 @@ DiaryView::DiaryView()
     m_button_chapter_ctg_dismiss->signal_clicked().connect(
             sigc::mem_fun( this, &DiaryView::dismiss_cur_chapter_ctg ) );
 
-    m_menuitem_import->signal_activate().connect(
+    m_button_import->signal_clicked().connect(
             sigc::mem_fun( *this, &DiaryView::start_dialog_import ) );
-    menuitem_export->signal_activate().connect(
+    button_export->signal_clicked().connect(
             sigc::mem_fun( *this, &DiaryView::start_dialog_export ) );
-    m_menuitem_encryption->signal_activate().connect(
+    m_button_encryption->signal_clicked().connect(
             sigc::mem_fun( *this, &DiaryView::start_dialog_password ) );
-    m_menuitem_dont_save->signal_activate().connect(
-            sigc::bind( sigc::mem_fun( *AppWindow::p, &AppWindow::logout ), false ) );
 }
 
 DiaryView::~DiaryView()
@@ -1457,14 +1478,12 @@ DiaryView::handle_login()
     m_combobox_spellcheck->set_sensitive( editable );
     m_combobox_chapter_ctg->set_sensitive( editable );
 
-    m_menuitem_import->set_visible( editable );
-    m_menuseparator_1->set_visible( editable );
-    m_menuitem_encryption->set_visible( editable );
-    m_menuseparator_2->set_visible( editable );
-    m_menuitem_dont_save->set_visible( editable );
+    m_button_import->set_visible( editable );
+    m_separator_encryption->set_visible( editable );
+    m_button_encryption->set_visible( editable );
 
-    m_menuitem_encryption->set_label( Diary::d->m_passphrase.empty() ? _( "Encrypt..." ) :
-                                                _( "Change Password..." ) );
+    m_button_encryption->set_label( Diary::d->m_passphrase.empty() ? _( "Encrypt..." ) :
+                                                _( STRING::CHANGE_PASSWORD ) );
 
     // BODY
     m_label_path->set_markup( Glib::ustring::compose( "<a href=\"file://%1\">%1</a>",
@@ -1498,18 +1517,22 @@ DiaryView::show( Diary& diary )
 void
 DiaryView::start_dialog_password()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     if( DialogPassword::launch(
             m_ptr2elem->is_encrypted() ? DialogPassword::OT_CHANGE : DialogPassword::OT_ADD,
             m_ptr2elem ) == RESPONSE_GO )
     {
         AppWindow::p->panel_main->refresh_extra_info();
-        m_menuitem_encryption->set_label( _( "Change Password..." ) );
+        m_button_encryption->set_label( _( STRING::CHANGE_PASSWORD ) );
     }
 }
 
 void
 DiaryView::start_dialog_import()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     Glib::RefPtr< Gtk::Builder > builder( Gtk::Builder::create_from_file( UIDIR "/import.ui" ) );
 
     DialogImport* dialog_import;
@@ -1529,6 +1552,8 @@ DiaryView::start_dialog_import()
 void
 DiaryView::start_dialog_export()
 {
+    AppWindow::p->panel_main->hide_popover();
+
     if( m_ptr2elem->is_encrypted() ?
             DialogPassword::launch( DialogPassword::OT_AUTHENTICATE,
                                     m_ptr2elem ) == RESPONSE_GO : true )
@@ -1712,13 +1737,13 @@ DiaryView::handle_cur_chapter_ctg_changed()
         switch( row[ colrec_chapter_ctg.type ] )
         {
             case CCCT_NEW: // create new
-                m_ptr2elem->m_ptr2chapter_ctg_cur = m_ptr2elem->create_chapter_ctg();
+                m_ptr2elem->set_current_chapter_ctg( m_ptr2elem->create_chapter_ctg() );
                 update_combobox_chapter_ctg();
                 flag_existing_ctg = true;
                 break;
             case CCCT_CATEGORY:
                 flag_existing_ctg = true;
-                m_ptr2elem->m_ptr2chapter_ctg_cur = row[ colrec_chapter_ctg.ptr ];
+                m_ptr2elem->set_current_chapter_ctg( row[ colrec_chapter_ctg.ptr ] );
                 AppWindow::p->panel_diary->update_entry_list();
                 break;
             default:	// for separators
