@@ -47,21 +47,19 @@ class TagView : public ElementShower< Tag >
         Glib::ustring           get_info_str() const
         {
             if( m_ptr2elem->get_type() == DiaryElement::ET_TAG )
-                return Glib::ustring::compose( _( "Tag with %1 entries" ),
+                return Glib::ustring::compose( _( STRING::ELEM_WITH_ENTRIES ),
+                                               m_ptr2elem->get_type_name(),
                                                m_ptr2elem->get_size() );
             else
                 return _( "Filter and theme entries without tags" );
         }
-#if LIFEOGRAPH_DEBUG_BUILD
-        Glib::ustring           get_tip_str() const
-        { return Glib::ustring::compose( "DEID: %1", m_ptr2elem->get_id() ); }
-#endif
-        Gtk::Menu*              get_menu();
+
+        Gtk::Widget*            get_popover();
         Gtk::Widget*            get_extra_tools()
         { return m_togglebutton_filter; }
 
         void                    handle_login();
-        void                    show( Tag &tag );
+        void                    show( Tag& tag );
 
         void                    update_combobox_categories();
         void                    update_button_filter_tag();
@@ -100,7 +98,7 @@ class TagView : public ElementShower< Tag >
 
         Gtk::Frame*             m_frame_edit;
         Gtk::ToggleButton*      m_togglebutton_filter;
-        Gtk::MenuItem*          m_menuitem_dismiss;
+        Gtk::Button*            m_button_dismiss;
         Gtk::ComboBox*          m_combobox_category;
         WidgetChart*            m_widgetchart;
         Gtk::TextView*          m_textview_theme;
@@ -146,11 +144,8 @@ class CategoryTagsView : public ElementShower< CategoryTags >
         Glib::ustring           get_info_str() const
         { return Glib::ustring::compose( _( "Tag category with %1 tags" ),
                                          m_ptr2elem->size() ); }
-#if LIFEOGRAPH_DEBUG_BUILD
-        Glib::ustring           get_tip_str() const
-        { return Glib::ustring::compose( "DEID: %1", m_ptr2elem->get_id() ); }
-#endif
-        Gtk::Menu*              get_menu();
+
+        Gtk::Widget*            get_popover();
 
         void                    show( CategoryTags& );
 
@@ -164,7 +159,7 @@ class CategoryTagsView : public ElementShower< CategoryTags >
 
         void                    dismiss_category();
 
-        Gtk::MenuItem*          m_menuitem_dismiss;
+        Gtk::Button*            m_button_dismiss;
         WidgetChart*            m_widgetchart;
 };
 
@@ -176,30 +171,30 @@ class ChapterView : public ElementShower< Chapter >
 
         Glib::ustring           get_title_str() const
         {
-            if( m_ptr2elem->m_date_begin.is_ordinal() )
-                return Glib::ustring::compose( "%1: %2",
-                                               m_ptr2elem->m_date_begin.format_string(),
-                                               m_ptr2elem->m_name );
-            else
-                return m_ptr2elem->m_name;
+            Glib::ustring title;
+
+            if( ! m_ptr2elem->get_date().is_hidden() )
+            {
+                title = m_ptr2elem->get_date().format_string();
+                title += "  ";
+            }
+
+            title += m_ptr2elem->m_name;
+
+            return title;
         }
         Glib::ustring           get_info_str() const
         {
-            if( m_ptr2elem->m_date_begin.is_ordinal() )
-                return Glib::ustring::compose( _( "Topic with %1 entries" ),
-                                               m_ptr2elem->m_size );
+            if( m_ptr2elem->m_time_span )
+                return Glib::ustring::compose( _( "Dated Chapter with %1 entries in %2 days" ),
+                                               m_ptr2elem->get_size(), m_ptr2elem->m_time_span );
             else
-                return Glib::ustring::compose(
-                        m_ptr2elem->m_time_span ?
-                                _( "Chapter with %1 entries in %2 days" ) :
-                                _( "Chapter with %1 entries" ),
-                        m_ptr2elem->get_size(), m_ptr2elem->m_time_span );
+                return Glib::ustring::compose( _( STRING::ELEM_WITH_ENTRIES ),
+                                               m_ptr2elem->get_type_name(),
+                                               m_ptr2elem->get_size() );
         }
-#if LIFEOGRAPH_DEBUG_BUILD
-        Glib::ustring           get_tip_str() const
-        { return Glib::ustring::compose( "DEID: %1", m_ptr2elem->get_id() ); }
-#endif
-        Gtk::Menu*              get_menu();
+
+        Gtk::Widget*            get_popover();
 
         void                    handle_login();
         void                    show( Chapter& );
@@ -222,11 +217,13 @@ class ChapterView : public ElementShower< Chapter >
         void                    add_new_entry();
         void                    dismiss_chapter();
 
-        Gtk::RadioMenuItem*     m_menuitem_todo;
-        Gtk::RadioMenuItem*     m_menuitem_done;
-        Gtk::RadioMenuItem*     m_menuitem_canceled;
-        Gtk::SeparatorMenuItem* m_menuseparator_1;
-        Gtk::MenuItem*          m_menuitem_dismiss;
+        Gtk::Image*             m_I_not_todo;
+        Gtk::RadioButton*       m_button_not_todo;
+        Gtk::RadioButton*       m_button_todo;
+        Gtk::RadioButton*       m_button_progressed;
+        Gtk::RadioButton*       m_button_done;
+        Gtk::RadioButton*       m_button_canceled;
+        Gtk::Button*            m_button_dismiss;
 
         Gtk::Entry*             m_entry_begins;
         Gtk::Button*            m_button_date_apply;
@@ -237,56 +234,6 @@ class ChapterView : public ElementShower< Chapter >
         Gtk::Frame*             m_frame_actions;
 };
 
-// THEME VIEW ======================================================================================
-/*class ThemeView : public ElementShower< Theme >
-{
-    public:
-                                ThemeView();
-
-        Glib::ustring           get_title_str() const
-        { return m_ptr2elem->get_name(); }
-        Glib::ustring   get_info_str() const;
-#if LIFEOGRAPH_DEBUG_BUILD
-        Glib::ustring           get_tip_str() const
-        { return Glib::ustring::compose( "DEID: %1", m_ptr2elem->get_id() ); }
-#endif
-        Gtk::Menu*              get_menu();
-
-        void                    show( Theme& );
-
-    protected:
-        bool                    is_title_editable() const
-        { return( ! m_ptr2elem->is_system() ); }
-        Glib::ustring           get_title_edit_str() const
-        { return m_ptr2elem->get_name(); }
-        bool                    check_title_applicable( const Glib::ustring& ) const;
-        bool                    apply_title( const Glib::ustring& );
-
-        void                    handle_font_changed();
-        void                    handle_color_changed();
-        void                    update_preview();
-
-        void                    duplicate();
-        void                    make_default();
-        void                    dismiss_theme();
-
-        Gtk::MenuItem           *m_menuitem_duplicate;
-        Gtk::MenuItem           *m_menuitem_make_default;
-        Gtk::SeparatorMenuItem  *m_menuseparator;
-        Gtk::MenuItem           *m_menuitem_dismiss;
-
-        Gtk::FontButton         *m_fontbutton;
-        Gtk::ColorButton        *m_colorbutton_bground;
-        Gtk::ColorButton        *m_colorbutton_text;
-        Gtk::ColorButton        *m_colorbutton_heading;
-        Gtk::ColorButton        *m_colorbutton_subheading;
-        Gtk::ColorButton        *m_colorbutton_highlight;
-        Gtk::EventBox           *m_eventbox_preview;
-        Gtk::Label              *m_label_preview;
-        Gtk::Frame              *m_frame_font;
-        Gtk::Frame              *m_frame_colors;
-};*/
-
 // FILTER VIEW =====================================================================================
 class FilterView : public ElementShower< Filter >
 {
@@ -296,10 +243,7 @@ class FilterView : public ElementShower< Filter >
         Glib::ustring           get_title_str() const
         { return m_ptr2elem->get_name(); }
         Glib::ustring           get_info_str() const;
-#if LIFEOGRAPH_DEBUG_BUILD
-        Glib::ustring           get_tip_str() const
-        { return Glib::ustring::compose( "DEID: %1", m_ptr2elem->get_id() ); }
-#endif
+
         void                    handle_login();
         void                    show( Filter& );
 
@@ -338,9 +282,11 @@ class FilterView : public ElementShower< Filter >
                                         int, int, guint );
         void                    handle_entry_selection_changed();
 
-        Gtk::ToggleButton*      m_tglbtn_todo;
-        Gtk::ToggleButton*      m_tglbtn_done;
-        Gtk::ToggleButton*      m_tglbtn_canceled;
+        Gtk::ToggleButton*      m_tglbtn_todo_not;
+        Gtk::ToggleButton*      m_tglbtn_todo_open;
+        Gtk::ToggleButton*      m_tglbtn_todo_progressed;
+        Gtk::ToggleButton*      m_tglbtn_todo_done;
+        Gtk::ToggleButton*      m_tglbtn_todo_canceled;
         Gtk::ToggleButton*      m_tglbtn_not_favored;
         Gtk::ToggleButton*      m_tglbtn_favored;
         Gtk::ToggleButton*      m_tglbtn_not_trashed;
@@ -357,8 +303,8 @@ class FilterView : public ElementShower< Filter >
         Gtk::Button*            m_button_remove_entry;
         Gtk::Button*            m_button_rm_all_entries;
 
-        Gtk::MenuItem*          m_menuitem_make_default;
-        Gtk::MenuItem*          m_menuitem_revert_to_default;
+        Gtk::Button*            m_button_make_default;
+        Gtk::Button*            m_button_revert_to_default;
 
         class ColrecEntries : public Gtk::TreeModel::ColumnRecord
         {
@@ -441,11 +387,9 @@ class DiaryView : public ElementShower< Diary >
         bool                    is_row_separator( const Glib::RefPtr< Gtk::TreeModel >&,
                                                   const Gtk::TreeIter );
 
-        Gtk::MenuItem*          m_menuitem_import;
-        Gtk::SeparatorMenuItem* m_menuseparator_1;
-        Gtk::MenuItem*          m_menuitem_encryption;
-        Gtk::SeparatorMenuItem* m_menuseparator_2;
-        Gtk::MenuItem*          m_menuitem_dont_save;
+        Gtk::Button*            m_button_import;
+        Gtk::Separator*         m_separator_encryption;
+        Gtk::Button*            m_button_encryption;
 
         Gtk::Frame*             m_frame_startup;
         Gtk::Frame*             m_frame_chapters;
