@@ -29,7 +29,7 @@
 using namespace LIFEO;
 
 
-// WIDGET ENTRY LIST ===========================================================
+// WIDGET ENTRY LIST ===============================================================================
 WidgetEntryList::WidgetEntryList( BaseObjectType* cobject,
                                   const Glib::RefPtr<Gtk::Builder>& )
 :   Gtk::TreeView( cobject )
@@ -69,6 +69,9 @@ WidgetEntryList::WidgetEntryList( BaseObjectType* cobject,
     }
 
     append_column( *column );
+
+    get_selection()->signal_changed().connect(
+            sigc::mem_fun( this, &WidgetEntryList::handle_selection_changed ) );
 }
 
 void
@@ -77,7 +80,7 @@ WidgetEntryList::cell_data_func_icon( Gtk::CellRenderer* cell, const Gtk::TreeMo
     DiaryElement* elem( ( * iter )[ ListData::colrec->ptr ] );
     if( elem != NULL )
     {
-        bool favored( elem->get_status() & ES::FAVORED );
+        bool favored( elem->is_favored() );
         cell->set_property( "visible", favored );
         if( favored )
             cell->set_property( "pixbuf", Lifeograph::icons->entry_favorite_16 );
@@ -101,13 +104,14 @@ WidgetEntryList::present_element( const DiaryElement* element )
     Gtk::TreePath path( element->m_list_data->treepath );
 
     expand_to_path( path );
-    if( ! get_selection()->is_selected( path ) )
-        get_selection()->select( path );
+
+    get_selection()->unselect_all();
+    get_selection()->select( path );
 
     Gtk::TreePath path_b, path_e;
     get_visible_range( path_b, path_e );
 
-    if( treepath_is_less( path, path_b ) || treepath_is_more( path, path_e ) )
+    if( is_treepath_less( path, path_b ) || is_treepath_more( path, path_e ) )
     {
         PRINT_DEBUG( "path is not visible" );
         scroll_to_row( path, 0.0 );   // does nothing if already visible
@@ -284,87 +288,76 @@ WidgetEntryList::find_element( const DiaryElement* element ) const
     return m_treestore->get_path( m_treestore->children().begin() );
 }
 
+bool
+select_true( const Glib::RefPtr< Gtk::TreeModel >& model,
+             const Gtk::TreePath& path, bool path_currently_selected )
+{
+    return true;
+}
+
+bool
+select_false( const Glib::RefPtr< Gtk::TreeModel >& model,
+              const Gtk::TreePath& path, bool path_currently_selected )
+{
+    return false;
+}
+
 bool
 WidgetEntryList::on_button_press_event( GdkEventButton* event )
 {
     Lifeograph::s_flag_dragging = false;
 
     Gtk::TreePath path;
-    if( get_path_at_pos( event->x, event->y, path ) )
+    if( get_path_at_pos( ( int ) event->x, ( int ) event->y, path ) )
     {
         Gtk::TreeRow row = * m_treestore->get_iter( path );
-        Lifeograph::s_elem_dragged = row[ ListData::colrec->ptr ];
+
+        if( get_selection()->is_selected( path ) && get_selection()->count_selected_rows() > 1 &&
+            !( event->state & ( Gdk::CONTROL_MASK | Gdk::SHIFT_MASK ) ) )
+        {
+            Lifeograph::s_elem_dragged = &m_multiple_entries;
+            get_selection()->set_select_function( sigc::ptr_fun( &select_false ) );
+        }
+        else
+        {
+            Lifeograph::s_elem_dragged = row[ ListData::colrec->ptr ];
+            get_selection()->set_select_function( sigc::ptr_fun( &select_true ) );
+        }
     }
     else
         Lifeograph::s_elem_dragged = NULL;
 
-/*  if( event->button != 3 )
-        return Gtk::TreeView::on_button_press_event( event );
-
-    Glib::RefPtr< Gtk::TreeSelection > selection = get_selection();
-
-    if( selection->count_selected_rows() <= 0 )
-        return Gtk::TreeView::on_button_press_event( event );
-
-    // treeview issues selection changed signal after button press signal.
-    // this causes context menus to be linked to the previously selected item
-    // when a row is selected with right click.
-    // to get around this we use a somewhat dirty hack and select the row
-    // from within the button press event handler
-    // p.s.: i dunno but there might be a simpler way of doing this
-    Gtk::TreeModel::Path path;
-    Gtk::TreeViewColumn  *column;
-    int i, j;
-    if( ! get_path_at_pos( (int) event->x, (int) event->y, path, column, i, j ) )
-        return Gtk::TreeView::on_button_press_event( event );
-
-    set_cursor( path );
-    // end of dirty hack
-
-    Gtk::TreeRow row = *( selection->get_selected() );
-    DiaryElement *item = row[ ListData::colrec->ptr ];
-
-    if( ! ( item->get_type() == DiaryElement::IT_ENTRY ||
-            item->get_type() == DiaryElement::IT_TAG ) )
-        return Gtk::TreeView::on_button_press_event( event );
-
-    if( m_menu )
-    {
-        delete m_menu;
-        m_menu = NULL;
-    }
-
-    m_menu = new Gtk::Menu;
-    Gtk::Image *imageDismiss = Gtk::manage(
-            new Gtk::Image( Gtk::Stock::DELETE, Gtk::ICON_SIZE_MENU ) );
-
-    if( item->get_type() == DiaryElement::IT_ENTRY )
-    {
-        Entry* entry = dynamic_cast< Entry* >( item );
-
-
-        m_menu->items().push_back(
-            Gtk::Menu_Helpers::ImageMenuElem(
-                entry->is_favored() ?
-                        _( "Remove from _Favorites" ) : _( "Add to _Favorites" ),
-                *image_favored,
-                sigc::mem_fun( * entry, &Entry::toggle_favoredness ) ) );
-    }
-    m_menu->accelerate( *this );
-    m_menu->popup( event->button, event->time );
-*/
     return Gtk::TreeView::on_button_press_event( event );
 }
 
 bool
 WidgetEntryList::on_button_release_event( GdkEventButton* event )
 {
+    get_selection()->set_select_function( sigc::ptr_fun( &select_true ) );
+
     if( ! Lifeograph::s_flag_dragging /*&& event->button != 1*/ )
     {
-        if( Lifeograph::s_elem_dragged )
-            Lifeograph::s_elem_dragged->show();
-        else
-            Diary::d->show();   // if nothing is selected show the diary view
+        if( Lifeograph::s_elem_dragged &&
+            !( event->state & ( Gdk::CONTROL_MASK | Gdk::SHIFT_MASK ) ) )
+        {
+            if( Lifeograph::s_elem_dragged->get_type() == DiaryElement::ET_MULTIPLE_ENTRIES )
+            {
+                get_selection()->unselect_all();
+
+                Gtk::TreePath path;
+                if( get_path_at_pos( ( int ) event->x, ( int ) event->y, path ) )
+                {
+                    get_selection()->select( path );
+                    Gtk::TreeRow row = * m_treestore->get_iter( path );
+                    DiaryElement *element = row[ ListData::colrec->ptr ];
+                    element->show();
+                }
+            }
+            else
+                Lifeograph::s_elem_dragged->show();
+        }
+
+        Lifeograph::s_elem_dragged = NULL;
     }
 
     return Gtk::TreeView::on_button_release_event( event );
@@ -394,9 +387,25 @@ WidgetEntryList::on_key_press_event( GdkEventKey* event )
 }
 
 void
-WidgetEntryList::on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& )
+WidgetEntryList::on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& context )
 {
-    Lifeograph::s_flag_dragging = ! Diary::d->is_read_only();
+    if( Lifeograph::s_elem_dragged )
+    {
+        Lifeograph::s_flag_dragging = true;
+        get_selection()->set_select_function( sigc::ptr_fun( &select_true ) );
+
+        //Gtk::TreeView::on_drag_begin( context );
+        context->set_icon( Lifeograph::s_elem_dragged->get_icon32(), 0, 0 );
+    }
+}
+
+void
+WidgetEntryList::on_drag_end( const Glib::RefPtr< Gdk::DragContext >& context )
+{
+    PRINT_DEBUG( "WidgetEntryList::on_drag_end()" );
+    Gtk::TreeView::on_drag_end( context );
+    restore_selection();
+    Lifeograph::s_elem_dragged = NULL;
 }
 
 bool
@@ -410,6 +419,7 @@ WidgetEntryList::on_drag_motion( const Glib::RefPtr< Gdk::DragContext >& context
         return false;
 
     bool retval( false );
+    Gdk::DragAction action( Gdk::ACTION_MOVE );
     Gtk::TreePath path;
     DiaryElement* element( NULL );
 
@@ -450,6 +460,12 @@ WidgetEntryList::on_drag_motion( const Glib::RefPtr< Gdk::DragContext >& context
                     if( element->get_type() != DiaryElement::ET_DIARY )
                         retval = true;
                     break;
+                case DiaryElement::ET_MULTIPLE_ENTRIES:
+                    if( element->get_type() == DiaryElement::ET_CHAPTER ||
+                        element->get_type() == DiaryElement::ET_TOPIC ||
+                        element->get_type() == DiaryElement::ET_GROUP )
+                        retval = true;
+                    break;
                 case DiaryElement::ET_CHAPTER:
                     // chapters can only be dropped onto temporal entries
                     if( element->get_type() == DiaryElement::ET_ENTRY &&
@@ -463,15 +479,18 @@ WidgetEntryList::on_drag_motion( const Glib::RefPtr< Gdk::DragContext >& context
                     if( element->get_type() == DiaryElement::ET_TOPIC )
                         retval = true;
                     break;
-                case DiaryElement::ET_TODO_GRP:
-                    // to-do groups can only be dropped onto other to-do groups
-                    if( element->get_type() == DiaryElement::ET_TODO_GRP )
+                case DiaryElement::ET_GROUP:
+                    // groups can only be dropped onto other groups
+                    if( element->get_type() == DiaryElement::ET_GROUP )
                         retval = true;
                     break;
                 case DiaryElement::ET_TAG:
                 case DiaryElement::ET_UNTAGGED:
                     if( element->get_type() == DiaryElement::ET_ENTRY )
+                    {
                         retval = true;
+                        action = Gdk::ACTION_COPY;
+                    }
                     break;
                 default: // the rest is not accepted
                     break;
@@ -482,11 +501,12 @@ WidgetEntryList::on_drag_motion( const Glib::RefPtr< Gdk::DragContext >& context
     if( retval )
     {
         m_elem_drop_target = element;
-        context->drag_status( Gdk::ACTION_MOVE, time );
+        context->drag_status( action, time );
+        restore_selection();
         get_selection()->select( path );
     }
     else
-        get_selection()->unselect_all();
+        restore_selection();
 
     //return Gtk::TreeView::on_drag_motion( context, x, y, time );
     return retval;
@@ -507,11 +527,11 @@ WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext >& context,
                 case DiaryElement::ET_ENTRY:
                 {
                     Entry* entry( dynamic_cast< Entry* >( Lifeograph::s_elem_dragged ) );
-                    switch(m_elem_drop_target->get_type() )
+                    switch( m_elem_drop_target->get_type() )
                     {
                         case DiaryElement::ET_CHAPTER:
                         case DiaryElement::ET_TOPIC:
-                        case DiaryElement::ET_TODO_GRP:
+                        case DiaryElement::ET_GROUP:
                         {
                             Chapter *chapter( dynamic_cast< Chapter* >( m_elem_drop_target ) );
                             Diary::d->set_entry_date( entry, chapter->get_free_order() );
@@ -531,48 +551,48 @@ WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext >& context,
                     }
                     break;
                 }
+                case DiaryElement::ET_MULTIPLE_ENTRIES:
+                    if( m_elem_drop_target->get_type() == DiaryElement::ET_CHAPTER ||
+                        m_elem_drop_target->get_type() == DiaryElement::ET_TOPIC ||
+                        m_elem_drop_target->get_type() == DiaryElement::ET_GROUP )
+                    {
+                        Chapter *chapter( dynamic_cast< Chapter* >( m_elem_drop_target ) );
+                        sigc::slot< void, Entry* > s = sigc::bind(
+                                 sigc::mem_fun( this, &WidgetEntryList::move_entry_to_chapter ),
+                                 chapter );
+                        AppWindow::p->panel_diary->do_for_each_selected_entry( s );
+
+                        AppWindow::p->panel_main->refresh_title();
+                        AppWindow::p->panel_diary->update_entry_list();
+                    }
+                    break;
                 case DiaryElement::ET_CHAPTER:
                 {
                     Chapter* chapter( dynamic_cast< Chapter* >( Lifeograph::s_elem_dragged ) );
                     Diary::d->get_current_chapter_ctg()->set_chapter_date(
-                            chapter, m_elem_drop_target->get_date().m_date );
+                            chapter, m_elem_drop_target->get_date_t() );
                     AppWindow::p->panel_main->refresh_title();
                     AppWindow::p->panel_diary->update_entry_list();
                     retval = true;
                     break;
                 }
-                case DiaryElement::ET_TODO_GRP:
+                case DiaryElement::ET_GROUP:
                 case DiaryElement::ET_TOPIC:
                 {
                     Chapter* chapter( dynamic_cast< Chapter* >( Lifeograph::s_elem_dragged ) );
-                    Diary::d->set_topic_order( chapter, m_elem_drop_target->get_date().m_date );
+                    Diary::d->set_topic_order( chapter, m_elem_drop_target->get_date_t() );
                     AppWindow::p->panel_main->refresh_title();
                     AppWindow::p->panel_diary->update_entry_list();
                     retval = true;
                     break;
                 }
                 case DiaryElement::ET_TAG:
-                    if( m_elem_drop_target->get_type() == DiaryElement::ET_ENTRY )
-                    {
-                        Tag *tag( dynamic_cast< Tag* >( Lifeograph::s_elem_dragged ) );
-                        Entry* entry( dynamic_cast< Entry* >( m_elem_drop_target ) );
-                        if( entry->add_tag( tag ) ) // if does not already have the tag
-                        {
-                            if( AppWindow::p->panel_main->is_cur_elem( m_elem_drop_target ) )
-                            {
-                                AppWindow::p->m_entry_view->update_tag_widget();
-                                AppWindow::p->m_entry_view->update_theme();
-                            }
-
-                            retval = true;
-                        }
-                    }
-                    break;
                 case DiaryElement::ET_UNTAGGED:
                     if( m_elem_drop_target->get_type() == DiaryElement::ET_ENTRY )
                     {
+                        Tag* tag( dynamic_cast< Tag* >( Lifeograph::s_elem_dragged ) );
                         Entry* entry( dynamic_cast< Entry* >( m_elem_drop_target ) );
-                        if( entry->clear_tags() )
+                        if( entry->add_tag( tag ) ) // if does not already have the tag
                         {
                             if( AppWindow::p->panel_main->is_cur_elem( m_elem_drop_target ) )
                             {
@@ -594,6 +614,63 @@ WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext >& context,
     return retval;
 }
 
+void
+WidgetEntryList::handle_selection_changed()
+{
+    if( Lifeograph::m_internaloperation || Lifeograph::s_flag_dragging )
+        return;
+
+    m_multiple_entries.m_entries.clear();
+
+    Glib::RefPtr< Gtk::TreeSelection > sel( get_selection() );
+    int num_sel( sel->count_selected_rows() );
+
+    std::vector< Gtk::TreePath > selected_rows = sel->get_selected_rows();
+
+    for( std::vector< Gtk::TreePath >::iterator iter = selected_rows.begin();
+         iter != selected_rows.end(); ++iter )
+    {
+        Gtk::TreePath path( *iter );
+        Gtk::TreeRow row( * m_treestore->get_iter( path ) );
+        DiaryElement* elem( row[ ListData::colrec->ptr ] );
+        if( elem->get_type() != DiaryElement::ET_ENTRY )
+        {
+            if( num_sel > 1 )
+            {
+                Lifeograph::m_internaloperation++;
+                sel->unselect( path );
+                Lifeograph::m_internaloperation--;
+            }
+        }
+        else
+            m_multiple_entries.m_entries.push_back( dynamic_cast< Entry* >( elem ) );
+    }
+}
+
+void
+WidgetEntryList::restore_selection()
+{
+    get_selection()->unselect_all();
+
+    for( EntryVectorIter iter = m_multiple_entries.m_entries.begin();
+         iter != m_multiple_entries.m_entries.end(); ++iter )
+    {
+        get_selection()->select( ( *iter )->m_list_data->treepath );
+    }
+
+    // TODO also restore if last selection was another type of element than entry
+}
+
+void
+WidgetEntryList::do_for_each_selected_entry( sigc::slot< void, Entry* >& slot )
+{
+    for( EntryVectorIter iter = m_multiple_entries.m_entries.begin();
+         iter != m_multiple_entries.m_entries.end(); ++iter )
+    {
+        slot( *iter );
+    }
+}
+
 int
 WidgetEntryList::sort_by_date( const Gtk::TreeModel::iterator& itr1,
                                const Gtk::TreeModel::iterator& itr2 )
@@ -609,11 +686,11 @@ WidgetEntryList::sort_by_date( const Gtk::TreeModel::iterator& itr1,
 
     int direction( ( item1->get_date().is_ordinal() && item2->get_date().is_ordinal() ) ? -1 : 1 );
 
-    if( item1->get_date().get_sort() > item2->get_date().get_sort() )
-        return( -1 * direction );
+    if( item1->get_date() > item2->get_date() )
+        return -direction;
     else
-    if( item1->get_date().get_sort() < item2->get_date().get_sort() )
-        return( 1 * direction );
+    if( item1->get_date() < item2->get_date() )
+        return direction;
     else
         return 0;
 }
@@ -628,8 +705,8 @@ WidgetEntryList::sort_by_size( const Gtk::TreeModel::iterator& itr1,
         return 0;
 
     // group ordinal entries together:
-    if( item1->get_date().is_ordinal() != item2->get_date().is_ordinal() )
-        return( item1->get_date().is_ordinal() ? -1 : 1 );
+//    if( item1->get_date().is_ordinal() != item2->get_date().is_ordinal() )
+//        return( item1->get_date().is_ordinal() ? -1 : 1 );
 
     if( item1->get_size() > item2->get_size() )
         return -1;
@@ -666,8 +743,8 @@ WidgetEntryList::sort_by_change( const Gtk::TreeModel::iterator& itr1,
 inline bool
 WidgetEntryList::move_path_next( Gtk::TreePath& path )
 {
-    if( unsigned( path.back() ) < ( m_treestore->
-                get_iter( path )->parent()->children().size() - 1 ) )
+    if( unsigned( path.back() ) <
+            ( m_treestore->get_iter( path )->parent()->children().size() - 1 ) )
     {
         path.next();
         return true;
@@ -686,3 +763,16 @@ WidgetEntryList::make_path_deeper_last( Gtk::TreePath& path )
     }
     return false;
 }
+
+// HELPER FUNCTION
+void
+WidgetEntryList::move_entry_to_chapter( Entry* entry, Chapter* chapter )
+{
+    Diary::d->set_entry_date( entry, chapter->get_free_order() );
+}
+
+const Glib::RefPtr< Gdk::Pixbuf >&
+WidgetEntryList::MultipleEntries::get_icon32() const
+{
+    return Lifeograph::icons->entry_32;
+}
