@@ -28,6 +28,7 @@
 #include <gtkmm/builder.h>
 
 #include "entry.hpp"
+#include "panel_extra.hpp"
 
 
 namespace LIFEO
@@ -48,6 +49,7 @@ class TagWidget : public EntryClear
         bool                        compare_text( const Glib::ustring&,
                                                   const Gtk::TreeModel::const_iterator& );
 
+        TreeStoreExtra::Colrec      colrec;
         Glib::RefPtr< Gtk::EntryCompletion >
                                     m_completion;
         Glib::RefPtr< Gtk::ListStore >
