@@ -48,6 +48,23 @@ Gtk::TextBuffer             *UndoEdit::m_ptr2buffer;
 
 PredicateNL                 TextbufferDiary::s_predicate_nl;
 
+
+int
+TextbufferDiary::get_text_width ( const Pango::FontDescription& fd, const Glib::ustring& str )
+{
+    int width, height;
+
+    Glib::RefPtr< Pango::Context > context = m_ptr2textview->get_pango_context();
+
+    Glib::RefPtr< Pango::Layout > layout = Pango::Layout::create( context );
+    layout->set_text( str );
+    layout->set_font_description( fd );
+    layout->get_pixel_size( width, height );
+
+    return width;
+}
+
+
 // LINK
 Link::Link( const Glib::RefPtr< Gtk::TextMark >& start,
             const Glib::RefPtr< Gtk::TextMark >& end,
@@ -127,7 +144,7 @@ LinkEntry::go()
         entries->at( 0 )->show();
     else
     {
-        Entry *entry = Diary::d->create_entry( m_date.m_date );
+        Entry* entry = Diary::d->create_entry( m_date.m_date );
         AppWindow::p->panel_diary->update_entry_list();
         entry->show();
     }
@@ -225,7 +242,7 @@ TextbufferDiary::TextbufferDiary()
 :   Gtk::TextBuffer(),
     parser_open_tag_is_link( false ),
     m_flag_settextoperation( false ), m_flag_ongoing_operation( 0 ), m_flag_parsing( false ),
-    m_ptr2textview( NULL ), m_max_thumbnail_width( 0 ),m_enchant_dict( NULL )
+    m_ptr2textview( NULL ), m_max_thumbnail_width( 0 ), m_enchant_dict( NULL )
 {
     LinkUri::m_ptr2buffer = this;
     UndoEdit::m_ptr2buffer = this;
@@ -645,11 +662,14 @@ void
 TextbufferDiary::apply_link_date()
 {
     LinkStatus status( LS_OK );
-    Entry *ptr2entry( Diary::d->get_entry( date_last.m_date + 1 ) ); // + 1 fixes order
+    Entry* ptr2entry( Diary::d->get_entry( date_last.m_date + 1 ) ); // + 1 fixes order
     if( ptr2entry == NULL )
+    {
+        if( Diary::d->is_read_only() )
+            return;
         status = LS_ENTRY_UNAVAILABLE;
-    else
-    if( date_last.get_pure() == m_ptr2entry->get_date().get_pure() )
+    }
+    else if( date_last.get_pure() == m_ptr2entry->get_date().get_pure() )
         status = Diary::d->get_day_has_multiple_entries( date_last ) ? LS_OK : LS_CYCLIC;
 
     Gtk::TextIter iter_start( get_iter_at_offset( m_pos_start ) );
@@ -660,8 +680,8 @@ TextbufferDiary::apply_link_date()
     {
         Gtk::TextIter iter_end( iter_current );
         iter_end++;
-        // if hidden link:
-        if( char_current == '>' )
+
+        if( m_flag_hidden_link )
         {
             m_list_links.push_back( new LinkEntry( create_mark( iter_tab ),
                                                    create_mark( iter_current ),
@@ -732,10 +752,30 @@ TextbufferDiary::apply_match()
     apply_tag( m_tag_match, iter_start, iter_end );
 }
 
+void
+TextbufferDiary::apply_indent()
+{
+    Glib::RefPtr< Gtk::TextTag > tag_indent = Tag::create();
+    int tab_width = get_text_width( m_ptr2entry->get_theme()->font, "\t" );
+    tab_width *=  ( pos_current - m_pos_start );
+    tag_indent->property_left_margin() = tab_width; // FIXME: indents more than expected
+    tag_indent->property_indent() = -tab_width;
+
+    PRINT_DEBUG2( "tab width= " , tab_width );
+    PRINT_DEBUG2( "pos_current= " , pos_current );
+    PRINT_DEBUG2( "m_pos_start= " , m_pos_start );
+
+    get_tag_table()->add( tag_indent );
+
+    Gtk::TextIter iter_start( get_iter_at_offset( m_pos_start ) );
+    Gtk::TextIter iter_end( get_iter_at_offset( pos_current ) );
+    apply_tag( tag_indent, iter_start, iter_end );
+}
+
 //#define CALL_MEMBER_FN(object,ptrToMember)  ((object).*(ptrToMember))
 
 inline void
-TextbufferDiary::apply_markup( const Glib::RefPtr< Tag >& tag)
+TextbufferDiary::apply_markup( const Glib::RefPtr< Tag >& tag )
 {
     Gtk::TextIter iter_start( get_iter_at_offset( m_pos_start ) );
     Gtk::TextIter iter_current( get_iter_at_offset( pos_current ) );
@@ -766,7 +806,7 @@ TextbufferDiary::on_insert( const Gtk::TextIter& iterator,
     }
     else
     {
-        UndoInsert * undo_insert = new UndoInsert( offset_itr, text );
+        UndoInsert* undo_insert = new UndoInsert( offset_itr, text );
         UndoManager::m->add_action( undo_insert );
     }
 
@@ -904,7 +944,7 @@ TextbufferDiary::process_new_line()
                     if( char_lf != '1' )
                         return false;
                     char_lf = ' ';
-                    text += Glib::ustring::compose<int,char>(
+                    text += Glib::ustring::compose< int,char >(
                             "%1%2 ", ++value, iter_start.get_char() );
                     break;
                 case '\t':
@@ -1144,7 +1184,7 @@ TextbufferDiary::clear_links()
 }
 
 void
-TextbufferDiary::clear_images( int start, int &end )
+TextbufferDiary::clear_images( int start, int& end )
 {
     assert( m_flag_parsing );   // this function should only be called during parsing
 
@@ -1206,7 +1246,7 @@ TextbufferDiary::update_thumbnail_width( int width )
 }
 
 void
-TextbufferDiary::handle_menu( Gtk::Menu *menu )
+TextbufferDiary::handle_menu( Gtk::Menu* menu )
 {
     if( Diary::d->is_read_only() )
         return;
@@ -1231,7 +1271,7 @@ TextbufferDiary::handle_menu( Gtk::Menu *menu )
     }
 
     // LANGUAGE SELECTION SUBMENU
-    Gtk::MenuItem *mi_langs( Gtk::manage( new Gtk::MenuItem( _("Spell Checking" ) ) ) );
+    Gtk::MenuItem* mi_langs( Gtk::manage( new Gtk::MenuItem( _( "Spell Checking" ) ) ) );
     mi_langs->set_submenu( *build_languages_menu() );
     mi_langs->show_all();
     menu->prepend( *mi_langs );
@@ -1239,7 +1279,7 @@ TextbufferDiary::handle_menu( Gtk::Menu *menu )
 
 // FORMATTING
 void
-TextbufferDiary::toggle_format( Glib::RefPtr< Tag > tag, const Glib::ustring &markup )
+TextbufferDiary::toggle_format( Glib::RefPtr< Tag > tag, const Glib::ustring& markup )
 {
     if( ! m_ptr2textview->has_focus() )
         return;
@@ -1254,14 +1294,20 @@ TextbufferDiary::toggle_format( Glib::RefPtr< Tag > tag, const Glib::ustring &ma
         int p_start = iter_start.get_offset();
         int p_end = iter_end.get_offset() - 1;
 
-        if( ! iter_start.is_start() )
-        {
+        Gtk::TextIter firstnl = begin();
+        if( ! firstnl.forward_find_char( s_predicate_nl ) ) // there is only heading
+            return;
+        int p_first_nl = firstnl.get_offset();
+
+        if( p_end <= p_first_nl )
+            return;
+        else if( p_start > p_first_nl )
             p_start--;   // also evaluate the previous character
-        }
-        else
+        else // p_start <= p_first_nl
         {
+            p_start = p_first_nl + 1;
             properly_separated = true;
-            start = -2;
+            start = -1;
         }
 
         for( ; ; p_start++ )
@@ -1273,7 +1319,7 @@ TextbufferDiary::toggle_format( Glib::RefPtr< Tag > tag, const Glib::ustring &ma
                 return;
             switch( get_iter_at_offset( p_start ).get_char() )
             {
-                case '\n':
+                case '\n': // selection spreads over more than one line
                     if( start >= 0 )
                     {
                         if( properly_separated )
@@ -1306,7 +1352,7 @@ TextbufferDiary::toggle_format( Glib::RefPtr< Tag > tag, const Glib::ustring &ma
                         start = -1;
                     }
                     break;
-                default:
+                default: // non-space
                     if( start == -2 )
                         start = -1;
                     else
@@ -1340,7 +1386,7 @@ TextbufferDiary::toggle_format( Glib::RefPtr< Tag > tag, const Glib::ustring &ma
     {
         Glib::RefPtr< Gtk::TextMark > mark = get_insert();
         iter_start = mark->get_iter();
-        if( Glib::Unicode::isspace( iter_start.get_char() ) )
+        if( Glib::Unicode::isspace( iter_start.get_char() ) || iter_start.is_end() )
         {
             if( iter_start.starts_line() )
                 return;
@@ -1355,9 +1401,7 @@ TextbufferDiary::toggle_format( Glib::RefPtr< Tag > tag, const Glib::ustring &ma
             iter_start--;
             if( Glib::Unicode::isspace( iter_start.get_char() ) )
             {
-                // ugly!
-                iter_start++;
-                iter_start++;
+                iter_start.forward_chars( 2 );
             }
         }
         if( iter_start.has_tag( tag ) ) // if already has the tag, remove it
@@ -1856,7 +1900,7 @@ TextbufferDiary::set_richtext( Entry* entry )
 }
 
 void
-TextbufferDiary::set_theme( const Theme *theme )
+TextbufferDiary::set_theme( const Theme* theme )
 {
     m_ptr2textview->override_font( theme->font );
     m_ptr2textview->override_background_color( theme->color_base, Gtk::STATE_FLAG_NORMAL );
@@ -1877,13 +1921,13 @@ TextbufferDiary::set_theme( const Theme *theme )
             theme->color_base, theme->color_text, 0.9 );
     m_tag_match->property_foreground_rgba() = theme->color_base;
     m_tag_match->property_background_rgba() = contrast2(
-            theme->color_base, Theme::s_color_match, Theme::s_color_match2 );
+            theme->color_base, Theme::s_color_match1, Theme::s_color_match2 );
     m_tag_markup->property_foreground_rgba() = color_mid;
     m_tag_markup_link->property_foreground_rgba() = color_mid;
     m_tag_link->property_foreground_rgba() = contrast2(
-            theme->color_base, Theme::s_color_link, Theme::s_color_link2 );
+            theme->color_base, Theme::s_color_link1, Theme::s_color_link2 );
     m_tag_link_broken->property_foreground_rgba() = contrast2(
-            theme->color_base, Theme::s_color_broken, Theme::s_color_broken2 );
+            theme->color_base, Theme::s_color_broken1, Theme::s_color_broken2 );
 }
 
 // SPELL CHECKING BY DIRECT UTILIZATION OF ENCHANT (code partly copied from GtkSpell library)
@@ -2152,7 +2196,7 @@ TextviewDiary::TextviewDiary( BaseObjectType* cobject, const Glib::RefPtr<Gtk::B
     set_buffer( static_cast< Glib::RefPtr< TextbufferDiary > >( m_buffer ) );
     m_buffer->set_textview( this );
     set_wrap_mode( Gtk::WRAP_WORD );
-    set_left_margin( 10 );
+    set_left_margin( TextbufferDiary::LEFT_MARGIN );
 
     signal_populate_popup().connect( sigc::mem_fun( *m_buffer, &TextbufferDiary::handle_menu ) );
     signal_query_tooltip().connect( sigc::mem_fun( this, &TextviewDiary::handle_query_tooltip ) );
@@ -2349,6 +2393,28 @@ TextviewDiary::on_size_allocate( Gtk::Allocation& allocation )
     }
 }
 
+bool
+TextviewDiary::on_drag_motion( const Glib::RefPtr< Gdk::DragContext >& context,
+                               int x, int y, guint time )
+{
+    if( Lifeograph::s_flag_dragging && Lifeograph::s_elem_dragged )
+    {
+        switch( Lifeograph::s_elem_dragged->get_type() )
+        {
+            case DiaryElement::ET_ENTRY:
+                break;
+            case DiaryElement::ET_TAG:
+            case DiaryElement::ET_UNTAGGED:
+                context->drag_status( Gdk::ACTION_COPY, time );
+                return true;
+            default:
+                return false;
+        }
+    }
+
+    return Gtk::TextView::on_drag_motion( context, x, y, time );
+}
+
 //void
 //TextviewDiary::on_style_changed( const Glib::RefPtr< Gtk::Style > &style_prev )
 //{
