@@ -100,7 +100,7 @@ class UndoEdit : public Undoable
         Glib::ustring       m_text;
 
     private:
-        static Gtk::TextBuffer      *m_ptr2buffer;
+        static Gtk::TextBuffer*     m_ptr2buffer;
 
     friend class TextbufferDiary;
 };
@@ -121,7 +121,7 @@ class UndoInsert :public UndoEdit
             return false;
         }
 
-        void                merge (Undoable* action)
+        void                merge( Undoable* action )
         {
             m_text += dynamic_cast< UndoInsert* >( action )->get_text();
         }
@@ -143,7 +143,7 @@ class UndoErase : public UndoEdit
                             UndoErase( int position, const Glib::ustring& text )
         : UndoEdit( position, text, UT_ERASE_TEXT ) { }
 
-        bool                can_merge (const Undoable* action) const
+        bool                can_merge( const Undoable* action ) const
         {
             if ( ( action->get_time_sec() - m_time.tv_sec ) < UNDO_MERGE_TIMEOUT )
                 if ( action->get_type() == m_type )
@@ -158,7 +158,7 @@ class UndoErase : public UndoEdit
             return false;
         }
 
-        void                merge (Undoable* action)
+        void                merge( Undoable* action )
         {
             UndoErase * action_erase = dynamic_cast< UndoErase* >( action );
             m_text.insert( 0, action_erase->get_text() );
@@ -234,7 +234,7 @@ class LinkEntry : public Link
         Date                        m_date;
 
     protected:
-        static Gtk::Menu            *menu_link;
+        static Gtk::Menu*           menu_link;
 };
 
 class LinkUri : public Link
@@ -246,7 +246,7 @@ class LinkUri : public Link
         void                        go();
 
         std::string                 m_url;
-        static Gtk::TextBuffer      *m_ptr2buffer;
+        static Gtk::TextBuffer*     m_ptr2buffer;
 };
 
 class LinkCheck : public Link
@@ -284,6 +284,9 @@ class PredicateNL
 class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 {
     public:
+        static const int            LEFT_MARGIN = 10;
+
+
         typedef void ( TextbufferDiary::*ParsingApplierFn )();
 
 //      typedef sigc::signal< LinkStatus, Date >
@@ -292,7 +295,7 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
                                     Signal_void_ustring;
 
                                     TextbufferDiary();
-        void                        set_textview( Gtk::TextView *ptr2textview )
+        void                        set_textview( Gtk::TextView* ptr2textview )
         { m_ptr2textview = ptr2textview; }
         void                        handle_logout();
         void                        handle_login();
@@ -377,10 +380,15 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         void                        apply_check_unf();
         void                        apply_check_fin();
         void                        apply_match();
-        void                        apply_markup( const Glib::RefPtr<Tag>& );
+        void                        apply_indent();
+
+        void                        apply_markup( const Glib::RefPtr< Tag >& );
 
         gunichar                    get_char_at( int );
 
+        int                         get_text_width( const Pango::FontDescription&,
+                                                    const Glib::ustring& );
+
         void                        handle_word();
 
         void                        handle_spellcheck_toggled();
@@ -436,8 +444,8 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         bool                        m_flag_settextoperation;
         int                         m_flag_ongoing_operation;   // Incremental to allow nesting
         bool                        m_flag_parsing;
-        Entry                       *m_ptr2entry;
-        Gtk::TextView               *m_ptr2textview;
+        Entry*                      m_ptr2entry;
+        Gtk::TextView*              m_ptr2textview;
 
         typedef std::list< Link* >  ListLinks;
         ListLinks                   m_list_links;
@@ -447,10 +455,9 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         int                         m_max_thumbnail_width;
 
         // ENCHANT SPELLCHECKER
-        EnchantDict                 *m_enchant_dict;
+        EnchantDict*                m_enchant_dict;
         int                         m_spell_suggest_offset;
 
-    friend class DialogTheme;
     friend class EntryView;
     friend class LinkCheck;
     friend class TextviewDiary;
@@ -465,7 +472,7 @@ class TextviewDiary : public Gtk::TextView
 
         void                        set_richtext( Entry* );
 
-        TextbufferDiary             *m_buffer;
+        TextbufferDiary*            m_buffer;
 
     protected:
         void                        update_link();
@@ -475,19 +482,22 @@ class TextviewDiary : public Gtk::TextView
         virtual bool                on_key_press_event( GdkEventKey* );
         virtual bool                on_key_release_event( GdkEventKey* );
         void                        on_size_allocate( Gtk::Allocation& );
-        bool                        handle_query_tooltip( int, int, bool,
-                                                          const Glib::RefPtr< Gtk::Tooltip >& );
+        bool                        on_drag_motion( const Glib::RefPtr< Gdk::DragContext >&,
+                                                    int, int, guint );
         //~ virtual void                on_populate_popup( Gtk::Menu* );
 //      virtual void                on_style_changed( const Glib::RefPtr< Gtk::Style >& );
 
+        bool                        handle_query_tooltip( int, int, bool,
+                                                          const Glib::RefPtr< Gtk::Tooltip >& );
+
     private:
         const Glib::RefPtr< Gdk::Cursor >
                                     m_cursor_hand;
         const Glib::RefPtr< Gdk::Cursor >
                                     m_cursor_xterm;
-        const Glib::RefPtr< Gdk::Cursor >
-                                    *m_ptr2cursor_last;
-        Link                        *m_link_hovered;
+        const Glib::RefPtr< Gdk::Cursor >*
+                                    m_ptr2cursor_last;
+        Link*                       m_link_hovered;
 
         bool                        m_flag_size_allocated;
         bool                        m_flag_set_text_queued;
